package com.hrsk.cloud.eg.app.loan.customize;

import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import org.springframework.beans.BeansException;
import org.springframework.context.ApplicationContext;
import org.springframework.context.ApplicationContextAware;
import org.springframework.stereotype.Component;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

/**
 * @author zhangyy
 * @version 1.0
 * @description: ApiBizHandler
 * @date 2024/9/13 09:34
 */
@Component
public class ApiCustomizeBizHandler implements ApplicationContextAware {

    private final Map<ServerCodeEnums, LoanDockingApi> bizHandlerMap = new HashMap<>();


    public void putBizHandler(ServerCodeEnums  type, LoanDockingApi handler) {
        bizHandlerMap.put(type, handler);
    }

    public LoanDockingApi getBizHandler(ServerCodeEnums type) {
        LoanDockingApi bizHandler = this.bizHandlerMap.get(type);
        if (bizHandler == null) {
            throw new RuntimeException("not.found.BizHandler");
        }
        return bizHandler;
    }

    @Override
    public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
        Map<String, LoanDockingApi> beansOfType = applicationContext.getBeansOfType(LoanDockingApi.class);
        Collection<LoanDockingApi> services = beansOfType.values();
        for (LoanDockingApi service : services) {
            ServerCodeEnums type = service.getType();
            bizHandlerMap.put(type, service);
        }
    }

}
