package com.hrsk.cloud.eg.app.loan.customize;

import com.hrsk.cloud.eg.clinet.dto.data.command.LoanParamCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.JoinMethodEnums;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl.*;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgLoanApiConfigInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.util.Objects;

/**
 * @author zhangyy
 * @version 1.0
 * @description: ApiRouteService
 * @date 2024/9/13 09:29
 */
@Slf4j
@Service
public class ApiCustomizeRouteService {

    @Resource
    private EgApiService egApiService;

    @Resource
    private ApiCustomizeBizHandler apiCustomizeBizHandler;

    @Resource
    private QingyuCreditService qingyuCreditService;

    @Resource
    private XinluCreditService xinluCreditService;

    @Resource
    private OpenApiCreditService openApiCreditService;

    @Resource
    private QingyuV2CreditService qingyuV2CreditService;

    @Resource
    private XiangKeDaCreditService xiangKeDaCreditService;

    @Resource
    private RxkCreditService rxkCreditService;

    @Resource
    private OpenApiAesCreditService openApiAesCreditService;

    @Resource
    private HuirongCrmCreditService huirongCrmCreditService;

    @Resource
    private JinDieV2CreditService jinDieV2CreditService;

    @Resource
    private JinDieV3CreditService jinDieV3CreditService;

    @Resource
    private QingyuV3CreditService qingyuV3CreditService;

    @Resource
    private PubNoCheckCreditService pubNoCheckCreditService;


    /**
     * API 路由
     *
     * @param xdProduct
     * @return
     */
    public LoanDockingApi apiRouter(PlanCmd xdProduct) {
        if (null == xdProduct.getApiId()) return null;
        EgLoanApiConfigInfoDo apiInfo = egApiService.getApiInfoByRedis(xdProduct.getApiId());
        LoanDockingApi apiService = null;
        if (Objects.isNull(apiInfo)&&apiInfo.getNeedCheck()==0){
             apiService=pubNoCheckCreditService;
             return apiService;
        }
        JoinMethodEnums method = JoinMethodEnums.getByCode(apiInfo.getApiCode());
        if (null == method) return null;
        switch (method) {
            case CRM_QY:
                apiService = qingyuCreditService;
                break;
            case CRM_XL:
                apiService = xinluCreditService;
                break;
            case OPEN_API:
                apiService = openApiCreditService;
                break;
            case CRM_QY_V2:
                apiService = qingyuV2CreditService;
                break;
            case CRM_XKD:
                apiService = xiangKeDaCreditService;
                break;
            case CRM_RXK:
                apiService = rxkCreditService;
                break;
            case HUIRONG_CRM:
                apiService = huirongCrmCreditService;
                break;
            case CRM_EC:
                break;
            case CRM_JD:
                apiService = jinDieV2CreditService;
                break;
            case CRM_JDV3:
                apiService = jinDieV3CreditService;
                break;
            case BUSI_API:
                apiService = apiCustomizeBizHandler.getBizHandler(ServerCodeEnums.map.get(apiInfo.getApiCode()));
                break;
            case CRM_QY_V3:
                apiService = qingyuV3CreditService;
                break;
            case OPEN_API_AES:
                apiService = openApiAesCreditService;
                break;
            default:
                log.error("不支持的对接方式:productId={}", xdProduct.getPlanId());
        }
        return apiService;
    }

    /**
     * @description:  助贷撞库api
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/9/13 09:59
     */
    public DataVo loanCheckInto(LoanParamCmd checkIntoParamCmd){
        LoanDockingApi loanDockingApi = apiRouter(checkIntoParamCmd.getPlan());
      return   loanDockingApi.qualityCheck(checkIntoParamCmd.getUser(), checkIntoParamCmd.getPlan(),checkIntoParamCmd.getApiConfigInfo());
    }
}
