package com.hrsk.cloud.eg.clinet.vo;

import java.io.Serializable;
import java.util.Objects;

public class DataVo<T> implements Serializable {
    private Integer status;
    private String msg;
    private T data;

    public DataVo(Integer status, String msg) {
        this.status = status;
        this.msg = msg;
    }

    public DataVo() {
    }

    public DataVo(Integer status, String msg, T data) {
        this.status = status;
        this.msg = msg;
        this.data = data;
    }

    public static <T> DataVo<T> dataVo(Integer status, String msg, T data) {
        return createDefaulDataVo(status, msg, data);
    }

    public static <T> DataVo<T> success(String msg, T data) {
        return createDefaulDataVo(0, msg, data);
    }

    public static <T> DataVo<T> success(Integer status, String msg, T data) {
        return createDefaulDataVo(status, msg, data);
    }

    public static <T> DataVo<T> fail(String msg, T data) {
        return createDefaulDataVo(1, msg, data);
    }

    public static <T> DataVo<T> fail(Integer status, String msg, T data) {
        return createDefaulDataVo(status, msg, data);
    }

    public static <T> DataVo<T> createDefaulDataVo(Integer code, String message, T data) {
        DataVo<T> responseVo = new DataVo();
        if (code != null) {
            responseVo.setStatus(code);
        }

        if (!Objects.isNull(message)) {
            responseVo.setMsg(message);
        }

        if (data != null) {
            responseVo.setData(data);
        }

        return responseVo;
    }

    public static DataVo timeout(String msg) {
        return new DataVo(2, msg);
    }

    public static <T> DataVo<T> timeout(T data, String msg) {
        return new DataVo(2, msg, data);
    }

    public static DataVo success() {
        return new DataVo(0, "撞库成功");
    }

    public static DataVo success(String msg) {
        return new DataVo(0, msg);
    }

    public static DataVo success(Integer status, String msg) {
        return new DataVo(status, msg);
    }

    public static DataVo success(Integer status) {
        return new DataVo(status, "成功");
    }

    public static DataVo fail() {
        return new DataVo(1, "撞库失败");
    }

    public static DataVo fail(String msg) {
        return new DataVo(1, msg + "撞库失败");
    }

    public Integer getStatus() {
        return this.status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getMsg() {
        return this.msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public T getData() {
        return this.data;
    }

    public void setData(T data) {
        this.data = data;
    }
}
