package com.hrsk.cloud.eg.domain.api;

import com.hrsk.cloud.eg.domain.api.common.ApiTypeEnums;
import com.hrsk.cloud.eg.domain.common.utils.BizPreconditions;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import com.alibaba.cola.domain.DomainFactory;
import org.springframework.stereotype.Component;

/**
 * @author: bianlanzhou
 * @create: 2024-07-26 17:57
 * @description: API领域对象工厂
 **/
@Component
@Slf4j
public class ApiFactory {
    /**
     * 创建API对象
     * @param apiConfig api配置
     * @param input 入参
     * @return API
     */
    public Api createApi(ApiConfig apiConfig,Object input){
        BizPreconditions.checkArgument(apiConfig!=null,"API配置不能为空!");
        BizPreconditions.checkArgument(StringUtils.isNotBlank(apiConfig.getType()),"API配置类型不能为空!");
        if(StringUtils.equals(ApiTypeEnums.HTTP.getType(),apiConfig.getType())
          ||StringUtils.equals(ApiTypeEnums.HTTPS.getType(), apiConfig.getType())
         ){
            return createHttpApi((HttpApiConfig)apiConfig,input);
        }else {
            log.error("不支持的API类型:{}!",apiConfig.getType());
        }
        return null;
    }


    /**
     * @description: 构建统一返回值
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/9/2 16:33
     */
    public Object createResult(ApiConfig apiConfig,Object output){
        HttpApi httpApi = DomainFactory.create(HttpApi.class);
        return httpApi.loadResult((HttpApiConfig) apiConfig,output);
    }
    /**
     * 创建HTTP API
     * @param httpApiConfig http api config
     * @return  HTTP API
     */
    private Api createHttpApi(HttpApiConfig httpApiConfig,Object input){
        HttpApi httpApi = DomainFactory.create(HttpApi.class);
        httpApi.load(httpApiConfig,input);
        return httpApi;
    }
}
