package com.hrsk.cloud.eg.domain.api;

import com.hrsk.cloud.eg.domain.api.resolver.vo.ValueObjectResolverManager;
import com.hrsk.cloud.eg.domain.common.utils.BizPreconditions;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import org.apache.commons.lang3.StringUtils;
import org.springframework.util.CollectionUtils;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * @author: bianlanzhou
 * @create: 2024-07-27 10:21
 * @description: 值对象
 **/

@Getter
@ToString
public class ValueObject implements Serializable {
    /**
     * 类型
     */
    @Setter
    private String type;
    /**
     * 值
     */
    @Setter
    private String value;
    /**
     * 真实值
     */
    private Object realValue;
    /**
     * 函数链
     */
    @Setter
    private List<FunctionObject> functions = new ArrayList<>();

    /**
     * 校验必要参数
     */
    void checkParam(){
        BizPreconditions.checkArgument(StringUtils.isEmpty(type),"配置中值对象的type不能为空!");
        BizPreconditions.checkArgument(StringUtils.isEmpty(value),"配置中值对象的value不能为空!");
    }


    public ValueObject compile(ApiContext apiContext){
        this.realValue = ValueObjectResolverManager.getInstance().resolve(this,apiContext);
        if(CollectionUtils.isEmpty(functions)){
            return this;
        }
        for(FunctionObject function : functions){
            this.realValue = function.apply(realValue,apiContext);
        }
        return this;
    }


    public ValueObject compile(Map<String,Object> apiContext){
        this.realValue = ValueObjectResolverManager.getInstance().resolve(this,apiContext);
        if(CollectionUtils.isEmpty(functions)){
            return this;
        }
        for(FunctionObject function : functions){
            this.realValue = function.apply(realValue,apiContext);
        }
        return this;
    }



}
