package com.hrsk.cloud.eg.domain.api.func;

import com.alibaba.cola.exception.BizException;
import com.hrsk.cloud.eg.domain.api.FunctionParam;
import lombok.extern.slf4j.Slf4j;

import java.util.HashMap;
import java.util.Map;
import java.util.function.Function;

/**
 * @author: bianlanzhou
 * @create: 2024-08-01 09:48
 * @description: 值对象函数管理器
 **/
@Slf4j
public class ValueObjectFunctionManager {
    /**
     * 函数
     */
    private static final Map<String, Function<FunctionParam, Object>> FUNCTIONS = new HashMap<>();
    /**
     * 实例
     */
    private static final ValueObjectFunctionManager INSTANCE = new ValueObjectFunctionManager();

    static {
        regist();
    }

    /**
     * 构造函数
     */
    private ValueObjectFunctionManager(){}

    /**
     * 获取实例
     * @return 实例
     */
    public static ValueObjectFunctionManager getInstance() {
        return INSTANCE;
    }

    /**
     * 注册函数
     */
    private static void regist(){
        log.info("开始注册值对象函数!");
        FUNCTIONS.put("md5", EncryptionFunction::md5);
        FUNCTIONS.put("resultCodeConvertStatusInteger", EncryptionFunction::resultCodeConvertStatusInteger);
        FUNCTIONS.put("resultCodeConvertStatusString", EncryptionFunction::resultCodeConvertStatusString);
        FUNCTIONS.put("combinationCodeSuccessIsExit",EncryptionFunction::combinationCodeSuccessIsExit);
        log.info("函数已注册!");
    }

    /**
     * 执行函数
     * @param code 函数编码
     * @param functionParam 函数参数
     * @return 函数执行结果
     */
    public Object apply(String code, FunctionParam functionParam){
        Function<FunctionParam,Object> function = FUNCTIONS.get(code);
        if(function == null){
            throw new BizException("不支持的函数编码!");
        }
        return function.apply(functionParam);
    }
}
