package com.hrsk.cloud.eg.domain.api.resolver.result;

import com.google.common.collect.Maps;
import com.hrsk.cloud.eg.domain.api.ApiContext;
import com.hrsk.cloud.eg.domain.api.ApiResult;
import com.hrsk.cloud.eg.domain.api.common.ApiPayloadTypeEnum;
import com.hrsk.cloud.eg.domain.api.resolver.payload.ApiJsonPayloadResolver;
import com.hrsk.cloud.eg.domain.api.resolver.payload.ApiPayloadResolver;
import lombok.extern.slf4j.Slf4j;

import java.util.Map;

/**
 * @author: bianlanzhou
 * @create: 2024-08-01 17:38
 * @description: api payload 管理器
 **/
@Slf4j
public class ApiResultResolverManage {
    /**
     * PAYLOAD MAP
     */
    private static final Map<String, ApiResultResolver> RESOLVER_MAP = Maps.newHashMap();
    /**
     * INSTANCE
     */
    private static final ApiResultResolverManage INSTANCE = new ApiResultResolverManage();

    static {
        regist();
    }

    private ApiResultResolverManage(){}

    /**
     * 获取实例
     * @return 实例
     */
    public static ApiResultResolverManage getInstance(){
        return INSTANCE;
    }


    /**
     * 解析
     * @param code 编码
     * @param apiResult
     * @return 解析结果
     */
    public Object resolve(String code, String template, Map<String,Object> apiResult){
        return RESOLVER_MAP.get(code).resolve(template,apiResult);
    }
    /**
     * 注册
     */
    private static void regist(){
        log.info("开始注册Payload解析器!");
        RESOLVER_MAP.put(ApiPayloadTypeEnum.APPLICATION_JSON.getCode(),new ApiJsonResultResolver());
        RESOLVER_MAP.put(ApiPayloadTypeEnum.APPLICATION_X_WWW_FORM_URLENCODED.getCode(),new ApiJsonResultResolver());

    }
}
