package com.hrsk.cloud.eg.infrastructure.exception;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.domain.common.constant.ResultCode;
import com.hrsk.pangu.dto.SingleResponse;
import lombok.extern.slf4j.Slf4j;
import org.springframework.boot.context.properties.bind.BindException;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.http.converter.HttpMessageNotReadableException;
import org.springframework.web.HttpRequestMethodNotSupportedException;
import org.springframework.web.bind.MethodArgumentNotValidException;
import org.springframework.web.bind.ServletRequestBindingException;
import org.springframework.web.bind.annotation.ControllerAdvice;
import org.springframework.web.bind.annotation.ExceptionHandler;
import javax.validation.ConstraintViolationException;


/**
 * 全局异常处理器
 */
@ControllerAdvice
@Slf4j
public class ExceptionAdvice {

    /**
     * 捕捉mvc handler 下的异常
     * @param exception
     * @return
     */
    @ExceptionHandler(Exception.class)
    public ResponseEntity<SingleResponse> exception(Exception exception) {
        ResponseEntity<SingleResponse> springResponse = handleSpringException(exception);
        if (springResponse != null) {
            return springResponse;
        }

        if (exception instanceof IllegalArgumentException) {
            return ResponseEntity.ok(fail(ResultCode.GLOBAL_REQUEST_FAIL.getCode(), exception.getMessage()));
        }
        if (exception instanceof BindException) {
            return ResponseEntity.ok(fail(ResultCode.GLOBAL_REQUEST_FAIL.getCode(), exception.getMessage()));
        }
        if (exception instanceof ConstraintViolationException) {
            return ResponseEntity.ok(fail(ResultCode.GLOBAL_REQUEST_FAIL.getCode(), exception.getMessage()));
        }
        if (exception instanceof BindException) {
//            BindException bizException = (BindException) exception;
            return ResponseEntity.ok(fail(ResultCode.GLOBAL_REQUEST_FAIL.getCode(), ResultCode.GLOBAL_REQUEST_FAIL.getMsg()));
        }
        if (exception instanceof MethodArgumentNotValidException) {
            MethodArgumentNotValidException bindException = (MethodArgumentNotValidException) exception;
            return ResponseEntity.ok(fail(400, bindException.getBindingResult().getFieldError().getDefaultMessage()));
        }
        log.error("全局未知异常,异常信息：{}", exception.getMessage(), exception);
        return ResponseEntity.status(HttpStatus.INTERNAL_SERVER_ERROR).body(fail(500, exception.getMessage()));
    }

    private ResponseEntity<SingleResponse> handleSpringException(Exception exception) {
        if (exception instanceof ServletRequestBindingException) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).body(fail(404,exception.getMessage()));
        }
        if (exception instanceof HttpRequestMethodNotSupportedException) {
            return ResponseEntity.status(HttpStatus.METHOD_NOT_ALLOWED).body(fail(405,exception.getMessage()));
        }
        if (exception instanceof HttpMessageNotReadableException) {
            return ResponseEntity.status(HttpStatus.BAD_REQUEST).body(fail(406,exception.getMessage()));
        }
        return null;
    }

    /** 
     * @description:  简单的构建错误信息
     * @param:  
     * @return:  
     * @author zhangyy
     * @date: 2024/11/11 10:50
     */ 
    private SingleResponse fail(Integer code,String msg){
            SingleResponse result = new SingleResponse<>();
            result.setSuccess(false);
            JSONObject data = new JSONObject();
            data.put("code",code);
            data.put("msg",msg);
            result.setData(data);
           return result;
    }
}