package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgLoanApiConfigInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.Instant;
import java.util.*;

/**
 * @Author Liu Tao
 * @Date 2023 11 09 09 49
 **/
@Service
@Slf4j
public class AnHuiHengDaoCreditService implements LoanDockingApi {

    @Resource
     private RetryRestTemplate httpRestTemplate;

    @Resource
    private EgApiService egApiService;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.AnHuiHengDao;
    }

    @Data
    private static class CheckInfo{
        private String timeStamp;//时间戳：1627538679006
        private String orderNo;//订单号（不可重复，一般是标识加上时间戳）
        private String sign;//签名（MD5(data&orderNo&timeStamp&token)）
        private String data;//手机号码MD5值（32位小写)
    }

    @Data
    public static class CheckData{
        private String clientname;
        private String phone;
        private String remarks;
        private String channelId;
    }
    @Data
    public static class ApplyInfoData{
        private String loanLimit;//贷款期限
        private String car;
        private String house;
        private String socialSecurity;
        private String reservedFunds;
        private String insurance;
        private String creditCard;//
        private String zhima;//
    }
    @Data
    private static class ApplyInfo {
        private String timeStamp; //时间戳：1627538679006
        private String orderNo; //订单号（不可重复，一般是标识加上时间戳）
        private String sign; //签名（MD5(data&orderNo&timeStamp&token)）
        private String data; //数据信息（json类型的字符串，该字段需要aes加密，{"clientname":"客户名称", "phone":"电话 必填", "remarks":"备注 客户详细信息", "channelId":1 // 来源必填，需要申请}）
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd    configInfo) {
        try {
            log.info("credit AnHuiHengDaoCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
           
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());

            log.info("安徽恒道对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setData(phoneMd5);
            String millisecondsSinceEpoch = String.valueOf(Instant.now().toEpochMilli());
            checkInfo.setTimeStamp(millisecondsSinceEpoch);//当前时间搓
            checkInfo.setOrderNo(config.getString("channel")+millisecondsSinceEpoch);//订单号
                //实体类转为JSONObject
            JSONObject jsons = JSONObject.parseObject(JSON.toJSONString(checkInfo));
            jsons.remove("sign");
            String sign = getSign(jsons,config.getString("key"));
            checkInfo.setSign(Md5Util.encoderByMd5(sign));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck AnHuiHengDaoCreditService request userId:{}, url:{}, checkInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("安徽恒道准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck AnHuiHengDaoCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanName());
            }
            if (jsonObject.getString("code").equals("000")) {
                return DataVo.success(0, product.getPlanId()+"安徽恒道撞库成功");
            } else {
                return DataVo.fail("安徽恒道撞库失败");
            }
        } catch (Exception e) {
            log.error("安徽恒道撞库失败", e);
            return DataVo.fail("安徽恒道撞库失败");
        }

    }

    private String getSign(JSONObject params, String key) {
            String sortStr = getFormatParams(params);
            System.out.println("sortStr = " + sortStr);
            //第二步：将tradeKey拼接在1中排序后的字符串后面得到待签名字符串。
            sortStr += "&"+ key;
            System.out.println("sortStr = " + sortStr);
            //sortStr += "key=BF1BDE5A649724056F904A9335B1C1C9";
            //第三步：使用md5算法加密待加密字符串并转为大写即为sign
//        String sign = DigestUtils.md5DigestAsHex(sortStr.getBytes()).toUpperCase();
//        System.out.println("sign = " + sign);
            return sortStr;
        }
    /**
     * 字典排序
     * 获得参数格式化字符串
     * 参数名按字典排序，小写在后面
     */
    private static String getFormatParams(Map<String, Object> params) {
        List<Map.Entry<String, Object>> infoIds = new ArrayList<Map.Entry<String, Object>>(params.entrySet());
        Collections.sort(infoIds, new Comparator<Map.Entry<String, Object>>() {
            public int compare(Map.Entry<String, Object> arg0, Map.Entry<String, Object> arg1) {
                return (arg0.getKey()).compareTo(arg1.getKey());
            }
        });
        String ret = "";
        for (Map.Entry<String, Object> entry : infoIds) {
            ret += entry.getValue();
            ret += "&";
        }
        ret = ret.substring(0, ret.length() - 1);
        return ret;
    }

}
