package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgLoanApiConfigInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.DateUtil;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.BadPaddingException;
import javax.crypto.Cipher;
import javax.crypto.IllegalBlockSizeException;
import javax.crypto.NoSuchPaddingException;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.io.UnsupportedEncodingException;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;
import java.util.Date;

/**
 * @Author zjc
 * @Date 2024 04 17 16 08
 **/
@Slf4j
@Service
public class BaiXinShunTaiCreditService implements LoanDockingApi {
    public static String code = "UTF-8";
    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Resource
    private EgApiService egApiService;

    //撞库
    @Data
    private static class CheckInfo {
        private String phoneNo;//md5 的手机号

    }

    @Data
    private static class RquestParam {
        private String data;
        private String merchantNo;
        private String timestamp;
        private String reqId;

    }

    //进件
    @Data
    private static class ApplyInfo {
        private String custName;//客户姓名
        private String city; //城市
        private String cityCode;//城市行政区划代码
        private String phoneNo; //手机号
        private Integer sex; //性别 0:男:1女
        private String age; //年龄
        private String loanAmount;//客户借款额度 0-3万：1 ,3-5万：2 ,5-10万：3 ,10-20万：4 ,20万以上：5
        private String profession;//职业身份
        private String salaryType;//工资情况
        private String socialSecurity; //社保0无 6个月以下1 6个月以上2
        private String providentFund; //公积金 0无 6个月以下1 6个月以上2
        private String car; //车产 0没有 1有按揭车 2有全款车
        private String estate; //房产    无房	0 有按揭商品房	1 有全款商品房	2
        private String creditCardLimit; //信用卡 0没有 1.3000元以下 2.3000-5000元 3.5000-10000元 4.10000元以上
        private String zhiMaScore;//芝麻分
        private String lifeInsurance; //保单0无1有
        private String monthIncome; //月收入
        private String degree; //学历 1 高中及以下	2 大专	3 本科及以上
        private String loanTerm;//借款周期 01:一年以内 02：1-3年 03：3年上
        private Integer company_id;//公司编码
        private String promotion_prefix;//渠道名

    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit QingDaoBaiXinShunTaiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("青岛佰信顺泰对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneNo(phoneMd5);
            RquestParam requestParam=new RquestParam();
            requestParam.setTimestamp(DateUtil.getFormatDate(new Date(), "yyyy-MM-dd HH:mm:ss"));
            requestParam.setData(encryptAes(JSON.toJSONString(checkInfo), config.getString("key")));
            requestParam.setReqId(config.getString("reqId"));
            requestParam.setMerchantNo(config.getString("merchantNo"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck QingDaoBaiXinShunTaiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, phoneMd5);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, requestParam, String.class);
            } catch (Exception e) {
                log.error("青岛佰信顺泰准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck QingDaoBaiXinShunTaiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanName());
            }
            if (jsonObject.getString("dealStatus").equals("0000")) {
                return  DataVo.success(0,product.getPlanId()+"青岛佰信顺泰撞库成功");
            } else {
                return DataVo.fail("青岛佰信顺泰撞库失败，请联系系统管理员");
            }
        } catch (Exception e) {
            log.error("青岛佰信顺泰撞库失败", e);
            return DataVo.fail("青岛佰信顺泰撞库失败，请联系系统管理员");
        }
    }

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.QingDaoBaiXinSHunTaiCreditService;
    }


    public static String encryptAes(String data, String secretKey) {
        try {
            byte[] encrpyted = tripleAes(Cipher.ENCRYPT_MODE, data.getBytes(code), secretKey.getBytes());
            byte[] encoded = Base64.encodeBase64(encrpyted); // Base64 编码
            return new String(encoded);
        } catch (UnsupportedEncodingException e) {
            throw new RuntimeException(e);
        }
    }

    private static byte[] cipherAes(String algorithm, String transformation, int opmode, byte[] data, byte[] iv, byte[] secretKey) {
        try {
            Cipher cipher = Cipher.getInstance(transformation);
            SecretKeySpec keyspec = new SecretKeySpec(secretKey, algorithm);
            IvParameterSpec ivspec = new IvParameterSpec(iv);  // CBC模式，需要一个向量iv，可增加加密算法的强度

            cipher.init(Cipher.ENCRYPT_MODE, keyspec, ivspec);
            byte[] encrypted = cipher.doFinal(data);
            return encrypted;
        } catch (InvalidKeyException | NoSuchAlgorithmException
                 | NoSuchPaddingException
                 | IllegalBlockSizeException | BadPaddingException |
                 InvalidAlgorithmParameterException e) {
            throw new RuntimeException(e);
        }
    }

    private static byte[] tripleAes(int opmode, byte[] data, byte[] secretKey) {
        return cipherAes("AES", "AES/CBC/PKCS5Padding", opmode, data, "dxjf18129979469s".getBytes(), secretKey);
    }
}




