package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;

/**
 * @Author Liu Tao
 * @Date 2023 11 29 15 59
 **/
@Slf4j
@Service
public class BeiJingChongHeCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.BeiJingChongHe;
    }

    @Data
    private static class CheckInfo{
        private Integer channel_code;//渠道编码
        private String channel_secret_key;//渠道密钥
        private String md5_phone;//md5加密后的手机号，32位小写
    }


    @Data
    private static class ApplyInfo{
        private Integer channel_code;

        private String phone;

        private String name;

        private Integer sex;

        private Integer age;

        private Integer quota;

        private Integer house;

        private Integer car;

        private Integer social_security;

        private Integer pay_taxes;

        private Integer credit_card;

        private Integer business_license;

        private Integer micro_loan;

        private Integer accumulation_fund;

        private Integer insurance_policy;

        private Integer marriage;

        private String accumulation_fund_area;

        private Integer accumulation_fund_term;

        private Integer accumulation_fund_count_quota;

        private Integer accumulation_fund_month_quota;

        private String work_unit;

        private Integer purchase_method;

        private Integer car_full_payment_quota;

        private Integer car_present_price;

        private Integer car_service_life;

        private String vehicle_license_plate;

        private String car_remark_info;

        private String hava_issued;

        private Integer issued_type;

        private String issued_info;

        private Integer house_situation;

        private Integer total_price;

        private String house_region;

        private Integer house_area;

        private Integer month_repayment;

        private Integer house_present_price;

        private String insurance_company;

        private String insurance_type;

        private Integer insurance_quota;

        private Integer insurance_years;

        private String insurance_remark;

        private Integer credit_card_count;

        private Integer credit_card_count_quota;

        private Integer credit_card_used_quota;

        private String credit_card_remark;

        private Integer hava_credit_loan;

        private Integer credit_loan_count_quota;

        private Integer credit_loan_balance;

        private Integer credit_loan_month_repayment;

        private String credit_loan_remark;

        private Integer housing_loan_quota;

        private String id_card;

        private Integer annual_income;

        private Integer professional_identity;

    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channel_code":"34","checkUrl":"http://120.46.41.14:8888/api/customer/collisionLibrary","channel_secret_key":"HrYk20230829KYR6"}
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit BeiJingChongHeCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("北京重和对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setMd5_phone((userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5()));
            checkInfo.setChannel_code(Integer.valueOf(config.getString("channel_code")));
            checkInfo.setChannel_secret_key(config.getString("channel_secret_key"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck BeiJingChongHeCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("北京重和准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck BeiJingChongHeCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 0) {
                return DataVo.success("北京重和撞库成功",product.getPlanId());
            } else {
                return DataVo.fail("北京重和撞库成功",product.getPlanId());
            }
        } catch (Exception e) {
            log.error("北京重和撞库失败", e);
            return DataVo.fail("北京重和撞库成功",product.getPlanId());
        }

    }


    private static class ApiAesUtil {
        public static String Encrypt(String sSrc, String sKey) throws Exception {
            if (sKey == null) {
                System.out.print("Key为空null");
                return null;
            }
            if (sKey.length() != 16) {
                System.out.print("Key长度不是16位");
                return null;
            }
            byte[] raw = sKey.getBytes("utf-8");
            SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
            Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");//"算法/模式/补码方式"
            cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
            byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));

            return Base64.encodeBase64String(encrypted);//此处使用BASE64做转码功能，同时能起到2次加密的作用。
        }

        public static String Decrypt(String sSrc, String sKey) throws Exception {
            try {
                if (sKey == null) {
                    System.out.print("Key为空null");
                    return null;
                }
                if (sKey.length() != 16) {
                    System.out.print("Key长度不是16位");
                    return null;
                }
                byte[] raw = sKey.getBytes("utf-8");
                SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
                Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
                cipher.init(Cipher.DECRYPT_MODE, skeySpec);
                byte[] encrypted1 = Base64.decodeBase64(sSrc);//先用base64解密
                try {
                    byte[] original = cipher.doFinal(encrypted1);
                    String originalString = new String(original,"utf-8");
                    return originalString;
                } catch (Exception e) {
                    System.out.println(e.toString());
                    return null;
                }
            } catch (Exception ex) {
                System.out.println(ex.toString());
                return null;
            }
        }

    }

}
