package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * @Author zjc
 * @Date 2024 07 09 16 36
 **/
@Slf4j
@Component
public class CangZhouSuYiRonogCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.CangZhouSuYiRong;
    }

    @Data
    private static class CheckInfo{
        private String mobile;//md5加密后的手机号，32位小写
    }


    @Data
    private static class ApplyInfo {
        private String promotion;//订单id
        private String name;//姓名
        private String mobile;//手机号码
        private Integer age;//年龄
        private Integer sex;//性别 （1男 2女）
        private String city;//城市
        private Integer is_house;//是否有房
        private Integer is_car;//是否有车
        private Integer is_company;//是否有车
        private Integer is_credit;//是否信用卡
        private Integer is_insurance;//是否有商业保险
        private Integer is_social;//是否有社保
        private Integer is_fund;//是否有公积金
        private Integer is_work;//是打卡工资
        private Integer is_tax;//是否有营业税
        private Integer webank;//是否有微粒贷
        private String money_demand;//贷款金额 万
        private String content;

    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit CangZhouSuYiRongCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("沧州速易融对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobile(phoneMd5);

            JSONObject json=new JSONObject();
            json.put("mobile",checkInfo.getMobile());
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck CangZhouSuYiRongCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,json, String.class);
            }catch (Exception e){
                log.error("沧州速易融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck CangZhouSuYiRongCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            if (jsonObject.getInteger("code") ==0 ) {

                return DataVo.success(0, "沧州速易融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "沧州速易融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("沧州速易融撞库失败", e);
            return  DataVo.fail( "沧州速易融撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
