package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Base64;


/**
 * @Author Liu Tao
 * @Date 2024 01 02 14 09
 **/
@Service
@Slf4j
public class ChengHongHuiCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ChengHongHui;
    }

    @Data
    private static class CheckInfo{
        private String tel;//手机号码md5(32位，字母小写)
    }


    @Data
    private static class ApplyInfo{
        private Integer source_id;//渠道号(我方分配)
        private String source_name;//渠道名称(中文)
        private String name;//客户姓名
        private String mobile;//手机号
        private String city;//城市(不包含市，比如“杭州市”应该是“杭州”)
        private String zhimafen;//芝麻分
        private String wld;//微粒贷
        private String baitiao_amount;//白条额度
        private String huabei_amount;//花呗额度
        private String car;//车
        private Integer age;//年龄(如：39)
        private String job;//工作
        private Integer job_type;//职业 1:自由职业 2:上班族 3:个体户 4:企业主 5:无固定职业
        private Integer monthly_income;//月收入(单位:元)
        private String house;//房
        private String baodan_is;//保单
        private String sex;//性别(“男”或“女”)
        private Integer money;//贷款额度(如：20，即单位为万)
        private String shebao;//社保
        private String gongjijin;//公积金
        private String isbankpay;//银行代发
        private String ip;//客户实际申请IP
        private String credit_card;//信用卡
        private Integer time;//该条数据实际申请时间（10位数字，如：1467100609）
        private Integer education;//学历 1：高中及以下 2：专科 3：本科 4：硕士 5:博士及以上
        private String use_remark;//贷款用途
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
//            log.info("credit ChengHongHuiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
//            log.info("晨宏汇对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setTel((userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5()));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck ChengHongHuiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            } catch (Exception e) {
                log.error("晨宏汇准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ChengHongHuiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
//            log.info("credit qualityCheck ChengHongHuiCreditService response userId:{}, jsonObject:{}", userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("resStatus").equals("1")) {
                return DataVo.success(0, "晨宏汇撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "晨宏汇撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("晨宏汇撞库失败", e);
            return DataVo.fail(1, "晨宏汇撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    public static String encrypt(String plainText, String key, String iv) throws Exception {
        // 将 key 转换为 SecretKey 对象
        SecretKey secretKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
        // 将 IV 字符串转换为字节数组
        byte[] ivBytes = iv.getBytes(StandardCharsets.UTF_8);
        // 生成 IV
        // 创建 Cipher 对象
        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
        cipher.init(Cipher.ENCRYPT_MODE, secretKey, new IvParameterSpec(ivBytes));
        // 加密明文
        byte[] encryptedBytes = cipher.doFinal(plainText.getBytes(StandardCharsets.UTF_8));
        // 将加密后的字节转换为 Base64 编码
        return Base64.getEncoder().encodeToString(encryptedBytes);
    }

}
