package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Base64;

/**
 * @Author Liu Tao
 * @Date 2024 05 07 10 38
 **/
@Slf4j
@Component
public class ChongQinDongRunCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;




    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ChongQinDongRunCreditService;
    }

    @Data
    private static class CheckInfo {
        private String sourceCode;// 渠道标识
        private String accessKey;// 渠道访问密钥
        private String phoneMd5;// 手机号MD5
    }

    @Data
    private static class ApplyInfo {
        private String realName;//姓名
        private Integer age; //年龄
        private String phone; //手机号
        private String sex; //性别
        private String city;//城市
        private Integer profession;//职业
        private Integer payoffType;//工资发放形式
        private String idcard;//身份证号码
        private Integer sesameScore;//芝麻分
        private Integer loanMoney;//借款金额（单位：万元）
        private Integer loanExpiresMonth;//借款期限
        private Integer loanUse; //借款用途
        private Integer gjjScop; //公积金
        private Integer sbScop; //社保
        private String incomeMonth;//月收入
        private Integer house;//名下房产
        private Integer car;//车产情况
        private Integer baodanScop;//保单范围
        private Integer credit;//信用情况
        private Integer isLoans;//微粒贷
        private Integer manageYears;//经营年限
        private Integer turnover;//总经营流水
        private Integer turnoverPublic;//对公账户经营收入
        private Integer workingYears;//当前单位工龄 int workingYears
        private Integer registAddress;//经营注册地
        private Integer hasBusinessLicense;//是否办理过营业执照
        private Integer education;//学历
        private Integer creditCard;//信用卡
        private Integer remarks;//备注

    }

    @Data
    private static class RequestData{
        private String sourceCode;// 渠道标识
        private String accessKey;// 渠道访问密钥
        private String dataStr;// 加密后参数
    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit ChongQinDongRunCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("重庆东润对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setAccessKey(config.getString("AccessKey"));
            checkInfo.setSourceCode(config.getString("SourceCode"));
            checkInfo.setPhoneMd5(phoneMd5);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck ChongQinDongRunCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, phoneMd5);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, String.class);
            } catch (Exception e) {
                log.error("重庆东润准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ChongQinDongRunCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            JSONObject data =JSONObject.parseObject(jsonObject.getString("data"));
            if (jsonObject.getString("code").equals("1")&&data.getBoolean("phoneMd5Exist")!=null&&!data.getBoolean("phoneMd5Exist")) {
                return DataVo.success (0, "重庆东润撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "重庆东润撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "重庆东润撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    public static String encrypt(String plainText, String key, String iv)  {
        try {
            // 将 key 转换为 SecretKey 对象
            SecretKey secretKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
            // 将 IV 字符串转换为字节数组
            byte[] ivBytes = iv.getBytes(StandardCharsets.UTF_8);
            // 生成 IV
            // 创建 Cipher 对象
            Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
            cipher.init(Cipher.ENCRYPT_MODE, secretKey, new IvParameterSpec(ivBytes));
            // 加密明文
            byte[] encryptedBytes = cipher.doFinal(plainText.getBytes(StandardCharsets.UTF_8));
            // 将加密后的字节转换为 Base64 编码
            return Base64.getEncoder().encodeToString(encryptedBytes);
        } catch (Exception e) {
            return "";
        }

    }


}
