package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.SecretKeyFactory;
import javax.crypto.spec.DESedeKeySpec;
import javax.crypto.spec.IvParameterSpec;
import java.nio.charset.StandardCharsets;
import java.security.Key;

/**
 * @Author Liu Tao
 * @Date 2023 11 08 10 29
 **/
@Slf4j
@Service
public class ChongQingRuiShangXinCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ChongQingRuiShuangXin;
    }

    @Data
    private static class CheckInfo{
        private String mobileEncrypt;//手机号MD5加密32位小写字符串
        private String appid;//数据标识，接收方提供
    }
    @Data
    private static class ApplyInfo{
        private String appid; //数据标识，接收方提供
        private String name; //姓名
        private String mobile; //手机号
        private String cardNo; //身份证
        private Integer gender; //性别; 0-女 1-男
        private String city; //城市（格式：xx市）
        private Integer amount; //申请金额(万)
        private String period; //申请期限(月)
        private Integer monthlyIncome; //月收入(元)
        private Integer age; //年龄(18-99)
        private Integer houseType; //房产; 0-无 1-有
        private Integer carType; //车产; 0-无 1-有
        private Integer socialInsurance; //社保; 0-无 1-有
        private Integer commercialInsurance; //	商业保险; 0-无 1-有
        private Integer accumulationFund; //公积金; 0-无 1-有
        private Integer entrepreneur; //是否企业主; 0-否 1-是
        private String credit; //信用情况
        private String zhima; //芝麻分
        private String additional; //其他信息
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
    {
    "checkUrl": "https://rsx.icl-network.com/api/data/common/check",
    "applyUrl": "https://rsx.icl-network.com/api/data/common/encrypt_push",
    "appid": "SQVEySSsMKOTialcatYIDtWmvFzwkcJM",
    "key": "xj9pgn0n972cd2wy0u5s88gz",
    "iv": "18521959"
    }
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit ChongQingRuiShangXinCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("重庆睿双鑫对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobileEncrypt(phoneMd5);
            checkInfo.setAppid(config.getString("appid"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck ChongQingRuiShangXinCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("重庆睿双鑫准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ChongQingRuiShangXinCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getApiId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getApiId(),product.getPlanName());
            }
            if (jsonObject.getString("code").equals("200")) {
                return DataVo.success(0, "重庆睿双鑫撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "重庆睿双鑫撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("重庆睿双鑫撞库失败", e);
            return DataVo.fail(1, "重庆睿双鑫撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


//3DES算法key，iv
    public static String encrypt(String data,String key,String iv) throws Exception {
        byte[] encrpyted = tripleDES(Cipher.ENCRYPT_MODE,data.getBytes(StandardCharsets.UTF_8), key.getBytes(),iv.getBytes());
        return new String(Base64.encodeBase64(encrpyted));
    }

    private static byte[] tripleDES(int opmode, byte[] data, byte[] secretKey,byte[] iv) throws
            Exception {
        return cipher("DESede", "DESede/CBC/PKCS5Padding", opmode, data, iv, secretKey);
    }

    private static byte[] cipher(String algorithm, String transformation, int opmode, byte[] data, byte[] iv, byte[] secretKey) throws Exception {
        Key key = SecretKeyFactory.getInstance(algorithm).generateSecret(new
                DESedeKeySpec(secretKey));
        IvParameterSpec spec = new IvParameterSpec(iv);
        Cipher cipher = Cipher.getInstance(transformation);
        cipher.init(opmode, key, spec);
        return cipher.doFinal(data);
    }
}
