package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;


import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/2/6
 * @Version V1.0
 **/
@Service
@Slf4j
public class ChuanjinCreditService implements LoanDockingApi {

    private final static String qualityCheckPath = "customers/check/MD5Encrypt";
    private final static String applyPath = "customers";

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ChuanJin;
    }
    @Data
    private static class CheckInfo {
        private String phone_encrypt;

        private String company_id;
    }

    @Data
    private static class ResResult {
        private Integer data;

        private Integer code;

        private String msg;
    }

    @Data
    private static class ApplyInfo {
        private String name;
        private String phone;
        private String gender;
        private Integer age;
        private Integer limit;
        //        private String income_year;
        private String provider_code;
        private String education;
        private String career;
        private String company_id;
    }


    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit ChuanjinCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
           
            Object requestConfig = HessianUtils.deserialize(configInfo.getRequestConfig()) ;
            JSONObject config = JSONObject.parseObject(requestConfig.toString());
            log.info("川金对接参数:{}", JSON.toJSONString(config));
            String url = config.getString("url") + qualityCheckPath;
            ResResult response = null;
            try {

                url = url + "?phone_encrypt=" + userInfo.getUserMobileMD5() + "&company_id=" + config.getString("channelSource");
                log.info("credit qualityCheck ChuanjinCreditService request userId:{}, url:{}", userInfo.getUserId(), url);
                response = httpRestTemplate.restTemplate().postForObject(url, null, ResResult.class);
            } catch (Exception e) {
                log.error("川金准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ChuanjinCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return Objects.equals(0, response.getData()) ? DataVo.success(0, "川金撞库成功", product.getPlanId())
                    : DataVo.fail(1, response.getMsg(), product.getPlanId());

        } catch (Exception e) {
            log.error("川金撞库失败", e);
            return DataVo.fail(1, "川金撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
