package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2024 06 24 10 58
 **/
@Slf4j
@Service
public class DeLuoXuanAesCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.DeLuoXuanAES;
    }
    @Data
    private static class CheckInfo{
        private String md5Phone;// 手机号md5
        private Integer company_id;//公司编号
    }
    @Data
    private static class ApplyInfo{
        private String username;//姓名：xxx
        private String phone; //手机号
        private String city; //城市
        private Integer loan; //贷款金额
        private Integer price;//放款金额
        private String content; //备注
        private Integer gjj; //1-有公积金；2-无公积金
        private String company; //工作单位
        private Integer ispayroll;//1-有代发：2-无代发
        private Integer house; //房产：1-本地房；2-无；3-外地房
        private Integer car; //1-有车；2-无车
        private Integer insurance; //保单：1-有 2-无
        private Integer xyk;//信用卡 0-无 1-有
        private Integer credit_loan; //信用贷款 1-无 2-有
        private Integer shebao; //社保 1-有 -2无
        private Integer pay_tax; //企业纳税 1-有 2-无
        private Integer particles;//微粒贷 1-有 2-无
        private Integer business_license;//营业执照 0-无 1-有
        private Integer write_id;//无
        private Integer sex;//性别 0-男 1-女
        private Integer age;//年龄
        private Integer job;//0自由职业1企业主2白领3公务员
        private Integer degree;//1-高中以下 2-专科 3-本科及以上
        private String source;//渠道名（平台提供）
        private Integer platform_id;//不需要回传值为 0，回传必传（平台提供）
    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit DeLuoXuanAesCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("德诺轩AES对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setMd5Phone(phoneMd5);
            checkInfo.setCompany_id(config.getInteger("company_id"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck DeLuoXuanAesCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, phoneMd5);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("德诺轩AES准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck DeLuoXuanAesCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code")==0) {
                return DataVo.success(0, "德诺轩AES撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "德诺轩AES撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("德诺轩AES撞库失败", e);
            return DataVo.fail(1, "德诺轩AES撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
