package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2023 10 09 16 18
 *  德州鑫易融API
 **/
@Slf4j
@Service
public class DeZhouXinYiRongCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.DeZhouXinYiRong;
    }

    @Data
    private static class CheckInfo{
        private String mobile;//md5 的手机号
        private String wxapp_id;//公司id
    }

    @Data
    private static class ApplyInfo{
        private Integer wxapp_id; //公司ID 是

        private Integer channel_id; //渠道ID,否

        private String name; //客户姓名 是

        private String mobile;//手机号码 是

        private Integer loans_price; //贷款金额，否

        private Integer age;//年龄

        private Integer sex; //性别(1:为男,2为女)

        private Integer property;//名下房产 1：本地房 2：外地房 3：无房

        private Integer vehicle;//	名下车 1：有 2：无

        private Integer guarantee;//保单 1：有 2：无

        private Integer drop;//代发 1：有 2：无

        private Integer credit_card;//信用卡 1：有 2：无

        private Integer social;//社保 1：有 2：无

        private Integer fund;//公积金 1：有 2：无
    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd    configInfo)  {
        try {
            log.info("credit DeZhouXinYiRongCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("德州鑫易融对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobile(phoneMd5);
            checkInfo.setWxapp_id(config.getString("wxapp_id"));
            String url=config.getString("http")+config.getString("index")+config.getString("parameter1")+config.getString("parameter2")+config.getString("parameter3")+config.getString("checkParmeter");
            log.info("credit qualityCheck DeZhouXinYiRongCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("德州鑫易融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck DeZhouXinYiRongCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 0) {
                return DataVo.success(0, "德州鑫易融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "德州鑫易融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("德州鑫易融撞库失败", e);
            return DataVo.fail(1, "德州鑫易融撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


}
