package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2023 10 16 10 44
 * 德州鑫易融V2API
 **/
@Slf4j
@Service
public class DeZhouXinYiRongV2CreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.DeZhouXinYiRongV2;
    }

    @Data
    private static class CheckInfo{
        private String mobile_md5;//md5 的手机号
    }

    @Data
    private static class ApplyInfo{
        private String name; //姓名

        private String mobile; //11位手机号

        private Integer sex; //性别 （1男 2女）

        private Integer loan_limit;//额度 (比如: 100000，单位：元）

        private Integer room; //是否有房产（1：有  0：无）

        private Integer car;//是否有车产（ 1：有  0：无)

        private Integer accumulation; //是否有公积金 ( 1：有  0：无)

        private Integer social;//是否有社保 ( 1：有  0：无 )

        private Integer policy;//是否有保单 (  1：有  0：无 )

        private Integer business;//是否有营业执照 ( 1：有  0：无 )

        private Integer issued;//是否有打卡工资 ( 1：有  0：无 )

        private Integer enterprise;//是否有企业纳税 (  1：有  0：无 )

    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit DeZhouXinYiRongV2CreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("德州鑫易融V2对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobile_md5(phoneMd5);
            String url=config.getString("checkUrl")+"?company="+config.getString("company")+"&mobile_md5="+checkInfo.getMobile_md5();
            log.info("credit qualityCheck DeZhouXinYiRongV2CreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("德州鑫易融V2准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck DeZhouXinYiRongV2CreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 0) {
                return DataVo.success(0, "德州鑫易融V2撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "德州鑫易融V2撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("德州鑫易融V2撞库失败", e);
            return DataVo.fail(1, "德州鑫易融V2撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
