package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 放心网API接单
 */
@Service
@Slf4j
public class FangxinwangiCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final String qualityCheckPath = "/api/VenderExists/Post";

    private final String applyPath = "/api/Venders/Save";


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Fangxinwang;
    }

    @Data
    private static class CheckInfo{
        private String phone;
    }
    @Data
    private static class ResultHt{
        private Integer code;
        private String msg;
    }
    @Data
    private static class ApplyInfo{

        String channeld;
        String name;
        String phoneNumber;
        Integer sex;
        int age;
        String city;
        int loanAmount;
        int house;
        int car;
        int houseFund;
        int socialInsurance;
        int lifeInsurance;
        String vender = "惠融易客";
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit FangxinwangCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());

            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject fangxinwangJointDTO = JSON.parseObject(configJson);
            log.info("放心网对接参数:{}", JSON.toJSONString(fangxinwangJointDTO));
            String url = fangxinwangJointDTO.getString("url") + qualityCheckPath;
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhone(userInfo.getUserMobile() != null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5());
            String requestBody = JSON.toJSONString(checkInfo);
            log.info("credit qualityCheck FangxinwangCreditService request userId:{},requestBody:{}",userInfo.getUserId(), url,requestBody);
            ResultHt response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/json");
                HttpResponse httpResponse = httpRestTemplate.restTemplate().postForObject(url, null, null, head, null, requestBody);
                String responseStr = EntityUtils.toString(httpResponse.getEntity());
                response = JSONObject.parseObject(responseStr,ResultHt.class);
            }catch (Exception e){
                log.error("放心网准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck FangxinwangCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return Objects.equals(0, response.getCode()) ? DataVo.success(0, "放心网撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());
        } catch (Exception e) {
            log.error("放心网撞库失败", e);
            return DataVo.fail(1, "放心网撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


    private void wrapSex(ApplyInfo applyInfoApi, String policeSex) {
        int sex = 0;
        switch (policeSex){
            case "男":
                sex = 1;
                break;
            case "女":
                sex = 2;
                break;
            default:
                sex = 0;
        }
        applyInfoApi.setSex(sex);
    }


}
