package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONArray;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;

import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2024 06 25 14 48
 **/
@Slf4j
@Service
public class FuZhouBeiJiuCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.FuZhouBeiJiu;
    }

    @Data
    private static class ApplyInfo {
        private String name; //（必填）客户姓名
        private String phone; //客户电话
        private String quota; //额度
        private String city; //0（0：福州，1：泉州）
        private String forCondition; //跟进条件 车房公积金等数据
        private String source; //来源.配置为2
    }


    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd    configInfo)  {
        try {
            log.info("credit FuZhouBeiJiuCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("福州北久对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            JSONArray jsonArray = new JSONArray();
            jsonArray.add(phoneMd5);
            JSONObject json = new JSONObject(){{
                put("data", jsonArray);
            }};
            log.info("credit qualityCheck FuZhouBeiJiuCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, json);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, json, String.class);
            } catch (Exception e) {
                log.error("福州北久准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck FuZhouBeiJiuCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("result").equals("success")) {
                return DataVo.success(0, "福州北久撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "福州北久撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("福州北久撞库失败", e);
            return DataVo.fail(1, "福州北久撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
