package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2023 11 06 11 58
 **/
@Slf4j
@Service
public class FuZhouBeiYinJinRongCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.FuZhouBeiYinJinRong;
    }

    @Data
    private static class CheckInfo{
        private String phone;//md5 的手机号
        private String channelCode;//渠道号
    }

    @Data
    private static class ApplyInfo{
        private String channelCode;//渠道编号
        private String phone;//手机号（RSA加密后）
        private String idCardNo;//否，身份证号码(RSA加密后)
        private String name;//姓名(RSA加密后)
        private Integer loanAmount;//贷款额度/单位:万元
        private String loanLimit;//借款期限 1.1个月 2.3个月 3.6个月 4.9个月 5.12个月 6.24个月 7.36个月 8.36个月以上
        private String loanUse;//借款用途 1.购车贷款 2.购房贷款 3.装修贷款 4.教育贷款 5.消费贷款 6.过桥贷款 7.结婚贷款 8.旅游贷款 9.医疗贷款 10.其他贷款
        private String sex;//性别 1:男 2:女 3:未知
        private Integer age;//年龄
        private String cityOfWork;//工作城市,结尾不要带‘市’
        private Integer cityOfWorkCode;//工作城市代码，重庆：500100
        private Integer revenue;//月收入/元
        private String profession;//职业 0.无固定职业 1.工薪族 2.生意人
        private String reservedFunds;//公积金 0.无 1.有
        private String socialSecurity;//社保 0.无 1.有
        private String creditCard;//信用卡 0.无 1.有
        private String zhima;//芝麻分 0.无 1.550分以下 2.550-600分 3.600-650分 4.650-700分 5.700分及以上
        private String car;//车产 0.无 1.有
        private String house;//房产 0.无 1.本地房 2.外地房
        private String insurance;//寿险保单 0.无 1.有
        private String education;//学历 0.高中及以下 1.大专 2.本科 3.本科以上
        private String salary;//工资代发 0.无 1.有
        private String weili;//微粒贷 0.无 1.有
        private String businessLicense;//营业执照 0.无 1.有
        private String enterpriseTaxes;//企业纳税 0.无企税 1.有企税
        private String marital;//婚姻状况 0.未婚/单身 1.离异 2.已婚



    }



    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     * {
     * 	"checkUrl": "http://110.40.178.43:8888/channel/openapi/checkuser",
     * 	"applyUrl": "http://110.40.178.43:8888/channel/openapi/pushuser",
     * 	"channelCode": "huirongyikefuzhou",
     * 	"sourcecode": "21070",
     * 	"publicKey": "MIIBIjANBgkqhkiG9w0BAQEFAAOCAQ8AMIIBCgKCAQEAsLuutChHG1O_PG6Xo7IE6EMr9S5DdIc4PX2T0OoWqf7-jLMvdgq0ueEBPXC-JmyE-vHFkejVwZBwte7eoVaW6KeW0v1FYuN_hDA7bra__zWpLKnlyvYs8TsqkwbCq5EhL7pnhi08ypoEEXQVsyjjBy7cttDMWz7b4bjkEPSdWulmTKeOadLJKdGA95MpC1kbA_TlKJf4bwaBluWSFdb7jyms-KtzcCygQLVD5z1NcPIQVe44HXGUYqelThZ0MwokcnLS2ow7RpkE3_-ut0Lrwk9zT2gJ3_gPEL6IE1XXXvsDZwsKdv252AfBiZwUqVc26XsMd7pd-jowK1QiLnOmSQIDAQAB"
     * }
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit FuZhouBeiYinJinRongCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("福州北银金融对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setPhone(phoneMd5);
            checkInfo.setChannelCode(config.getString("channelCode"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck FuZhouBeiYinJinRongCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("福州北银金融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck FuZhouBeiYinJinRongCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") ==0 ) {
                return DataVo.success(0, "福州北银金融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "福州北银金融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("福州北银金融撞库失败", e);
            return DataVo.fail(1, "福州北银金融撞库失败，请联系系统管理员", product.getPlanId());
        }

    }
}
