package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 格鑫金服API接单
 */
@Service
@Slf4j
public class GexinjinfuCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final String qualityCheckPath = "/api/rsatg/checkmobile";

    private final String applyPath = "/api/rsatg/add";


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Gexinjinfu;
    }

    @Data
    public static class CheckData{

        private String channel_code;
        private String mobile_md5;
        private String channel_secret_key;
    }

    @Data
    private static class CheckInfo{
        private String client_id;

        private String client_secret;

        private CheckData data;


    }
    @Data
    private static class ResultHt{
        private Integer status;
        private String msg;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit GexinjinfuCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
           
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject gexinjinfuJointDTO = JSON.parseObject(configJson);
            log.info("格鑫金服对接参数:{}", JSON.toJSONString(gexinjinfuJointDTO));
            String md5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = gexinjinfuJointDTO.getString("url") + qualityCheckPath  + "?mobnum_md5=" +  md5;
            log.info("credit qualityCheck GexinjinfuCreditService request userId:{}, url:{}, checkData:{}",userInfo.getUserId(), url);
            ResultHt response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/x-www-form-urlencoded; charset=UTF-8");
                 response = httpRestTemplate.restTemplate().getForObject(url, ResultHt.class,head);
            }catch (Exception e){
                log.error("格鑫金服准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck GexinjinfuCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return Objects.equals(200, response.getStatus()) ? DataVo.success(0, "格鑫金服撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());
        } catch (Exception e) {
            log.error("格鑫金服撞库失败", e);
            return DataVo.fail(1, "格鑫金服撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
