package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2023 12 14 15 55
 **/
@Slf4j
@Service
public class GuanZhouPuHuiCreditService  implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.GuanZhouPuHui;
    }

    @Data
    private static class CheckInfo{
        private String mobile;//Md5(mobile)
    }

    @Data
    private static class ApplyInfo{
        private Integer file_id;
        private String name; //姓名
        private String mobile; //手机号码
        private Integer age; //年龄
        private Integer sex;//性别(1:为男,2:为女,无传0)
        private String city; //城市(如武汉市)
        private Integer is_house; //是否有房(是传1,否传0)
        private Integer is_car; //是否有车(是传1,否传0)
        private Integer is_company; //是否有公司营业执照(是传1,否传0)
        private Integer is_credit; //是否有信用卡 (是传1,否传0)
        private Integer is_insurance; //是否有保单(是传1,否传0)
        private Integer is_social; //是否有社保(是传1,否传0)
        private Integer is_fund; //是否有公积金(是传1,否传0)
        private Integer is_work; //是否有打卡工资(是传1,否传0)
        private Integer is_tax; //是否有营业税(是传1,否传0)
        private String webank; //微粒贷额度（单位:元）
        private String money_demand; //申请额度（单位:元）
        private String remarks; //备注
    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit GuanZhouPuHuiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("广州普惠对接参数:{}", JSONObject.toJSONString(config));
            String Phone_md5=(userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5());
            CheckInfo checkInfo=new CheckInfo();
            checkInfo.setMobile(Phone_md5);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck GuanZhouPuHuiCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("广州普惠准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck GuanZhouPuHuiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            log.info("credit qualityCheck GuanZhouPuHuiCreditService response md5Phone:{}, jsonObject:{}",userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code")==0) {
                return DataVo.success(0, "广州普惠撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "广州普惠撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("广州普惠撞库失败", e);
            return DataVo.fail(1, "广州普惠撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
