package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2023 09 22 17 08
 *广东昊恩API
 **/
@Slf4j
@Service
public class GuangDongHaoEnCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.GuangDongHaoEn;
    }

    @Data
    private static class CheckInfo{
        private String appid;//数据标识
        private String mobileEncrypt;//手机号MD5加密32位小写字符串
    }

    @Data
    private static class ApplyInfo{
        private String appid; //数据标识
        private String name; //姓名
        private String mobile;//手机号
        private String cardNo;//身份证
        private Integer gender;//性别; 0-女 1-男
        private String city;//城市（格式：xx市）
        private Integer amount;//申请金额(万)
        private String period;//申请期限(月)
        private Integer monthlyIncome;//月收入(元)
        private Integer age;//年龄(18-99)
        private Integer houseType;//房产; 0-无 1-有
        private Integer carType;//车产; 0-无 1-有
        private Integer socialInsurance;//社保; 0-无 1-有
        private Integer commercialInsurance;//商业保险; 0-无 1-有
        private Integer accumulationFund;//公积金; 0-无 1-有
        private Integer entrepreneur;//是否企业主; 0-否 1-是
        private Integer credit;//信用情况
        private Integer zhima;//芝麻分
        private Integer additional;//其他信息
    }
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit GuangDongHaoEnCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("广东昊恩对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobileEncrypt(phoneMd5);
            checkInfo.setAppid(config.getString("appid"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck GuangDongHaoEnCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("广东昊恩准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck GuangDongHaoEnCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 200) {
                return DataVo.success(0, "广东昊恩撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "广东昊恩撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("广东昊恩撞库失败", e);
            return DataVo.fail(1, "广东昊恩撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
