package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author zjc
 * @Date 2024 08 14 16 36
 **/
@Slf4j
@Service
    public class GuangDongHongZhanCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.GuangDongHongZhan;
    }

    @Data
    private static class CheckInfo{
        private String mobile;//md5加密后的手机号，32位小写
    }


    @Data
    private static class ApplyInfo {

        private String loanName;//姓名
        private String phone;//手机号码
        private String loanMoney;//贷款金额 元
        private String area;//城市
        private String situation;//备注
    }
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit GuangDongHongZhanCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("广东鸿展对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobile(phoneMd5);


            String url = config.getString("checkUrl");

            log.info("credit qualityCheck GuangDongHongZhanCreditService request userId:{}, url:{}, checkInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("广东鸿展准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck GuangDongHongZhanCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") ==0 && jsonObject.getBoolean("data")) {
                return DataVo.success(0, "广东鸿展撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "广东鸿展撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("广东鸿展撞库失败", e);
            return DataVo.fail(1, "广东鸿展撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


}
