package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;


/**
 * @Author Liu Tao
 * @Date 2024 07 22 14 13
 **/
@Service
@Slf4j
public class GuangZhouHuaXinCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.GuangZhouHuaXin;
    }

    @Data
    private static class CheckInfo {
        private String appKey;// Md5(mobile)
        private String sign;// Md5签名
        private String timestamp;// 时间戳 到秒级 例：1704042061，10位
        private String phoneMd5;// 明文电话号码Md5加密值(小写)，用于判断是否重复
    }


    @Data
    private static class ApplyInfo {
        private String appKey;//渠道代码【接收方提供】
        private String sign;//Md5签名
        private String timestamp;//时间戳
        private String phone;//手机
        private String phoneMd5;//明文电话号码Md5加密值(小写)，用于判断是否重复
        private String province;//省
        private String city;//市
        private String realName;//真实姓名
        private String idCard;//身份证号，如果没有该字段，传“无”
        private int age;//年龄
        private Integer gender;//性别；0:女 1:男
        private String wageMonth;//月收入 (没有传“0”)，单位“元”，具体的数字，例如：10000，或者，25000
        private Integer education;//教育程度:1、初中；2、 高中 ；3、 中专 ；4、 大专 ；5、 本科及以上(没有传5)
        private Integer socialSecurity;//社保信息： 0、 无社保信息；1、 六个月以下；2、 六到十二个月； 3、 十二个月以上(没有传0)
        private Integer overdue;//信用记录：1、无信用卡或贷款；2、一年内逾期超过3次且超过90天； 3、 一年内逾期不超过3次且少于90天；4、 信用良好并无逾期 (没有传4)
        private Integer profession;//职业 ： 1、 上班职员；2、 自由职业；3、 个体户；4、企业主(没有传1)
        private Integer paymentForm;//工资发放形式：0、 无 ；1、 现金发放；2、 转账工资；3、 银行代发；4、 打卡+现金； (没有传3)
        private Integer workTime;//工作时间：1、 六个月以下；2、 六到十二个月；3、十二个月以上 (没有传3)
        private Integer house;//房产信息：1 无房产 2 商品房 3 自建房 (没有传1)
        private Integer accumulationFound;//公积金信息：0、无公积金；1、 六个月以下；2、 六到十二个月；3、 十二个月以上 (没有传0)
        private Integer loanAmount;//贷款额度: 1,5万以下; 2,5-10万（推荐）;3,10-20万（推荐）; 4,20万以上; (没有传2)
        private Integer car;//车产信息：1 无车产；2 全款车；3 按揭车(没有传1)
        private Integer carAmount;//车辆价值：0：无；1：0-8万；2：9-15万；3：15-20万；4：20万以上(没有传0)
        private Integer carYear;//车子购买年限：0：无；1，8年以上； 2，8年以下（没有传0)
        private Integer carMortgageStatus;//车子当前抵押状态：0，无；1：当前抵押中；2：当前无抵押(没有传0)
        private Integer isCarOwner;//车产是否本人名下：0：否 1：是(没有传0)
        private Integer loanTime;//贷款时间：1、 1~3个月；2、 3~6个月；3、 6~12个月；4、12~24个月；5、>24个月(没有传1)
        private Integer commercialInsurance;//商业保险：1、 无； 2、投保人寿险且投保两年以下；3、投保人寿险且投保两年以上(没有传1)
        private Integer creditCardLimit;//信用卡额度：1、 无；2、 3000以下；3、3千到1万； 4、1万到3万； 5、3万以上(没有传1)
        private Integer weiLiDai;//微粒贷：0 、无；1 、500 ~ 2999；2 、3000~5999； 3、6000~9999；4 10000 ~ 29999； 5 、30000~99999 ；6、>100000；(没有传0)
        private Integer zhiMa;//芝麻分数：0,无；1、小于500; 2，500~599; 3,600~649; 4,650~699; 5,700以上; (没有传0)
        private Integer baiTiao;//京东白条 0，无；1，3000以下；2，3000～4999；3，5000以上(没有传0
        private Integer huaBei;//蚂蚁花呗 0，无；1，3000以下；2，3000～4999；3，5000以上(没有传0)

    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit GuangZhouHuaXinCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("广州华鑫对接参数:{}", JSONObject.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            //签名
            StringBuffer sb = new StringBuffer();
            long currentTimeMillis = System.currentTimeMillis()/1000;
            sb.append(config.getString("AppKey")+config.getString("AppSecret")+phoneMd5+currentTimeMillis);
            String sign = Md5Util.encoderByMd5(sb.toString()).toLowerCase();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(phoneMd5);
            checkInfo.setTimestamp(String.valueOf(currentTimeMillis));
            checkInfo.setAppKey(config.getString("AppKey"));
            checkInfo.setSign(sign);
            log.info("credit qualityCheck GuangZhouHuaXinCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, String.class);
            } catch (Exception e) {
                log.error("广州华鑫准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck GuangZhouHuaXinCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code").equals(200) && "SUCCESS".equals(jsonObject.getString("msg"))) {
                return DataVo.success(0, "广州华鑫撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "广州华鑫撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("广州华鑫撞库失败", e);
            return DataVo.fail(1, "广州华鑫撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
