package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 灏瀚无崟API接单
 */
@Service
@Slf4j
public class HaohanwuyinCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    private final String qualityCheckPath = "/api/customer/collisionLibrary";

    private final String applyPath = "/api/customer/pushCustomer";

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Haohanwuyin;
    }

    @Data
    public static class CheckData{

        private String channel_code;
        private String mobile_md5;
        private String channel_secret_key;
    }

    @Data
    private static class CheckInfo{
        private String client_id;

        private String client_secret;

        private CheckData data;


    }
    @Data
    private static class ResultHt{
        private Integer code;
        private String msg;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit HaohanwuyinCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
           
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString() ;
            JSONObject HaohanwuyinJointDTO = JSON.parseObject(configJson);
            log.info("灏瀚无崟对接参数:{}", JSON.toJSONString(HaohanwuyinJointDTO));
            Map<String,String> checkData = new HashMap<>();
            checkData.put("channel_code", HaohanwuyinJointDTO.getString("channelCode"));
            checkData.put("channel_secret_key", HaohanwuyinJointDTO.getString("channelSecretKey"));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkData.put("md5_phone", phoneMd5);
            String url = HaohanwuyinJointDTO.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck HaohanwuyinCreditService request userId:{}, url:{}, checkData:{}",userInfo.getUserId(), url, checkData);
            ResultHt response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/x-www-form-urlencoded; charset=UTF-8");
                String httpResponse = httpRestTemplate.restTemplate().postForObject(url,  head,String.class, checkData);
                response = JSONObject.parseObject(httpResponse,ResultHt.class);
            }catch (Exception e){
                log.error("灏瀚无崟准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HaohanwuyinCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return Objects.equals(0, response.getCode()) ? DataVo.success(0, "灏瀚无崟撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());
        } catch (Exception e) {
            log.error("灏瀚无崟撞库失败", e);
            return DataVo.fail(1, "灏瀚无崟撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
