package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2023 12 07 10 53
 **/
@Slf4j
@Service
public class HeFeiShenDaiCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;




    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HeFeiShenDai;
    }

    @Data
    private static class ApplyInfo{
        private String name; //客户姓名
        private String phone; //手机号
        private String gender; //性别
        private Integer age; //年龄
        private String grade;//星级
        private Integer limit; //额度
        private Integer annual_income; //年收入
        private Integer remark_condition; //条件备注
        private String is_married; //是否结婚
        private String source_from; //来源
        private String mortgages; //条件信息
        private String education; //学历
        private String profession; //职业
    }


    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product,EgLoanApiConfigInfoCmd configInfoDo) {
        try {
            log.info("credit HeFeiShenDaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
            byte[] requestConfig = configInfoDo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("合肥盛代对接参数:{}", JSONObject.toJSONString(config));
            String Phone_md5=(userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5());
            String url = config.getString("checkUrl")+Phone_md5;
            log.info("credit qualityCheck HeFeiShenDaiCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, Phone_md5);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().getForObject(url, String.class);
            }catch (Exception e){
                log.error("合肥盛代准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HeFeiShenDaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            log.info("credit qualityCheck HeFeiShenDaiCreditService response md5Phone:{}, jsonObject:{}",userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code")==0&&jsonObject.getString("data").equals("0")) {
                return DataVo.success(0, "合肥盛代撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "合肥盛代撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("合肥盛代撞库失败", e);
            return DataVo.fail(1, "合肥盛代撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
