package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;

import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;
import java.util.Collections;

/**
 * @Author zjc
 * @Date 2024 07 17 14 53
 **/
@Slf4j
@Component
public class HengYangJiuZhenCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HengYangJiuZhen;
    }

    @Data
    private static class CheckInfo{
        private String phone;
        private String source;
        private String city;
    }

    @Data
    private static class ApplyInfo{
        private String qdName;//渠道ID
        private String name;//姓名
        private String phone;//手机号
        private Integer price;//贷款金额
        private Integer house;//是否有房，1有，0无
        private Integer car;//是否有⻋，1有，0无
        private Integer insurance;//是否有寿险，1有，0无
        private Integer fund;//是否有公积⾦，1有，0无
        private Integer socital;//是否有社保，1有，0无
        private String city;//所在城市

        private Integer xyk;//信用卡
        private Integer wld;
        private Integer qyns;
        private Integer df;
        private String source;
        private Integer age;
        private Integer loan_periods;//
        private Integer business_license;//营业执照（0无1有）


    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
//            log.info("credit YunHaiLianDongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());

            String url = config.getString("checkUrl");

            MultiValueMap<String, String> params = new LinkedMultiValueMap<>();
            params.put("phone", Collections.singletonList(userInfo.getUserMobileMD5()));
            params.put("source", Collections.singletonList(config.getString("source")));
            params.put("city", Collections.singletonList(userInfo.getCityAllName()));
            HttpHeaders headers = new HttpHeaders();
            headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
            HttpEntity<MultiValueMap<String, String>> httpEntity = new HttpEntity<>(params, headers);


            log.info("credit qualityCheck HengYangJiuZhenCreditService request userId:{}, url:{}, params:{}", userInfo.getUserId(), url, params);
            String response = null;
            try {
//                response =getRestTemplate().postForObject(url,checkInfo, String.class);
                response = httpRestTemplate.restTemplate().postForEntity(url, httpEntity, String.class).getBody();
            } catch (Exception e) {
                log.error("衡阳玖臻准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HengYangJiuZhenCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
//            log.info("credit qualityCheck YunHaiLianDongCreditService response userId:{}, jsonObject:{}", userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("status") == 200) {
                return DataVo.success(0, "衡阳玖臻撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "衡阳玖臻撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("衡阳玖臻撞库失败", e);
            return DataVo.fail(1, "衡阳玖臻撞库失败，请联系系统管理员", product.getPlanId());
        }
    }



}
