package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.core.env.Environment;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Date;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2022/12/5
 * @Version V1.0
 **/
@Service
@Slf4j
public class HengaiCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    private final String qualityCheckPathTest = "/api/source/test_filter";

    private final String qualityCheckPathProd = "/api/source/filter";

    private final String applyPathTest = "/api/source/test_post_customer";

    private final String applyPathProd = "/api/source/post_customer";

    private final String devUrl = "http://apitest.shlyxxjs.com";

    private final String prodUrl = "https://api.shlyxxjs.com";

    @Resource
    private Environment env;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HengAi;
    }

    @Data
    private static class CheckInfo {
        private int source_code;

        private int timestamp;

        private String access_key;

        private String md5_phone;


    }

    @Data
    private static class ResultHa {
        private int errcode;
        private String msg;
    }

    @Data
    private static class HengaiPushData {
        private String name;
        private String phone;
        private Integer intention_amount;//意向金额（额度）	 单位 元 例如（50000）
        private Integer age; //年龄(未知传0)
        private String city;
        private Integer credit_score; //芝麻信用分
        private Integer has_social_security; //是否有社保
        private Integer has_provident_fund;      //是否有公积金	Int 1有 2无
        private Integer has_car;  //是否有车	Int 1有 2无
        private Integer has_house;  //是否有房	Int 1有 2无
        private Integer has_business_license;  //是否有营业执照	Int 1有 2无
        private Integer has_policy;  //是否有保单	Int 1有 2无
        private Integer has_credit_card;  //是否有信用卡	Int 1有 2无
        private Integer has_jdbaitiao;  //是否有京东白条	Int 1有 2无
        private Integer has_weilidai;  //是否有微粒贷	Int 1有 2无
        private Integer has_huabei;  //是否有花呗	Int 1有 2无
        private String desc;  //备注	String
    }


    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit HengaiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("恒爱对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMd5_phone(phoneMd5);
            checkInfo.setSource_code(config.getIntValue("channelSource"));
            String timestamp = String.valueOf(new Date().getTime() / 1000);
            checkInfo.setTimestamp(Integer.valueOf(timestamp));
            String accessKey = config.getIntValue("channelSource") + config.getString("key") + timestamp;
            checkInfo.setAccess_key(Md5Util.encoderByMd5(accessKey));

            String proFile = env.getActiveProfiles()[0];
            String url;
            if (proFile.indexOf("prod") >= 0) {
                url = config.getString("url") + qualityCheckPathProd;
            } else {
                url = config.getString("url") + qualityCheckPathTest;
            }
            log.info("credit qualityCheck HengaiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            ResultHa response = null;
            try {
                HttpHeaders headers = new HttpHeaders();
                headers.setContentType(MediaType.valueOf("application/json;UTF-8"));
                HttpEntity<CheckInfo> entity = new HttpEntity(checkInfo, headers);
                response = httpRestTemplate.restTemplate().postForObject(url, entity, ResultHa.class);
            } catch (Exception e) {
                log.error("恒爱准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HengaiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return 0 == response.getErrcode() ? DataVo.success(0, "恒爱撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());

        } catch (Exception e) {
            log.error("恒爱撞库失败", e);
            return DataVo.fail(1, "恒爱撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
