package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;


/**
 * @Author Liu Tao
 * @Date 2024 09 03 09 49
 **/
@Slf4j
@Service
public class HongShengJinFuCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HongShengJinFu;
    }

    @Data
    private static class CheckInfo {
        private String md5;// 手机号（32位MD5加密字符串）
    }

    @Data
    private static class ApplyInfo {
        private String name;//客户姓名
        private String sex; //性别(“男”或“女”)
        private String mobile; //手机号
        private String check_num;//验证码（无则留空）
        private Integer money;//贷款额度(如：20，即单位为万)
        private String city; //城市不包含市
        private Integer age;//年龄
        private String shebao; //社保(“有”或“无”)
        private String gongjijin; //公积金(“有”或“无”)
        private String credit_card;//信用卡(“有”或“无”)
        private String baodan_is;//保单(“有”或“无”)
        private String license; //营业执照（“有”或“无”）
        private String house;//房(“有”或“无”)
        private String car; //是否有车(“有”或“无”)
        private String isbankpay; //银行代发(“是”或“否”)
        private String source;//（必填）贷款来源(固定值，具体需要和对接人确定)
        private String meiti;//媒体名称(投放媒体名称，第三方私下内容以便其对数据分析)
        private String remark;
    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("弘盛金服对接参数:{}", JSONObject.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            log.info("弘盛金服开始撞库,请求地址：{},md5:{}", url, phoneMd5);
            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            params.add("md5", phoneMd5);
            String response = null;
            try{
                HttpHeaders headers = new HttpHeaders();
                headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
                HttpEntity<MultiValueMap<String, String>> requestEntity = new HttpEntity<MultiValueMap<String, String>>(params, headers);
                response = httpRestTemplate.restTemplate().postForEntity(url, requestEntity, String.class).getBody();
            } catch (Exception e) {
                log.error("弘盛金服准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("弘盛金服撞库响应：{},md5:{}", response, phoneMd5);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject.getString("code").equals("12")) {
                return DataVo.success(0, "弘盛金服撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "弘盛金服撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "弘盛金服撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
