package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;

import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author Liu Tao
 * @Date 2024 07 04 13 49
 **/
@Slf4j
@Service
public class HongXinPuHuiCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HongXinPuHui;
    }

    @Data
    private static class CheckInfo{
        private String mobile_md5;//md5加密后的手机号，32位小写
        private Integer company;//指定推送商户id，当前默认都传“3
        private Integer is_encrypt;//是否加密，1:是  0:否
    }


    @Data
    private static class ApplyInfo {
        private String name;//姓名
        private String mobile;//加密字符串
        private Integer channel;//渠道来源（固定传16）
        private Integer company;//商户id,默认传“3”
        private Integer sex;//性别 （1男 2女）
        private Integer loan_limit;//额度 (比如: 100000，单位：元）
        private Integer room;//是否有房产（1：有  0：无）
        private Integer car;//是否有车产（ 1：有  0：无)
        private Integer accumulation;//是否有公积金 ( 1：有  0：无)
        private Integer social;//是否有社保 ( 1：有  0：无 )
        private Integer policy;//是否有保单 (  1：有  0：无 )
        private Integer business;//是否有营业执照 ( 1：有  0：无 )
        private Integer issued;//是否有打卡工资 ( 1：有  0：无 )
        private Integer enterprise;//是否有企业纳税 (  1：有  0：无 )
        private Integer credit;//是否有信用卡 (  1：有  0：无 )
        private Integer is_encrypt;//是否加密（1：是 0:否）
    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd    configInfo)  {
        try {
            log.info("credit HongXinPuHuiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("弘鑫普惠对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobile_md5(phoneMd5);
            checkInfo.setCompany(config.getInteger("company"));
            checkInfo.setIs_encrypt(0);

            Map<String, String> requestData = new HashMap<>();
            requestData.put("mobile_md5", String.valueOf(checkInfo.getMobile_md5()));
            requestData.put("company", String.valueOf(checkInfo.getCompany()));
            requestData.put("is_encrypt", String.valueOf(checkInfo.getIs_encrypt()));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck HongXinPuHuiCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            JSONObject response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/x-www-form-urlencoded");
                HttpResponse httpResponse = httpRestTemplate.restTemplate().postForObject(url, null, null, head, null, requestData);
                String responseStr = EntityUtils.toString(httpResponse.getEntity());
                response = JSONObject.parseObject(responseStr);
            }catch (Exception e){
                log.error("弘鑫普惠准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HongXinPuHuiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (response.getInteger("code")==0) {
                return DataVo.success(0, "弘鑫普惠撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "弘鑫普惠撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("弘鑫普惠撞库失败", e);
            return DataVo.fail(1, "弘鑫普惠撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


}
