package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;

/**
 * @Author Liu Tao
 * @Date 2023 12 04 17 12
 **/
@Slf4j
@Service
public class HuNanDiShuiYanCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HuNanDiShuiYan;
    }

    @Data
    private static class CheckInfo{
        private String phone_md5;//手机号
        private String channel;//渠道代码QHXR59
    }
    @Data
    private static class ApplyInfo{
        private String username; //客户姓名
        private String tel; //手机号
        private String cityName; //城市（上海/苏州/…）
        private Integer price; //需求金额（如50000）
        private String sex;//性别（男/女）
        private Integer hasHouse; //是否有房（1有/2无）
        private Integer hasCar; //是否有车（1有/2无）
        private Integer hasBaodan; //有无保单（1有/2无）
        private Integer hasGongjijin; //是否有公积金（1有/2无）
        private Integer hasWeilidai; //有无芝麻分（1有/2无）
        private Integer hasNashui; //有无纳税（1有/2无）
        private String channel; //渠道代码由我方提供：QHXR59
        private Integer note; //备注可为空（其他信息可传这
    }

    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit HuNanDiShuiYanCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("湖南滴水岩对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo=new CheckInfo();
            checkInfo.setPhone_md5(userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5());
            checkInfo.setChannel(config.getString("channel"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck HuNanDiShuiYanCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("湖南滴水岩准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HuNanDiShuiYanCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("state").equals("1")) {
                return DataVo.success(0, "湖南滴水岩撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "湖南滴水岩撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("湖南滴水岩撞库失败", e);
            return DataVo.fail(1, "湖南滴水岩撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    public static String encrypt(String sSrc, String sKey) throws Exception {

        // 判断Key是否为16位
//        if (sKey.length() != 16) {
//            System.out.print("Key长度不是16位");
//            return null;
//        }
        byte[] raw = sKey.getBytes("utf-8");
        SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
        Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");//"算法/模式/补码方式"
        cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
        byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));

        return new Base64().encodeToString(encrypted);//此处使用BASE64做转码功能，同时能起到2次加密的作用。
    }



}
