package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgLoanApiConfigInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * 惠融crmAPI接单
 */
@Service
@Slf4j
public class HuirongCrmCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.HUIRONG_CRM;
    }

    @Data
    public static class CheckData {
        private String chanelCode;
        private String secretKey;
        private String attackPhone;
        private String merchantNo;
    }

    @Data
    private static class ResultHt {
        private Integer code;
        private String msg;
        private JSONObject data;
    }



    /**
     * 撞库 实现单个用户撞库
     *
     * @return {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfoCmd) {
        try {
            log.info("credit HuirongCrmCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
            String config = HessianUtils.deserialize(configInfoCmd.getRequestConfig()).toString();
            JSONObject huirongJointDTO = JSON.parseObject(config);
            String url = huirongJointDTO.getString("checkUrl");
            CheckData checkData = new CheckData();
            if(StringUtils.isNotBlank(userInfo.getUserMobile())){
                checkData.setAttackPhone(Md5Util.encoderByMd5(userInfo.getUserMobile()));
            }else{
                checkData.setAttackPhone(userInfo.getUserMobileMD5());
            }

            checkData.setSecretKey(huirongJointDTO.getString("secretKey"));
            checkData.setChanelCode(huirongJointDTO.getString("channelCode"));
            checkData.setMerchantNo(product.getBid());
            String requestJson = JSON.toJSONString(checkData);
            log.info("credit qualityCheck HuirongCrmCreditService request userId:{}, url:{},requestParam:{}", userInfo.getUserId(), url, requestJson);
            ResultHt response = null;
            try {
               HttpHeaders headers = new HttpHeaders();
               headers.set("Content-Type", "application/json");
               HttpEntity httpEntity = new HttpEntity<>(requestJson,headers);
               //post方式如果出现对接 请求体 为空参考这种方式
                response = httpRestTemplate.restTemplate().postForObject(url,httpEntity,ResultHt.class);
              log.info("hui ron result {}",JSONObject.toJSONString(response));
            } catch (Exception e) {
                log.error("惠融crm准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HuirongCrmCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject data = response.getData();
            Integer status = data.getInteger("status");
            return Objects.equals(0, status) ? DataVo.success(0, "惠融crm撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());
        } catch (Exception e) {
            log.error("惠融crm撞库失败", e);
            return DataVo.fail(1, "惠融crm撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
