package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.*;
import javax.crypto.spec.DESedeKeySpec;
import javax.crypto.spec.IvParameterSpec;
import java.io.UnsupportedEncodingException;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.Key;
import java.security.NoSuchAlgorithmException;
import java.security.spec.InvalidKeySpecException;
import java.util.Objects;

/**
 * 惠众API接单
 */
@Service
@Slf4j
public class HuizhongCreditService implements LoanDockingApi {

    private final String qualityCheckPath = "/api/user/check";

    private final String applyPath = "/api/yhzd/addCust";

    private final String devUrl = "http://apitest.shlyxxjs.com";

    private final String prodUrl = "https://api.shlyxxjs.com";

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Huizhong;
    }


    @Data
    private static class CheckInfo{
        private String phoneNo;

        private String channelSource;
    }
    @Data
    private static class ResultHt{
        private String code;
        private String msg;
    }
    @Data
    private static class ApplyInfo{
        private String cust_name;

        private String mobile;

        private Integer age; //年龄(未知传0)

        private Integer sex; //性别(1:为男,2:为女,未知传0)

        private Integer apply_limit;//申请额度（单位元）如50000，若无特别说明，金额需3万起步

        private String channel_source;

        private String city;
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit HuizhongCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("惠众对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneNo(userInfo.getUserMobileMD5());
            checkInfo.setChannelSource(config.getString("channelSource"));
            String url = config.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck HuizhongCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            ResultHt response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, ResultHt.class);
            }catch (Exception e){
                log.error("惠众准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck HuizhongCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return Objects.equals("0000", response.getCode()) ? DataVo.success(0, "惠众撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());

        } catch (Exception e) {
            log.error("惠众撞库失败", e);
            return DataVo.fail(1, "惠众撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

    private static class ApiAesUtil {

        public static String encrypt(String data, String secretKey) {
            try {
                byte[] encrpyted = tripleDES(Cipher.ENCRYPT_MODE, data.getBytes("UTF-8"), secretKey.getBytes());
                byte[] encoded = Base64.encodeBase64(encrpyted); // Base64编码
                return new String(encoded);
            } catch (UnsupportedEncodingException e) {
                throw new RuntimeException(e);
            }
        }

        public static String decrypt(String data, String secretKey ) {
            try {
                byte[] decoded = Base64.decodeBase64(data); // Base64解码
                byte[] decrypted = tripleDES(Cipher.DECRYPT_MODE, decoded, secretKey.getBytes());// 3DES解密
                return new String(decrypted, "UTF-8");
            } catch (UnsupportedEncodingException e) {
                throw new RuntimeException(e);
            }
        }

        private static byte[] tripleDES(int opmode, byte[] data, byte[] secretKey) {
            return cipher("DESede", "DESede/CBC/PKCS5Padding", opmode, data, "01234567".getBytes(), secretKey);
        }

        private static byte[] cipher(String algorithm, String transformation, int opmode, byte[] data, byte[] iv, byte[] secretKey) {
            try {
                Key key = SecretKeyFactory.getInstance(algorithm).generateSecret(new DESedeKeySpec(secretKey));
                IvParameterSpec spec = new IvParameterSpec(iv);
                Cipher cipher = Cipher.getInstance(transformation);
                cipher.init(opmode, key, spec);
                return cipher.doFinal(data);
            } catch (InvalidKeyException | InvalidKeySpecException | NoSuchAlgorithmException | NoSuchPaddingException
                    | IllegalBlockSizeException | BadPaddingException | InvalidAlgorithmParameterException e) {
                throw new RuntimeException(e);
            }
        }
    }
}
