package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author Liu Tao
 * @Date 2024 05 21 11 33
 **/
@Slf4j
@Service
public class JianZhanCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.JianZhan100;
    }

    @Data
    private static class CheckInfo {
        private String act;// 操作类型
        private String c_phone;// 手机号（32位MD5加密字符串）

        private String aid;// Access Id
        private String timestamp;// 时间戳
        private String noncestr;// 随机字符串
        private String signature;// 签名
    }

    @Data
    private static class ApplyInfo {
        private String act;//姓名
        private String c_name; //年龄
        private String c_phone; //手机号
        private Integer c_sex; //性别
        private String type;//类型
        private String c_city;//城市
        private String c_birth_year;//出生年份如：1990）
        private String c_daikuanedu;//贷款额度如：3000）
        private Integer c_has_xinyongka;//有无信用卡1（有）2（无）
        private Integer loanMoney;//借款金额（单位：万元）
        private Integer c_has_fang;//有无房 1（有）2（无）
        private Integer c_has_che; //有无车 1（有）2（无）
        private Integer c_has_gongjijin; //有无公积金 1（有）2（无）

        private Integer c_has_shebao; //有无社保 1（有）2（无）
        private String c_has_baodan;//有无保单 1（有）2（无）
        private Integer c_has_weilidai;//有无微粒贷 1（有）2（无）
        private Integer c_faxinfangshi;//发薪方式1（银行转账）2（代发工资）3（现金发放）4（无）
        private String c_shouru;//收入（如：3000）
        private String c_zhiye;//职业（如：工程师）

        private String aid;// Access Id
        private String timestamp;// 时间戳
        private String noncestr;// 随机字符串
        private String signature;// 签名

    }

    @Data
    private static class RequestData{
        private String aid;// Access Id
        private String act;// 操作类型，具体的功能点act值不一样。
        private String timestamp;// 时间戳
        private String noncestr;// 随机字符串
        private String signature;// 签名
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd user, PlanCmd product, EgLoanApiConfigInfoCmd configInfoCmd) {
        try {
            log.info("credit JianZhanCreditService qualityCheck begin...userId:{}", user.getUserMobileMD5());
          
            byte[] requestConfig =
            configInfoCmd.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("建站100对接参数:{}", JSON.toJSONString(config));
            DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMddHHmmss");
            // 获取当前日期时间
            LocalDateTime now = LocalDateTime.now();
            // 使用format方法将LocalDateTime对象转换为字符串
            String formattedDateTime = now.format(formatter);
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setAct(config.getString("checkAct"));
            checkInfo.setC_phone(user.getUserMobileMD5());
            checkInfo.setAid(config.getString("aid"));
            checkInfo.setNoncestr(formattedDateTime);
            checkInfo.setTimestamp(formattedDateTime);
            String signature=checkInfo.getAid()+checkInfo.getAct()+checkInfo.getTimestamp()+checkInfo.getNoncestr()+config.getString("akey");
            checkInfo.setSignature(Md5Util.encoderByMd5(signature));
            Map<String, String> requestData = new HashMap<>();
            requestData.put("act", checkInfo.getAct());
            requestData.put("c_phone",checkInfo.getC_phone());
            requestData.put("aid", checkInfo.getAid());
            requestData.put("noncestr",checkInfo.getNoncestr());
            requestData.put("timestamp", checkInfo.getTimestamp());
            requestData.put("signature",checkInfo.getSignature());

            String url = config.getString("url");
            log.info("credit qualityCheck JianZhanCreditService request userId:{}, url:{}, CheckInfo:{}", requestData, url, user.getUserMobileMD5());
            Map<String, String> header = new HashMap<>();
            header.put("Content-Type", "application/x-www-form-urlencoded");
            String res = "";
            JSONObject jsonObject = new JSONObject();
            try{
                HttpResponse response = httpRestTemplate.restTemplate().postForObject(url, null, null, header, null, requestData);
                res = EntityUtils.toString(response.getEntity());
                jsonObject = JSON.parseObject(res);
            }catch (Exception e){
                log.error("建站100准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck JianZhanCreditService response userId:{}, result:{}",user.getUserMobileMD5(), jsonObject);
            if (jsonObject == null) {
                 return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            if (jsonObject.getString("status").equals("0")) {
                return DataVo.success(0, "建站100撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "建站100撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "建站100撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
