package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgLoanApiConfigInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2023 12 01 16 54
 **/
@Component
@Slf4j
public class JinDieV3CreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        //三方对接平台，或者第三方sass平台，此处不设置任何默认值
        return ServerCodeEnums.CRM_JDV3;
    }

    @Data
    private static class ApplyInfo {
        private String Username;
        private String Userphone;
        private Integer Sex; //性别(1:为男,2:为女,未知传0)
        private Integer Money;//申请额度（单位元）如50000，若无特别说明，金额需3万起步
        private String City;
        private String Channel;
        private String ChannelInfo;
        private String Info;
        private Integer Price;
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"url":"http://apitest.shlyxxjs.com","key":"fluxZhudai*_key","tenantId":"1405729496904110081","trafficPlatformId":"13872425018351111"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo) {
        try {
            log.info("credit JinDieV3CreditService qualityCheck begin...userId:{},productId={}", userInfo.getUserId(), product.getPlanId());
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            if (StringUtils.isBlank(configJson)) {
                return DataVo.fail(product.getPlanName(), product.getPlanId());
            }
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("锦蝶V3.0对接参数:{}", JSON.toJSONString(config));
            JSONObject jsonObject = new JSONObject() {{
                put("Appid", config.getString("Appid"));
                put("Appkey", config.getString("Appkey"));
                put("Userphone", userInfo.getUserMobileMD5());
            }};
            String url = config.getString("CheckUrl");
            log.info("credit qualityCheck JinDieV3CreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, jsonObject);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, jsonObject, String.class);
            } catch (Exception e) {
                log.error("【{}】-锦蝶V3.0准入异常,异常信息：{}", product.getPlanName(), e.getMessage(), e);
            }
            log.info("credit qualityCheck JinDieV3CreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject res = JSONObject.parseObject(response);
            if (res.getInteger("result") == 400) {
                return DataVo.success(0, "【" + product.getPlanName() + "】-锦蝶V3.0撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(res.getString("message"), product.getPlanId());
            }
        } catch (Exception e) {
            log.error("【{}】-锦蝶V3.0撞库失败", product.getPlanName(), e);
            return DataVo.fail(1, "锦蝶V3.0撞库失败，请联系系统管理员", product.getPlanId());
        }

    }
}
