package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author zjc
 * @Date 2024 06 12 17 11
 **/
@Slf4j
@Service
public class JinZhuLiCreditService  implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.JinZhuLiCreditService;
    }

    @Data
    private static class CheckInfo {
        private String phone;//手机号, MD5加密(32位小写)
        private String qdName;//城市：例如：北京
        private String source;//固定值，具体需要和对接人确定
    }

    @Data
    private static class ApplyInfo {
        private String qdName;
        private String name;
        private Long phone;
        private Long price;
        private Integer house;
        private Integer car;
        private Integer insurance;
        private Integer fund;
        private Integer socital;
        private Integer xyk;
        private Integer wld;
        private Integer qyns;
        private Integer df;
        private Integer business_license;
        private String city;
        private String source;
        private Integer age;
        private Integer loan_periods;

    }

    @Data
    private static class ApplyInfoRequst {
       private String is_jm;
       private String source;
       private String data;
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit JinZhuLiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());

            log.info("金助理对接参数:{}", JSON.toJSONString(config));

            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhone(phoneMd5);
            checkInfo.setQdName(config.getString("qdName"));
            checkInfo.setSource(config.getString("source"));

            String url = config.getString("checkUrl");

            log.info("credit qualityCheck JinZhuLiCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, phoneMd5);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("金助理准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck JinZhuLiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("status").equals("200")) {
                return DataVo.success(0, "金助理撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "金助理撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("金助理撞库失败", e);
            return DataVo.fail(1, "金助理撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
