package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;
import java.util.Objects;

/**
 * 快易贷API接单
 */
@Service
@Slf4j
public class KuaiyidaiFourToOneCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    private final String qualityCheckPath = "/Admin/UserIncomeApi/comparePhoneMonitor";

    private final String applyPath = "/Admin/UserIncomeApi/addUserAes";

    @Data
    public static class CheckData{
        private String merNo;
        private String params;
    }

    @Data
    private static class ResultHt{
        private String status;
        private String mes;
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit KuaiyidaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
           
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject kuaiyidaiJointDTO = JSON.parseObject(configJson);
            log.info("快易贷对接参数:{}", JSON.toJSONString(kuaiyidaiJointDTO));


            Map<String, String> paramMap = new HashMap<>();
            paramMap.put("city",userInfo.getCityAllName() );
            paramMap.put("phone", userInfo.getUserMobileMD5());
            paramMap.put("qdName", kuaiyidaiJointDTO.getString("qdName"));


            String url = kuaiyidaiJointDTO.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck KuaiyidaiCreditService request userId:{}, url:{}, data:{}",userInfo.getUserId(), url, JSON.toJSONString(paramMap));
            ResultHt response = null;
            try{
                JSONObject resJson = httpRestTemplate.restTemplate().postForEntity(url,paramMap,JSONObject.class).getBody();
                response = JSON.parseObject(resJson.toJSONString(), ResultHt.class);
            }catch (Exception e){
                log.error("快易贷准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck KuaiyidaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return Objects.equals("200", response.getStatus()) ? DataVo.success(0, "快易贷撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMes(), product.getPlanId());
        } catch (Exception e) {
            log.error("快易贷撞库失败", e);
            return DataVo.fail(1, "快易贷撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.KuaiyidaiFourToOne;
    }

}
