package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.infrastructure.utils.RSAUtils;
import com.hrsk.cloud.eg.infrastructure.utils.SnowflakeIdWorker;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.security.interfaces.RSAPublicKey;
import java.time.Instant;

/**
 * @Author Liu Tao
 * @Date 2024 06 19 17 49
 **/
@Slf4j
@Service
public class LianKeYunKongCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.LianKeYunKong;
    }

    @Data
    private static class CheckInfo {
        private String phoneMd5;// 手机号MD5
    }

    @Data
    private static class ApplyInfo {
        private String custName;//姓名
        private String mobile; //手机号
        private String age; //年龄
        private String sex; //性别
        private String city;//城市
        private BigDecimal applyLimit;//申请额度
        private String applyTime;//申请日期
        private String channelSource;//渠道来源
        private String hasFund;//是否有公积金
        private String hasHouse;//是否有房
        private String hasCar;//是否有车
        private String hasSocial; //是否有社保
        private String inspectionLevel; //芝麻信用分
        private String mediaSource; //媒体来源
    }

    @Data
    private static class RequestData{
        private String tenantId;// 租户 ID
        private String timestamp;// 时间戳
        private String requestId;// 随机字符串
        private String configName;// 撞库配置名
        private JSONObject data;// 随机字符串
        private String sign;//签名
    }


    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit LianKeYunKongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("链客云控对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(phoneMd5);
            String millisecondsSinceEpoch = String.valueOf(Instant.now().toEpochMilli());
            long id = SnowflakeIdWorker.nextId();
            String sign="timestamp:"+millisecondsSinceEpoch+"-"+"requestId:"+id;
            RequestData requestParam=new RequestData();
            requestParam.setTenantId(config.getString("tenantId"));
            requestParam.setTimestamp(millisecondsSinceEpoch);
            RSAPublicKey publicKey = RSAUtils.getPublicKey(config.getString("publicKey"));
            String s = RSAUtils.publicEncrypt(checkInfo.getPhoneMd5(), publicKey);
            JSONObject json=new JSONObject();
            json.put("phoneMd5",s);
            requestParam.setData(json);
            requestParam.setRequestId(String.valueOf(id));
            requestParam.setSign(Md5Util.encoderByMd5(sign));
            requestParam.setConfigName(config.getString("configNameCheck"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck LianKeYunKongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, phoneMd5);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, requestParam, String.class);
            } catch (Exception e) {
                log.error("链客云控准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck LianKeYunKongCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject data = JSON.parseObject(jsonObject.getString("data"));
            if (jsonObject.getString("code").equals("0")&&data.getString("code").equals("200")) {
                return DataVo.success(0, "链客云控撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "链客云控撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("链客云控撞库失败", e);
            return DataVo.fail(1, "链客云控撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
