package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2023 08 22 09 57
 **/
@Slf4j
@Service
public class LiaoChengXinYiDaiCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.DaXiangHuaBei;
    }

    @Data
    private static class CheckInfo{
        private String phone;//md5 的手机号
        private String source;//合作标识
        private String city;//客户所在城市。比如：北京
    }
    @Data
    private static class ResultHt{
        private String code;
        private String msg;
        private JSONObject data;
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"source":"xy_dxhb","checkUrl":"http://api-crm.krdcrm.cn:8181/home/encryptCheckCustomer","publicKey":"hxW7zT4BI9siImpE"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit LiaoChengXinYiDaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("聊城鑫易代对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setPhone(phoneMd5);
            checkInfo.setSource(config.getString("source"));
            checkInfo.setCity(userInfo.getCompanyCity());
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck LiaoChengXinYiDaiService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("聊城鑫易代准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck LiaoChengXinYiDaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 200 && jsonObject.getJSONObject("data")!=null && jsonObject.getJSONObject("data").getInteger("isRegistered")==0) {
                return DataVo.success(0, "聊城鑫易代撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "聊城鑫易代撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("聊城鑫易代撞库失败", e);
            return DataVo.fail(1, "聊城鑫易代撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
