package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.infrastructure.utils.RSAUtils;
import com.hrsk.cloud.eg.infrastructure.utils.RedisUtil;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.security.interfaces.RSAPublicKey;
import java.util.concurrent.TimeUnit;

/**
 * @Author Liu Tao
 * @Date 2024 04 12 09 29
 **/
@Slf4j
@Service
public class NanTongXingChengCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Resource
    private RedisUtil redisUtil;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.NanTongXingChengCreditService;
    }

    @Data
    private static class CheckInfo{
        private String openId;//广告平台
        private String cityCode;//城市代码
        private String phone;
    }
    @Data
    private static class Request{
        private String data;
    }




    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit NanTongXingChengCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("南通星辰对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhone(phoneMd5);
            checkInfo.setOpenId(config.getString("openId"));
            String cityCode = String.valueOf(userInfo.getCityCode());
            String citycodes=cityCode+"000000";
            checkInfo.setCityCode(citycodes);
            RSAPublicKey publicKey = RSAUtils.getPublicKey(config.getString("key"));
            String data = RSAUtils.publicEncrypt(JSON.toJSONString(checkInfo), publicKey);
            Request request= new Request();
            request.setData(data);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck NanTongXingChengCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, phoneMd5);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,request, String.class);
            }catch (Exception e){
                log.error("南通星辰准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck NanTongXingChengCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("result").equals("true")) {
                redisUtil.set(String.format("zudai:token:%s:%s", "nantong", phoneMd5), jsonObject.getString("token"),1, TimeUnit.DAYS);
                return DataVo.success(0, "南通星辰撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "南通星辰撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("南通星辰撞库失败", e);
            return DataVo.fail(1, "南通星辰撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
