package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2024 06 06 13 43
 **/
@Slf4j
@Service
public class NiYouKeCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.NiYouKe;
    }
    @Data
    private static class CheckInfo{
        private String channelcode;//渠道号
        private String phone_md5;//手 机 号 md5 小 写
        private String city;//申请人所在城市，如上海市
        private String sign;//键按照升序组合，加上秘钥(URSolKiBSlcxUuAVtbEO)md5
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd    configInfo)  {
        try {
            log.info("credit NiYouKeCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("尼优客对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setPhone_md5(phoneMd5);
            checkInfo.setCity(userInfo.getCityAllName());
            checkInfo.setChannelcode(config.getString("channelCode"));
            String sign="channelcode="+config.getString("channelCode")+"&city="+checkInfo.getCity()+"&phone_md5="+phoneMd5+config.getString("appKey");
            checkInfo.setSign(Md5Util.encoderByMd5(sign));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck NiYouKeCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("尼优客准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck NiYouKeCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 200) {
                return DataVo.success(0, "尼优客撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "尼优客撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("尼优客撞库失败", e);
            return DataVo.fail(1, "尼优客撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
