package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.time.Instant;
import java.util.Base64;

/**
 * @Author Liu Tao
 * @Date 2023 12 27 16 28
 **/
@Component
@Slf4j
public class PingDingShanCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.PingDingShan;
    }

    @Data
    private static class CheckInfo{
        private String partnerName;//合作⽅名称
        private String channelId;//渠道号
        private String serialNo;//请求流⽔号
        private String requestData;//请求数据密⽂
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit PingDingShanCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("平顶山对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setPartnerName("惠融易客");
            checkInfo.setChannelId(config.getString("chanelId"));
            String millisecondsSinceEpoch = String.valueOf(Instant.now().toEpochMilli());
            checkInfo.setSerialNo("hryk"+millisecondsSinceEpoch);

            JSONObject jsonObjects = new JSONObject() {{
                put("anonymizer", "MASKED_MOBILE_2");
                put("encryptValue", phoneMd5);
            }};
            checkInfo.setRequestData(encrypt(String.valueOf(jsonObjects),config.getString("publicKey")));
            log.info("平顶山手机号{},加密前参数{},加密后参数{}",userInfo.getUserMobile(),jsonObjects,checkInfo);
            String url = config.getString("checkUrl");
            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            params.add("partnerName", checkInfo.getPartnerName());
            params.add("channelId", checkInfo.getChannelId());
            params.add("serialNo", checkInfo.getSerialNo());
            params.add("requestData", checkInfo.getRequestData());
            log.info("credit qualityCheck PingDingShanCreditService request userId:{}, url:{}, checkInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                HttpHeaders headers = new HttpHeaders();
                headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
                HttpEntity<MultiValueMap<String, String>> requestEntity = new HttpEntity<MultiValueMap<String, String>>(params, headers);
                response = httpRestTemplate.restTemplate().postForEntity(url, requestEntity, String.class).getBody();
            }catch (Exception e){
                log.error("平顶山准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck PingDingShanCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);
            if (jsonObject.getInteger("code")==1) {
                    return DataVo.success(0, "平顶山撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "平顶山撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("平顶山撞库失败", e);
            return DataVo.fail(1, "平顶山撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

    // 加密
    public static String encrypt(String sSrc, String sKey) throws Exception {
        if (sKey == null) {
            System.out.print("Key为空null");
            return null;
        }
        // 判断Key是否为16位
        if (sKey.length() != 16) {
            System.out.print("Key长度不是16位");
            return null;
        }
        byte[] raw = sKey.getBytes("utf-8");
        SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
        Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");//"算法/模式/补码方式"
        cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
        byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));

        return Base64.getEncoder().encodeToString(encrypted);//此处使用BASE64做转码功能，同时能起到2次加密的作用。
    }

    public static String getphonecrypt(String num){
        char[] phoneArray = num.toCharArray();
        // 将最后两位字符替换为星号
        phoneArray[phoneArray.length - 2] = '*';
        phoneArray[phoneArray.length - 1] = '*';
        String maskedPhoneNumber = new String(phoneArray);
       return maskedPhoneNumber;
    }



}
