package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.AllArgsConstructor;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;

/**
 * 庆鱼API接单
 */
@Component
@Slf4j
public class QingyuCreditService implements LoanDockingApi {
    private final String qualityCheckPath = "/openapi/interface/query/phones";
    private final String applyPath = "/openapi/interface/save/customer";

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    public ServerCodeEnums getType() {
        return null;
    }

    private String getSign(String data, String trafficPlatformId, String key) {
        return Md5Util.encoderByMd5("data=" + data + "&trafficPlatformId=" + trafficPlatformId + key);
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"url":"http://apitest.shlyxxjs.com","key":"fluxZhudai*_key","tenantId":"1405729496904110081","trafficPlatformId":"13872425018351111"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo) {
        try {
            log.info("credit QingyuCreditService qualityCheck begin...userId:{},productId={}", userInfo.getUserId(), product.getPlanId());
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            if (StringUtils.isBlank(configJson)) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }

            JSONObject config = JSONObject.parseObject(configJson);
            log.info("庆鱼对接参数:{}", JSON.toJSONString(config));
            CheckInfoReq checkInfo = new CheckInfoReq();
            checkInfo.setData(JSON.toJSONString(new ArrayList<CheckInfoReq.CheckRequest>() {{
                add(new CheckInfoReq.CheckRequest() {{
                    setCustomers(new ArrayList<CustomersReq>() {{
                        add(new CustomersReq(userInfo.getUserMobileMD5()));
                    }});
                    setTenantId(config.getString("tenantId"));
                }});
            }}));
            checkInfo.setTrafficPlatformId(config.getString("trafficPlatformId"));
            checkInfo.setSign(getSign(checkInfo.getData(), checkInfo.getTrafficPlatformId(), config.getString("key")));
            String url = config.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck QingyuCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            ResultYq response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, ResultYq.class);
            } catch (Exception e) {
                log.error("【{}】-庆鱼准入异常,异常信息：{}", product.getPlanName(), e.getMessage(), e);
            }
            log.info("credit qualityCheck QingyuCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (response.getCode() == 200 && response.getSuccess() == true && response.getData().get(0).getCustomers().get(0).getStatus() == 0) {
                return DataVo.success(0, "【" + product.getPlanName() + "】-庆鱼撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(response.getMsg(), product.getPlanId());
            }
        } catch (Exception e) {
            log.error("【{}】-庆鱼撞库失败", product.getPlanName(), e);
            return DataVo.fail(1, "庆鱼撞库失败，请联系系统管理员", product.getPlanId());
        }

    }
    @Data
    private static class CheckInfoReq {
        private String data;

        private String sign;

        private String trafficPlatformId;

        @Data
        static class CheckRequest {
            private List<CustomersReq> customers;

            private String tenantId;

            @Data
            @AllArgsConstructor
            static class CustomersReq {
                private String phone;
            }
        }
    }

    @Data
    private static class ResultYq {
        private Integer code;
        private String msg;
        private Boolean success;

        private List<Result> data;

        @Data
        static class Result {
            private List<CustomersRes> customers;

            private String tenantId;

            @Data
            static class CustomersRes {
                private String phone;
                //0.成功 1.失败
                private Integer status;
            }
        }
    }

    @Data
    private static class ApplyInfo {

        private String data;

        private String sign;

        private String trafficPlatformId;

        @Data
        static class ApplyRequest {

            private List<CustomersReq> customers;

            private String tenantId;

            @Data
            static class CustomersReq {

                private String name;//姓名

                private String phone;//电话

                private String amount;//申请金额

                private String car; //车产(有  无)

                private String house; //房产(有  无)

                private String age; //年龄

                private String purpose;//贷款目的（消费贷款）

                private String deadline;//贷款期限（6~12月）

                private String social;//社保

                private String accumulation;//公积金

                private String insurance;//保险保单

                private String points;//芝麻分

                private String provinceCode;//省代码

                private String cityCode;//市代码

                private String resource;
            }
        }
    }
}
