package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Base64;

/**
 * @Author Liu Tao
 * @Date 2023 11 03 17 31
 **/
@Slf4j
@Service
public class RongXiangDaChangShaCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.RongXiangDaChangSha;
    }

    @Data
    private static class CheckInfo{
        private String phoneMd5;//md5 的手机号
        private String accessKey;//渠道访问密钥
        private String sourceCode;//渠道标识
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {
     * 	"checkUrl": "http://test-gw.xxb888.com/xxb-filter/api/filter/md5",
     * 	"applyUrl": "http://test-gw.xxb888.com/xxb/api/source/clue_data/consumer",
     * 	"accesskey": "3465D5B2-1D08-4875-B7E7-E1DAA9385530",
     * 	"sourcecode": "10986",
     * 	"key": "BFXC7JM1OG35XDVR",
     * 	"iv": "67P0VGV0AXUM9NH5"
     * }
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit RongXiangDaChangShaCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("融享达长沙对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? convertMD5ToUpperCase(Md5Util.encoderByMd5(userInfo.getUserMobile())) : convertMD5ToUpperCase(userInfo.getUserMobileMD5());
            checkInfo.setPhoneMd5(phoneMd5);
            checkInfo.setAccessKey(config.getString("accesskey"));
            checkInfo.setSourceCode(config.getString("sourcecode"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck RongXiangDaChangShaCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            }catch (Exception e){
                log.error("融享达长沙准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck RongXiangDaChangShaCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 1 && jsonObject.getJSONObject("data")!=null && jsonObject.getJSONObject("data").getBoolean("phoneMd5Exist").equals(false)) {
                return DataVo.success(0, "融享达长沙撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "融享达长沙撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("融享达长沙撞库失败", e);
            return DataVo.fail(1, "融享达长沙撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


    public static String convertMD5ToUpperCase(String md5Hash) {
        if (md5Hash == null || md5Hash.length() == 0) {
            return "";
        }
        StringBuilder sb = new StringBuilder();
        for (int i = 0; i < md5Hash.length(); i++) {
            char c = md5Hash.charAt(i);
            if (Character.isLowerCase(c)) {
                sb.append(Character.toUpperCase(c));
            } else {
                sb.append(c);
            }
        }
        return sb.toString();
    }
    public static String encrypt(String plainText, String key, String iv) throws Exception {
        // 将 key 转换为 SecretKey 对象
        SecretKey secretKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
        // 将 IV 字符串转换为字节数组
        byte[] ivBytes = iv.getBytes(StandardCharsets.UTF_8);
        // 生成 IV
        // 创建 Cipher 对象
        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
        cipher.init(Cipher.ENCRYPT_MODE, secretKey, new IvParameterSpec(ivBytes));
        // 加密明文
        byte[] encryptedBytes = cipher.doFinal(plainText.getBytes(StandardCharsets.UTF_8));
        // 将加密后的字节转换为 Base64 编码
        return Base64.getEncoder().encodeToString(encryptedBytes);
    }

}
