package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Hex;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;
import org.springframework.util.StringUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;

import javax.annotation.Resource;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.*;

/**
 * 荣西子API接单
 */
@Service
@Slf4j
public class RongxiziCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final String qualityCheckPath = "https://admin.qxd-wh.com/home/Api/checkTel";

    private final String applyPath = "http://47.111.167.41:8009/customer/import";



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Rongxizi;
    }


    @Data
    private static class ResultHt{
        private String code;
        private String msg;
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     * {"token":"UWDSdzJHCq3KnrLwuBaPBBGX8Hs0oEY3","vender_name":"birong","appid":"20076","appkey":"05xduuQdn6r46giJji91aXDlzEeOT5Be"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd    configInfo)  {
        try {
            log.info("credit RongxiziCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("荣西子对接参数:{}", JSONObject.toJSONString(config));
            String url = qualityCheckPath;
            log.info("credit qualityCheck RongxiziCreditService request userId:{}, url:{}",userInfo.getUserId(), url);
            HttpHeaders headers = new HttpHeaders();
            headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
            Map map = new HashMap();
            map.put("token",config.getString("token"));
            map.put("tel",userInfo.getUserMobileMD5());
            HttpEntity<String> requestBody = new HttpEntity<String>(JSONObject.toJSONString(map), headers);
            String res = null;
            try{
                ResponseEntity<String> responseEntity = httpRestTemplate.restTemplate().postForEntity(url, requestBody, String.class);
                res = responseEntity.getBody();
            }catch (Exception e){
                log.error("荣西子准入异常,异常信息：{}", e.getMessage(), e);
            }
            if (res == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject result = JSONObject.parseObject(res);
            log.info("credit qualityCheck RongxiziCreditService response userId:{}, result:{}",userInfo.getUserId(), JSONObject.toJSONString(result));
            if (result.getInteger("code") == 200) {
                if (result.getJSONObject("data").getInteger("state") == 0 ) {
                    return DataVo.success(0, "荣西子撞库成功", product.getPlanId());
                }
            }
            return DataVo.fail(1, result.getString("message"), product.getPlanId());

        } catch (Exception e) {
            log.error("荣西子撞库失败", e);
            return DataVo.fail(1, "荣西子撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


    private static String buildPreSign(Map map){

        //将参数转换为map

        Set<String> keys = map.keySet();
        List<String> list = new ArrayList<>();
        for (String key : keys) {
            if(!StringUtils.isEmpty(map.get(key))){
                list.add(key);
            }
        }
        //排序key
        Collections.sort(list);
        //遍历封装排序后key的list,拼接字符串
        StringBuilder sb = new StringBuilder("");
        for (int i=0;i<list.size();i++) {
            if (i==0){
                sb.append(list.get(i)).append("=").append(map.get(list.get(i)));
            }else {
                sb.append("&");
                sb.append(list.get(i)).append("=").append(map.get(list.get(i)));
            }

        }
        return sb.toString();
    }

    private static String sha1(String text){

        // 获取指定摘要算法的messageDigest对象
        MessageDigest messageDigest = null; // 此处的sha代表sha1
        try {
            messageDigest = MessageDigest.getInstance("SHA");
        } catch (NoSuchAlgorithmException e) {
            e.printStackTrace();
        }

        // 调用digest方法，进行加密操作
        byte[] cipherBytes = messageDigest.digest(text.getBytes());

        return Hex.encodeHexString(cipherBytes);
    }
}
