package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/4/17
 * @Version V1.0
 **/
@Slf4j
@Service
public class RxkCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    private final static String CHECK_URL="/xxb-filter/api/filter/md5";
    private final static String REGISTER_URL="/xxb/api/source/clue_data/consumer";


    private final static String CHECK_URL_PRIVATE="/youka/api/user_filter/md5";
    private final static String REGISTER_URL_PRIVATE="/youka/api/clue_data/accept";


    @Data
    private static class CheckInfo {
        private String sourceCode;

        private String accessKey;

        private String phoneMd5;
    }

    @Data
    private static class Result {
        private Integer code;
        private String msg;
        private JSONObject data;
        private boolean success;
    }

    @Data
    private static class ResultRegister {
        private String code;
        private String msg;
        private String data;
        private boolean success;
    }



    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo) {
        log.info("credit RxkCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
        try {
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("融享客对接参数:{}", JSON.toJSONString(config));

            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(userInfo.getUserMobileMD5());
            checkInfo.setSourceCode(config.getString("sourceCode"));
            checkInfo.setAccessKey(config.getString("accessKey"));
            String url;
            if(null !=config.get("private") && config.getBoolean("private")){
                url = config.getString("domain")+CHECK_URL_PRIVATE;
            }else {
                url = config.getString("domain")+CHECK_URL;
            }
            log.info("credit qualityCheck RxkCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            Result response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, Result.class);
            } catch (Exception e) {
                log.error("融享客准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck RxkCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return
                    Objects.equals(1, response.getCode())
                            && Objects.equals(true, response.isSuccess())
                            && Objects.equals(false, response.getData().getBoolean("phoneMd5Exist")) ?
                            DataVo.success(0, "融享客撞库成功", product.getPlanId())
                            : DataVo.fail("融享客-"+product.getPlanName()+"撞库失败", product.getPlanId());

        } catch (Exception e) {
            log.error("融享客撞库失败", e);
            return DataVo.fail(1, "融享客撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.CRM_RXK;
    }

}
