package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.util.HashMap;
import java.util.Map;
/**
 * @Author Liu Tao
 * @Date 2023 09 18 13 40
 **/
@Slf4j
@Service
public class ShanDongBangBangDaiCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ShanDongBangBangDai;
    }

    @Data
    private static class CheckInfo{
        private String mobile_md5;//md5 的手机号
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit ShanDongBangBangDaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("山东帮帮代对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobile_md5(phoneMd5);
            String checkUrl = config.getString("checkUrl");
            String url=checkUrl+"?company="+config.getString("checkCompany")+"&mobile_md5="+checkInfo.getMobile_md5();
            log.info("credit qualityCheck ShanDongBangBangDaiCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().getForObject(url, String.class);
            }catch (Exception e){
                log.error("山东帮帮代准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ShanDongBangBangDaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 0) {
                return DataVo.success(0, "山东帮帮代撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "山东帮帮代撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("山东帮帮代撞库失败", e);
            return DataVo.fail(1, "山东帮帮代撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


    public static class AESUtil {

        // mode_key:Cipher
        private static final Map<String, Cipher> CIPHERMAP_MAP = new HashMap<String, Cipher>();

        // constants
        private static final String DEFAULT_CHARSET = "utf-8";
        private static final String ALGORITHM_NAME = "AES";
        private static final String ALGORITHM_STR = ALGORITHM_NAME + "/CBC/PKCS5Padding";
        private static final String IV = "0000000000000000";

        /**
         * get cipher
         *
         * @param mode
         * @param key
         * @param charset
         * @return
         * @throws Exception
         */
        private static Cipher getCipher(int mode, String key, String charset) throws Exception {
            Cipher cipher = CIPHERMAP_MAP.get(mode + "_" + key);
            if (cipher != null) {
                return cipher;
            }

            // secretKeySpec
            SecretKeySpec secretKeySpec = new SecretKeySpec(key.getBytes(charset), ALGORITHM_NAME);
            // ivParameterSpec
            IvParameterSpec ivParameterSpec = new IvParameterSpec(IV.getBytes(charset));
            // cipher
            cipher = Cipher.getInstance(ALGORITHM_STR);
            cipher.init(mode, secretKeySpec, ivParameterSpec);
            // return
            CIPHERMAP_MAP.put(mode + "_" + key, cipher);
            return cipher;
        }

        public static String encrypt(String a, String key, String charset) throws Exception {
            Cipher cipher = getCipher(Cipher.ENCRYPT_MODE, key, charset);
            byte[] resultByte = cipher.doFinal(a.getBytes(charset));
            return base64BytesToString(resultByte, charset);
        }

        public static String encrypt(String a, String key) throws Exception {
            return encrypt(a, key, DEFAULT_CHARSET);
        }

        public static String decrypt(String a, String key, String charset) throws Exception {
            Cipher cipher = getCipher(Cipher.DECRYPT_MODE, key, charset);
            byte[] inputByte = base64stringToBytes(a, charset);
            byte[] resultByte = cipher.doFinal(inputByte);
            return new String(resultByte, charset);
        }

        public static String decrypt(String a, String key) throws Exception {
            return decrypt(a, key, DEFAULT_CHARSET);
        }

        private static String base64BytesToString(byte[] bytes, String charset) throws Exception {
            return new String(Base64.encodeBase64(bytes), charset);
        }

        private static byte[] base64stringToBytes(String string, String charset) throws Exception {
            return Base64.decodeBase64(string.getBytes(charset));
        }


    }
}
