package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Base64;

/**
 * @Author Liu Tao
 * @Date 2023 11 01 17 49
 **/
@Slf4j
@Service
public class ShanXiHengShengDaiCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ShanXiHengSheng;
    }
    @Data
    private static class CheckInfo{
        private String md5mobile;//md5 的手机号
        private String brand;//品牌对应数字(比如 6)
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
    {
    "checkUrl": "https://www2.zhudaicms.com/sem/check_canindb.html",
    "applyUrl": "https://www2.zhudaicms.com/sem/loan_do_aes_cbc_new.html",
    "source": "hsjf-hryk",
    "brand": "609",
    "publickey": "zhudai#aes#cbc#1",
    "iv": "2022042215123456"
    }
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit ShanXiHengShengDaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("山西恒昇对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMd5mobile(phoneMd5);
            checkInfo.setBrand(config.getString("brand"));
            String url = config.getString("checkUrl");
            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            params.add("md5mobile", phoneMd5);
            params.add("brand", config.getString("brand"));
            log.info("credit qualityCheck ShanXiHengShengDaiCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                HttpHeaders headers = new HttpHeaders();
                headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
                HttpEntity<MultiValueMap<String, String>> requestEntity = new HttpEntity<MultiValueMap<String, String>>(params, headers);
                response = httpRestTemplate.restTemplate().postForEntity(url, requestEntity, String.class).getBody();
            }catch (Exception e){
                log.error("山西恒昇准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ShanXiHengShengDaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            if (response.equals("1")) {
                return DataVo.success(0, "山西恒昇撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "山西恒昇撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("山西恒昇撞库失败", e);
            return DataVo.fail(1, "山西恒昇撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


    public static String encrypt(String plainText, String key, String iv) throws Exception {
        // 将 key 转换为 SecretKey 对象
        SecretKey secretKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
        // 将 IV 字符串转换为字节数组
        byte[] ivBytes = iv.getBytes(StandardCharsets.UTF_8);
        // 生成 IV
        // 创建 Cipher 对象
        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
        cipher.init(Cipher.ENCRYPT_MODE, secretKey, new IvParameterSpec(ivBytes));
        // 加密明文
        byte[] encryptedBytes = cipher.doFinal(plainText.getBytes(StandardCharsets.UTF_8));
        // 将加密后的字节转换为 Base64 编码
        return Base64.getEncoder().encodeToString(encryptedBytes);
    }
}
