package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;

/**
 * @Author Liu Tao
 * @Date 2024 07 22 14 13
 **/
@Service
@Slf4j
public class ShanXiMingDePuHuiCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ShanXiMingDePuHui;
    }

    @Data
    private static class CheckInfo {
        private String tel;// 明文电话号码Md5加密值(小写)，用于判断是否重复
    }



    @Data
    private static class RequestData {

        private String data;
        private String source;
        private String sourceName;
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit ShanXiMingDePuHuiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("陕西明德普惠对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");

            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setTel(phoneMd5);

            log.info("credit qualityCheck ShanXiMingDePuHuiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, String.class);
            } catch (Exception e) {
                log.error("陕西明德普惠准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ShanXiMingDePuHuiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code").equals(200) && jsonObject.getBoolean("isSuccess")) {
                return DataVo.success(0, "陕西明德普惠撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "陕西明德普惠撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("陕西明德普惠撞库失败", e);
            return DataVo.fail(1, "陕西明德普惠撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    /**
     * AES 加密
     *
     * @param str 待加密内容
     * @param key 加密key
     * @return 加密内容
     */
    public static String encryptAES(String str, String key) {
        try {
            byte[] raw = key.getBytes(StandardCharsets.UTF_8);
            SecretKeySpec secretKeySpec = new SecretKeySpec(raw, "AES");
            Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
            cipher.init(Cipher.ENCRYPT_MODE, secretKeySpec);
            byte[] encrypted = cipher.doFinal(str.getBytes(StandardCharsets.UTF_8));
            return Base64.encodeBase64String(encrypted);
        } catch (Exception e) {
            log.error("AES 加密异常", e);
            throw new RuntimeException(e);
        }
    }


}
