package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Component;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2024 06 05 14 46
 **/
@Slf4j
@Component
public class ShangHaiHanGeCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ShangHaiHanGe;
    }

    @Data
    private static class CheckInfo {
        private String MobilePhone;// 手机号（32位MD5加密字符串）
    }



    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("上海晗各对接参数:{}", JSONObject.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            log.info("上海晗各开始撞库,请求地址：{},md5:{}", url, phoneMd5);
            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            params.add("MobilePhone", phoneMd5);
            String response = null;
            try{
                HttpHeaders headers = new HttpHeaders();
                headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
                HttpEntity<MultiValueMap<String, String>> requestEntity = new HttpEntity<MultiValueMap<String, String>>(params, headers);
                response = httpRestTemplate.restTemplate().postForEntity(url, requestEntity, String.class).getBody();
            } catch (Exception e) {
                log.error("上海晗各准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("上海晗各撞库响应：{},md5:{}", response, phoneMd5);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject.getString("Ret").equals("0")&&jsonObject.getString("Code").equals("100")) {
                return DataVo.success(0, "上海晗各撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "上海晗各撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "上海晗各撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
