package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Base64;
import java.util.HashMap;
import java.util.Map;
import java.util.TreeMap;

/**
 * @Author Liu Tao
 * @Date 2024 03 12 14 03
 **/
@Slf4j
@Service
public class ShiYueCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ShiYue;
    }

    @Data
    private static class CheckInfo{
        private Integer app_id;//渠道编码
        private String timestamp;//时间戳
        private String sign;//签名
        private String mobile;//md5加密后的手机号，32位小写
    }
    /*
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit ShiYueCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("司跃对接参数:{}", JSON.toJSONString(config));

            Map<String, String> map = new HashMap<>();
            map.put("app_id",config.getString("app_id"));
            map.put("mobile",(userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5()));
            map.put("timestamp",System.currentTimeMillis()/1000+"");
            String sign = makeSign(map, config.getString("token"));
            map.put("sign",sign);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck ShiYueCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, map);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,map, String.class);
            }catch (Exception e){
                log.error("司跃准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ShiYueCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("code") .equals("20000")) {
                return DataVo.success(0, "司跃撞库成功", product.getPlanId());
            } else {
                return  DataVo.fail(1, "司跃撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("司跃撞库失败", e);
            return DataVo.fail(1, "司跃撞库失败，请联系系统管理员", product.getPlanId());
        }

    }



    public static String makeSign(Map<String, String> args, String token) {
        if (args == null || token == null) {
            return "";
        }

        Map<String, String> sortedArgs = new TreeMap<>(args);

        StringBuilder signStr = new StringBuilder();
        for (Map.Entry<String, String> entry : sortedArgs.entrySet()) {
            String key = entry.getKey();
            String value = entry.getValue();
            if (value != null && !value.isEmpty()) {
                signStr.append(key).append(value);
            }
        }

        System.out.println(signStr.toString());

        return md5(md5(signStr.toString()) + token).toUpperCase();
    }

    private static String md5(String str) {
        try {
            MessageDigest md = MessageDigest.getInstance("MD5");
            md.update(str.getBytes());
            byte[] digest = md.digest();

            StringBuilder sb = new StringBuilder();
            for (byte b : digest) {
                sb.append(String.format("%02x", b & 0xff));
            }

            return sb.toString();
        } catch (NoSuchAlgorithmException e) {
            e.printStackTrace();
            return "";
        }
    }

    // 加密
    public static String encrypt(String sSrc, String sKey) throws Exception {
        if (sKey == null) {
            System.out.print("Key为空null");
            return null;
        }
        // 判断Key是否为16位
        if (sKey.length() != 16) {
            System.out.print("Key长度不是16位");
            return null;
        }
        byte[] raw = sKey.getBytes("utf-8");
        SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
        Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");//"算法/模式/补码方式"
        cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
        byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));

        return Base64.getEncoder().encodeToString(encrypted);//此处使用BASE64做转码功能，同时能起到2次加密的作用。
    }


}
