package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.SecretKeyFactory;
import javax.crypto.spec.DESKeySpec;
import javax.crypto.spec.IvParameterSpec;
import java.security.Key;
import java.util.Base64;
/**
 * @Author Liu Tao
 * @Date 2024 03 20 13 50
 **/
@Slf4j
@Service
public class SouYuJinFuCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.SouYuJinFu;
    }

    @Data
    private static class CheckInfo{
        private String phone;//手机号码md5(32位，字母小写)
    }



    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit SouYuJinFuCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("授渔金服对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhone((userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5()));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck SouYuJinFuCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            } catch (Exception e) {
                log.error("授渔金服准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck SouYuJinFuCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            log.info("credit qualityCheck SouYuJinFuCreditService response userId:{}, jsonObject:{}", userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("businessCode").equals("200")) {
                return DataVo.success(0, "授渔金服撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "授渔金服撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("授渔金服撞库失败", e);
            return DataVo.fail(1, "授渔金服撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


    public static class DESUtil {

        private static final Logger log = LoggerFactory.getLogger(DESUtil.class);

        /**
         * 偏移变量，固定占8位字节
         */
        private final static String IV_PARAMETER = "12345678";

        private static final String ALGORITHM = "DES";

        private static final String CIPHER_ALGORITHM = "DES/CBC/PKCS5Padding";

        private static final String CHARSET = "utf-8";

        /**
         * 解密
         * @param key 密钥
         * @param data 密文
         * @return  解密后的内容
         */
        public static String decrypt(String key, String data) {
            if(StringUtils.isBlank(key))
                throw new RuntimeException("缺少key");
            if(StringUtils.isBlank(data))
                throw new RuntimeException("加密对象空的");
            try {
                Key secretKey = generateKey(key);
                Cipher cipher = Cipher.getInstance(CIPHER_ALGORITHM);
                IvParameterSpec iv = new IvParameterSpec(IV_PARAMETER.getBytes(CHARSET));
                cipher.init(Cipher.DECRYPT_MODE, secretKey,iv);
                return new String(cipher.doFinal(Base64.getDecoder().decode(data.getBytes(CHARSET))), CHARSET);
            } catch (Exception e) {
                log.error("key-{},data-{},DES解密异常:{}-{}",key,data,e.getMessage(),e);
                return null;
            }
        }


        /**
         * 加密
         * @param key 密钥
         * @param data 待加密的内容
         * @return 密文
         */
        public static String encrypt(String key, String data) {
            if (key== null || key.length() < 8) {
                throw new RuntimeException("加密失败，key不能小于8位");
            }
            if (data == null)
                return null;
            try {
                Key secretKey = generateKey(key);
                Cipher cipher = Cipher.getInstance(CIPHER_ALGORITHM);
                IvParameterSpec iv = new IvParameterSpec(IV_PARAMETER.getBytes(CHARSET));
                cipher.init(Cipher.ENCRYPT_MODE, secretKey,iv);
                byte[] bytes = cipher.doFinal(data.getBytes(CHARSET));
                //JDK1.8及以上可直接使用Base64，JDK1.7及以下可以使用BASE64Encoder
                //Android平台可以使用android.util.Base64
                return new String(Base64.getEncoder().encode(bytes));
            } catch (Exception e) {
                log.error("key-{},data-{},DES加密异常:{}-{}",key,data,e.getMessage(),e);
                return null;
            }
        }

        /**
         * 生成key
         *
         * @param password
         * @return
         * @throws Exception
         */
        private static Key generateKey(String password) throws Exception {
            DESKeySpec dks = new DESKeySpec(password.getBytes(CHARSET));
            SecretKeyFactory keyFactory = SecretKeyFactory.getInstance(ALGORITHM);
            return keyFactory.generateSecret(dks);
        }
    }
}
