package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;

/**
 * @Author Tianli
 * @Date 2023 11 08.
 * 苏州昌硕API接单
 **/
@Service
@Slf4j
public class SuzhouchangshuoCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Suzhouchangshuo;
    }

    @Data
    public static class CheckData{
        private String tel;
    }

    /*@Data
    private static class CheckInfo{
        private String phoneMd5;

        private String sign;

        private String areaName;


    }*/
    @Data
    private static class ResultHt{
        private String code;
        private String msg;
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit SuzhouchangshuoCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("苏州昌硕对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            /*checkInfo.setPhoneMd5(phoneMd5);
            AreaCity cityInfoByCode = cityService.getCityInfoByCode(userInfo.getCityCode());
            checkInfo.setAreaName(cityInfoByCode.getCityName());
//实体类转为JSONObject
            JSONObject jsons = JSONObject.parseObject(JSON.toJSONString(checkInfo));
            jsons.remove("sign");
            String sign = getSign(jsons,config.getString("signKey"));
            checkInfo.setSign(MSDSUtils.MD5.EncoderByMd5(sign));
            CheckData checkData = new CheckData();
            checkData.setParams(AESencrypt(JSONObject.toJSONString(checkInfo),config.getString("encKey")));
            checkData.setMerNo(config.getString("merNo"));*/
            CheckData checkData = new CheckData();
            checkData.setTel(phoneMd5);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck SuzhouchangshuoCreditService request userId:{}, url:{}, checkData:{}",userInfo.getUserId(), url, checkData);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkData, String.class);
            }catch (Exception e){
                log.error("苏州昌硕准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck SuzhouchangshuoCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 0) {
                return DataVo.success(0, "苏州昌硕撞库成功", product.getPlanId());
            }else if (jsonObject.getInteger("code") == 1) {
                return DataVo.fail(1, "苏州昌硕撞库失败，该数据对方已存在", product.getPlanId());
            } else {
                return DataVo.fail(1, "苏州昌硕撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("苏州昌硕撞库失败", e);
            return DataVo.fail(1, "苏州昌硕撞库失败，请联系系统管理员", product.getPlanId());
        }

    }



    public static String encrypt(String sSrc, String sKey) throws Exception {

        // 判断Key是否为16位
        if (sKey.length() != 16) {
            System.out.print("Key长度不是16位");
            return null;
        }
        byte[] raw = sKey.getBytes("utf-8");
        SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
        Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");//"算法/模式/补码方式"
        cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
        byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));

        return new Base64().encodeToString(encrypted);//此处使用BASE64做转码功能，同时能起到2次加密的作用。
    }






}
