package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import javax.annotation.Resource;
/**
 * @Author Liu Tao
 * @Date 2024 07 22 14 13
 **/
@Service
@Slf4j
public class TangShanRongYangCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ThangSanRongYang;
    }

    @Data
    private static class CheckInfo {
        private String md5_phone;// Md5(mobile)
    }


    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit TangShanRongYangCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("唐山融扬对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setMd5_phone(phoneMd5);
            log.info("credit qualityCheck TangShanRongYangCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, String.class);
            } catch (Exception e) {
                log.error("唐山融扬准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck TangShanRongYangCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("resStatus").equals("1")) {
                return DataVo.success(0, "唐山融扬撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "唐山融扬撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("唐山融扬撞库失败", e);
            return DataVo.fail(1, "唐山融扬撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

}
