package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/2/16
 * @Version V1.0
 **/
@Service
@Slf4j
public class TuoBaoRongCreditService implements LoanDockingApi {

    private static final String checkPath = "api/check";
    private static final String applyPath = "api/apply";

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;



    @Data
    private static class CheckInfo {
        private String trafficsources;
        private String md5_mobile;
    }

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.TuoBaoRong;
    }



    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit TuoBaoRongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("拓宝荣对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setMd5_mobile(userInfo.getUserMobileMD5());
            checkInfo.setTrafficsources(config.getString("channelSource"));

            JSONObject param = new JSONObject() {{
                put("data", encrypt(JSON.toJSONString(checkInfo), config.getString("secret")));
            }};

            String url = config.getString("url") + checkPath;
            log.info("credit qualityCheck TuoBaoRongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            JSONObject response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, param, JSONObject.class);
            } catch (Exception e) {
                log.error("拓宝荣准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck TuoBaoRongCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return Objects.equals("200", response.getString("code")) ? DataVo.success(0, "拓宝荣撞库成功", product.getPlanId())
                    : DataVo.fail(response.getString("msg"), product.getPlanId());

        } catch (Exception e) {
            log.error("拓宝荣撞库失败", e);
            return DataVo.fail(1, "拓宝荣撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


    public static String encrypt(String sSrc, String sKey) throws Exception {
        if (sKey == null) {
            return null;
        }
        // 判断 Key 是否为 16 位
        if (sKey.length() != 16) {
            return null;
        }

        byte[] raw = sKey.getBytes("utf-8");
        SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
        // "算法/模式/补码方式"
        Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
        cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
        byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));
        return bytesToHexString(encrypted);
    }


    public static String bytesToHexString(byte[] src) {
        StringBuilder stringBuilder = new StringBuilder("");
        if (src == null || src.length <= 0) {
            return null;
        }
        for (int i = 0; i < src.length; i++) {
            int v = src[i] & 0xFF;
            String hv = Integer.toHexString(v);
            if (hv.length() < 2) {
                stringBuilder.append(0);
            }
            stringBuilder.append(hv);
        }
        return stringBuilder.toString();
    }

}
