package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;


/**
 * @Author Liu Tao
 * @Date 2024 07 03 16 14
 **/
@Slf4j
@Service
public class WeiFangHuaShenCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.WeiFangHuaShenCreditService;
    }

    @Data
    private static class CheckInfo{
        private Integer channel_code;//渠道编码，由负责人提供
        private String md5_phone;//md5加密后的手机号，32位小写
    }



    /**
     * 助贷对接模板2，撞库，需要form表单提交
     * @param userInfo
     * @param product
     * @return
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit WeiFangHuaShenCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("潍坊华盛对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMd5_phone(phoneMd5);
            checkInfo.setChannel_code(config.getInteger("channel_code"));

            Map<String, String> requestData = new HashMap<>();
            requestData.put("channel_code", String.valueOf(checkInfo.getChannel_code()));
            requestData.put("md5_phone", String.valueOf(checkInfo.getMd5_phone()));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck WeiFangHuaShenCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            JSONObject response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/x-www-form-urlencoded");
                HttpResponse httpResponse = httpRestTemplate.restTemplate().postForObject(url, null, null, head, null, requestData);
                String responseStr = EntityUtils.toString(httpResponse.getEntity());
                response = JSONObject.parseObject(responseStr);
            }catch (Exception e){
                log.error("潍坊华盛准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck WeiFangHuaShenCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (response.getInteger("code")==0) {
                return DataVo.success(0, "潍坊华盛撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "潍坊华盛撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("潍坊华盛撞库失败", e);
            return DataVo.fail(1, "潍坊华盛撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
