package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.*;

/**
 * @Author Liu Tao
 * @Date 2023 12 22 09 42
 **/
@Slf4j
@Service
public class WenZhouGaoShenCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.WenZhouGaoShen;
    }

    @Data
    private static class CheckInfo {
        private String appKey;//appKey
        private String phone;//手机
        private String isMask;//是否加密，默认0 不加密；1加密
        private String Sign;//
    }


    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit WenZhouGaoShenCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("温州高升对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhone((userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5()));
            checkInfo.setIsMask("1");
            checkInfo.setAppKey(config.getString("appKey"));
            String sign="appKey="+config.getString("appKey")+"&phone="+checkInfo.getPhone()+config.getString("appSecret");
            log.info("温州高升对接sign:{}", JSON.toJSONString(sign));
            checkInfo.setSign(Md5Util.encoderByMd5(sign).toUpperCase());
            String url = config.getString("post")+config.getString("tenantCode")+"/"+config.getString("check");
            log.info("credit qualityCheck WenZhouGaoShenCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                response =httpRestTemplate.restTemplate().postForObject(url,checkInfo, String.class);
            } catch (Exception e) {
                log.error("温州高升准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck WenZhouGaoShenCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            log.info("credit qualityCheck WenZhouGaoShenCreditService response userId:{}, jsonObject:{}", userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("errCode") == 0 && jsonObject.getString("data").equals("true")) {
                return DataVo.success(0, "温州高升撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "温州高升撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("温州高升撞库失败", e);
            return DataVo.fail(1, "温州高升撞库失败，请联系系统管理员", product.getPlanId());
        }
    }



    public static String encrypt(String str, String key) {
        try {
            byte[] raw = key.getBytes(StandardCharsets.UTF_8);
            SecretKeySpec secretKeySpec = new SecretKeySpec(raw, "AES");
            Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
            cipher.init(Cipher.ENCRYPT_MODE, secretKeySpec);
            byte[] encrypted = cipher.doFinal(str.getBytes(StandardCharsets.UTF_8));
            return HEX(encrypted);
        } catch (Exception e) {
            log.error("AES 加密异常", e);
            throw new RuntimeException(e);
        }
    }

    public static String HEX(byte[] bytes) {
        StringBuilder hexString = new StringBuilder();
        for (byte b : bytes) {
            String hex = Integer.toHexString(0xff & b);
            if (hex.length() == 1) {
                hexString.append('0');
            }
            hexString.append(hex);
        }
        return hexString.toString();
    }

    /**
     * 计算签名
     *
     * @param params
     * @return
     */
    public static String getSign(JSONObject params, String key) {
        String sortStr = getFormatParams(params);
        System.out.println("sortStr = " + sortStr);
        //第二步：将tradeKey拼接在1中排序后的字符串后面得到待签名字符串。
        sortStr += "&"+ key;
        System.out.println("sortStr = " + sortStr);
        //sortStr += "key=BF1BDE5A649724056F904A9335B1C1C9";
        //第三步：使用md5算法加密待加密字符串并转为大写即为sign
//        String sign = DigestUtils.md5DigestAsHex(sortStr.getBytes()).toUpperCase();
//        System.out.println("sign = " + sign);
        return sortStr;
    }

    /**
     * 字典排序
     * 获得参数格式化字符串
     * 参数名按字典排序，小写在后面
     */
    private static String getFormatParams(Map<String, Object> params) {
        List<Map.Entry<String, Object>> infoIds = new ArrayList<Map.Entry<String, Object>>(params.entrySet());
        Collections.sort(infoIds, new Comparator<Map.Entry<String, Object>>() {
            public int compare(Map.Entry<String, Object> arg0, Map.Entry<String, Object> arg1) {
                return (arg0.getKey()).compareTo(arg1.getKey());
            }
        });
        String ret = "";
        for (Map.Entry<String, Object> entry : infoIds) {
            ret += entry.getValue();
            ret += "&";
        }
        ret = ret.substring(0, ret.length() - 1);
        return ret;
    }

}
