package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.codec.digest.DigestUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.security.MessageDigest;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author Liu Tao
 * @Date 2023 09 25 15 22
 * 厦门易捷助代API
 **/
@Slf4j
@Service
public class XiaMenYiJieZhuDaiCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XiaMenYiJieZhuDai;
    }


    @Data
    private static class CheckInfo{
        private String mobile;//md5 的手机号
    }

    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit XiaMenYiJieZhuDaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("厦门易捷助代对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setMobile(phoneMd5);
            String url = config.getString("checkUrl");
            String appid = config.getString("appid");
            long timestamp = System.currentTimeMillis() / 1000;
            String t = String.valueOf(timestamp);
            String k = config.getString("key");
            String sign = generateHash(appid, t, k);

            log.info("credit qualityCheck XiaMenYiJieZhuDaiCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            String response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/json");
                head.put("appid",appid);
                head.put("t", t);
                head.put("sign", sign);
                String httpResponse = httpRestTemplate.restTemplate().postForObject(url,  head, String.class,JSONObject.toJSONString(checkInfo));
                log.info("credit qualityCheck XiaMenYiJieZhuDaiCreditService response userId:{}, result:{}",userInfo.getUserId(), httpResponse);
            }catch (Exception e){
                log.error("厦门易捷助代准入异常,异常信息：{}", e.getMessage(), e);
            }
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 200) {
                return DataVo.success(0, "厦门易捷助代撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "厦门易捷助代撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("厦门易捷助代撞库失败", e);
            return DataVo.fail(1, "厦门易捷助代撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

    public static String encrypt(String data, String key, String ivStr) {
        try {
            Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
            SecretKeySpec keySpec = new SecretKeySpec(key.getBytes("UTF-8"), "AES");
            IvParameterSpec ivSpec = new IvParameterSpec(ivStr.getBytes("UTF-8"));
            cipher.init(Cipher.ENCRYPT_MODE, keySpec, ivSpec);
            byte[] encrypted = cipher.doFinal(data.getBytes("UTF-8"));

            return java.util.Base64.getEncoder().encodeToString(encrypted);
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }
    //加密算法
    public static class AesUtils {

        /**
         * ECB
         */
        /*** 加密 * @param sSrc 加密内容 * @param sKey 加密 key * @return * @throws Exception */
        public static String Encrypt(String sSrc, String sKey) throws Exception {
            if (sKey == null) {
                System.out.print("Key 为空 null");
                return null;
            }// 判断 Key 是否为 16 位
            if (sKey.length() != 16) {
                System.out.print("Key 长度不是 16 位");
                return null;
            }
            byte[] raw = sKey.getBytes("utf-8");
            SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES"); // "算法/模式/补码方式"
            Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
            cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
            byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8")); // 此处使用 BASE64 做转码功能，同时能起到 2 次加密的作用。
            return Base64.encodeBase64String(encrypted);
        }

        /**
         * sha1
         * @param message
         * @return
         */
        public static String  sha1(String message){
            return DigestUtils.sha1Hex(message.getBytes());
        }


        /**
         * 0填充
         * @param data
         * @param key
         * @param ivStr
         * @return
         */
        //加密
        public static String encryptCBC2(String data, String key,String ivStr) {
            String ivString = ivStr;
            //偏移量
            byte[] iv = ivString.getBytes();
            try {
                Cipher cipher = Cipher.getInstance("AES/CBC/NoPadding");
                int blockSize = cipher.getBlockSize();
                byte[] dataBytes = data.getBytes();
                int length = dataBytes.length;
                //计算需填充长度
                if (length % blockSize != 0) {
                    length = length + (blockSize - (length % blockSize));
                }
                byte[] plaintext = new byte[length];
                //填充
                System.arraycopy(dataBytes, 0, plaintext, 0, dataBytes.length);
                SecretKeySpec keySpec = new SecretKeySpec(key.getBytes(), "AES");
                //设置偏移量参数
                IvParameterSpec ivSpec = new IvParameterSpec(iv);
                cipher.init(Cipher.ENCRYPT_MODE, keySpec, ivSpec);
                byte[] encryped = cipher.doFinal(plaintext);

                return Base64.encodeBase64String(encryped);

            } catch (Exception e) {
                e.printStackTrace();
                return null;
            }
        }
    }

    public static String generateHash(String appId, String timestamp, String privateKey) throws Exception {
        String hashString = appId + timestamp;
        // 计算 SHA-1 hash
        MessageDigest sha1 = MessageDigest.getInstance("SHA-1");
        byte[] hashedBytes = sha1.digest(hashString.getBytes("UTF-8"));
        // 将 SHA-1 hash 转为 hex 字符串
        StringBuffer hexStringBuffer = new StringBuffer();
        for (int i = 0; i < hashedBytes.length; i++) {
            String hex = Integer.toHexString(0xff & hashedBytes[i]);
            if (hex.length() == 1) hexStringBuffer.append('0');
            hexStringBuffer.append(hex);
        }
        String sha1HexString = hexStringBuffer.toString();

        // 计算 MD5 hash
        hashString = sha1HexString + privateKey;
        MessageDigest md5 = MessageDigest.getInstance("MD5");
        hashedBytes = md5.digest(hashString.getBytes("UTF-8"));

        // 将 MD5 hash 转为 hex 字符串
        hexStringBuffer = new StringBuffer();
        for (int i = 0; i < hashedBytes.length; i++) {
            String hex = Integer.toHexString(0xff & hashedBytes[i]);
            if (hex.length() == 1) hexStringBuffer.append('0');
            hexStringBuffer.append(hex);
        }
        return hexStringBuffer.toString();
    }
}
