package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.lang3.StringUtils;
import org.apache.tomcat.util.http.fileupload.IOUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import java.io.ByteArrayOutputStream;
import java.security.KeyFactory;
import java.security.NoSuchAlgorithmException;
import java.security.interfaces.RSAPrivateKey;
import java.security.interfaces.RSAPublicKey;
import java.security.spec.InvalidKeySpecException;
import java.security.spec.PKCS8EncodedKeySpec;
import java.security.spec.X509EncodedKeySpec;


/**
 * @Descrption
 * @Author: zhangyy
 * @Date: 2023/5/8
 * @Version V1.0
 **/
@Service
@Slf4j
public class XiangKeDaCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.CRM_XKD;
    }


    @Data
    private static class CredentialStuffingDto {
        private Integer companyId;

        private String customerPhone;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"url":"http://apitest.shlyxxjs.com","key":"fluxZhudai*_key","tenantId":"1405729496904110081","trafficPlatformId":"13872425018351111"}
     */
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo) {
        try {
            // 同业买量数据适配
            if(userInfo.getUserMobile() == null && userInfo.getUserMobileMD5() != null){
                return DataVo.success("撞库失败"+userInfo.getUserMobileMD5(), product.getPlanId());
            }
            log.info("credit XiangKeDaCreditService qualityCheck begin...userId:{},productId={}", userInfo.getUserId(), product.getPlanId());
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            if (StringUtils.isBlank(configJson)) {
                return DataVo.success("撞库失败"+userInfo.getUserMobileMD5(), product.getPlanId());
            }
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("享客达对接参数:{}", JSON.toJSONString(config));
            CredentialStuffingDto dto = new CredentialStuffingDto();
            dto.setCompanyId(config.getInteger("companyId"));
            String param = AesUtil.publicEncrypt(userInfo.getUserMobile(), config.getString("publicKey"));
            dto.setCustomerPhone(Md5Util.encoderByMd5(param));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck XiangKeDaCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, JSON.toJSONString(dto));
            String response = null;
            try {
//                + MSDSUtils.MD5.EncoderByMd5(param)
                response = httpRestTemplate.restTemplate().postForObject(url, dto, String.class);
            } catch (Exception e) {
                log.error("【{}】-享客达惠准入异常,异常信息：{}", product.getPlanName(), e.getMessage(), e);
            }
            log.info("credit qualityCheck XiangKeDaCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject res = JSONObject.parseObject(response);
            if (res.getInteger("code") == 0 && res.getBoolean("data")) {
                return DataVo.success(0, "【" + product.getPlanName() + "】-享客达撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(res.getString("msg"), product.getPlanId());
            }
        } catch (Exception e) {
            log.error("【{}】-享客达撞库失败", product.getPlanName(), e);
            return DataVo.fail(1, "享客达撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


    public static class AesUtil {

        // 算法类别
        public static final String RSA_ALGORITHM = "RSA";
        public static final String CHARSET = "UTF-8";
        // 算法位数
        private final static Integer KEY_SIZE = 2048;


        /*
         * 得到私钥
         * @param privateKey 密钥字符串（经过base64编码）
         * @throws Exception
         */
        public static RSAPrivateKey getPrivateKey(String privateKey) throws NoSuchAlgorithmException, InvalidKeySpecException {
            //通过PKCS#8编码的Key指令获得私钥对象
            KeyFactory keyFactory = KeyFactory.getInstance(RSA_ALGORITHM);
            PKCS8EncodedKeySpec pkcs8KeySpec = new PKCS8EncodedKeySpec(Base64.decodeBase64(privateKey));
            RSAPrivateKey key = (RSAPrivateKey) keyFactory.generatePrivate(pkcs8KeySpec);
            return key;
        }

        /**
         * 得到公钥
         *
         * @param publicKey 密钥字符串（经过base64编码）
         * @throws Exception
         */
        public static RSAPublicKey getPublicKey(String publicKey) throws NoSuchAlgorithmException, InvalidKeySpecException {
            //通过X509编码的Key指令获得公钥对象
            KeyFactory keyFactory = KeyFactory.getInstance(RSA_ALGORITHM);
            X509EncodedKeySpec x509KeySpec = new X509EncodedKeySpec(Base64.decodeBase64(publicKey));
            RSAPublicKey key = (RSAPublicKey) keyFactory.generatePublic(x509KeySpec);
            return key;
        }


        /*
         * 公钥加密
         * @param data
         * @param publicKey
         * @return
         */
        public static String publicEncrypt(String data, String publicString) {
            try {
                RSAPublicKey publicKey = getPublicKey(publicString);
                Cipher cipher = Cipher.getInstance(RSA_ALGORITHM);
                cipher.init(Cipher.ENCRYPT_MODE, publicKey);
                return Base64.encodeBase64URLSafeString(rsaSplitCodec(cipher, Cipher.ENCRYPT_MODE, data.getBytes(CHARSET), publicKey.getModulus().bitLength()));
            } catch (Exception e) {
                throw new RuntimeException("加密字符串[" + data + "]时遇到异常", e);
            }
        }

        //rsa切割解码  , ENCRYPT_MODE 加密数据   ,DECRYPT_MODE 解密数据
        private static byte[] rsaSplitCodec(Cipher cipher, int opmode, byte[] datas, int keySize) {
            int maxBlock = 0;  //最大块
            if (opmode == Cipher.DECRYPT_MODE) {
                maxBlock = keySize / 8;
            } else {
                maxBlock = keySize / 8 - 11;
            }
            ByteArrayOutputStream out = new ByteArrayOutputStream();
            int offSet = 0;
            byte[] buff;
            int i = 0;
            try {
                while (datas.length > offSet) {
                    if (datas.length - offSet > maxBlock) {
                        //可以调用以下的doFinal（）方法完成加密或解密数据：
                        buff = cipher.doFinal(datas, offSet, maxBlock);
                    } else {
                        buff = cipher.doFinal(datas, offSet, datas.length - offSet);
                    }
                    out.write(buff, 0, buff.length);
                    i++;
                    offSet = i * maxBlock;
                }
            } catch (Exception e) {
                throw new RuntimeException("加解密阀值为[" + maxBlock + "]的数据时发生异常", e);
            }
            byte[] resultDatas = out.toByteArray();
            IOUtils.closeQuietly(out);
            return resultDatas;
        }

        /*
         * 解密
         * */
        public static String privateDecrypt(String data, String privateString) {
            try {
                RSAPrivateKey privateKey = getPrivateKey(privateString);
                Cipher cipher = Cipher.getInstance("RSA");
                cipher.init(Cipher.DECRYPT_MODE, privateKey);
                return new String(rsaSplitCodec(cipher, Cipher.DECRYPT_MODE, Base64.decodeBase64(data), privateKey.getModulus().bitLength()), "UTF-8");
            } catch (Exception e) {
                throw new RuntimeException("解密字符串[" + data + "]时遇到异常", e);
            }
        }
    }


}
