package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;

/**
 * 壹融API接单
 */
@Service
@Slf4j
public class XiangRongCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XiangRong;
    }


    @Data
    private static class CheckInfo {
        private String mobile;
        private String file_id;
        private String channelSource;
    }

    @Data
    private static class ResultHt {
        private String code;
        private String data;
        private String msg;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit xiangrongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setMobile(userInfo.getUserMobileMD5());
            checkInfo.setFile_id(config.getString("fileId"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck xiangrongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, String.class);
                log.info("fanhui");
            } catch (Exception e) {
                log.error("宁波享融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck xiangrongCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            JSONObject jsonObject = JSON.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.get("code").equals("0")) {
                return DataVo.success(0, "宁波享融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "宁波享融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("宁波古可撞库失败", e);
            return DataVo.fail(1, "宁波享融撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


    private static class ApiAesUtil {
        //AES/128/ECB
        private static final String AES = "AES";
        private static final String SP = "SHA1PRNG";
        private static final String CHARACTER = "utf-8";
        private static final String ALGO = "AES/ECB/PKCS5Padding"; // 使用AES算法，ECB模式，PKCS5Padding填充

        public static String decrypt(String sSrc, String sKey) {
            try {
                // 判断Key是否正确
                if (sKey == null) {
                    log.error("Key为空null");
                    return null;
                }
                // 判断Key是否为16位
                if (sKey.length() != 16) {
                    log.error("Key长度不是16位");
                    return null;
                }
                byte[] raw = sKey.getBytes("utf-8");
                SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
                Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
                cipher.init(Cipher.DECRYPT_MODE, skeySpec);
                byte[] encrypted1 = new Base64().decode(sSrc);//先用base64解密
                try {
                    byte[] original = cipher.doFinal(encrypted1);
                    String originalString = new String(original, "utf-8");
                    return originalString;
                } catch (Exception e) {
                    System.out.println(e.toString());
                    return null;
                }
            } catch (Exception ex) {
                System.out.println(ex.toString());
                return null;
            }
        }

        public static String encrypt(String sSrc, String sKey) {
            try {
                if (sKey == null) {
                    log.error("Key为空null");
                    return null;
                }
                // 判断Key是否为16位
                if (sKey.length() != 16) {
                    log.error("Key长度不是16位");
                    return null;
                }
                byte[] raw = sKey.getBytes("utf-8");
                SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
                Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");//"算法/模式/补码方式"
                cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
                byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));

                return new Base64().encodeToString(encrypted);//此处使用BASE64做转码功能，同时能起到2次加密的作用。
            } catch (Exception e) {
                log.error("加密失败{}", e.getMessage());
                return null;
            }
        }

    }

}
