package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;

/**
 * @Author Liu Tao
 * @Date 2023 12 04 14 51
 **/
@Slf4j
@Service
public class XiaoMeiYiRongCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XiaoMeiYiRong;
    }

    @Data
    private static class RequestDate {
        private String data;
        private Integer providerAPIId;
        private Integer encryptType;
    }
    @Data
    private static class CheckInfo {
        private String telMD5;
    }
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit XiaoMeiYiRongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("小美易融对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo=new CheckInfo();
            checkInfo.setTelMD5( userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5());
            RequestDate requestDate=new RequestDate();
            requestDate.setData(AESUtil.encrypt(JSON.toJSONString(checkInfo),config.getString("publicKey")));
            requestDate.setProviderAPIId(config.getInteger("apiId"));
            requestDate.setEncryptType(1);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck XiaoMeiYiRongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, requestDate);
            JsonNode jsonNode = null;
            try {

                HttpHeaders headers = new HttpHeaders();
                headers.set("Content-Type","application/json");
                headers.set("User-Agent","Apifox/1.0.0 (https://apifox.com)");
                HttpEntity<String> requestEntity = new HttpEntity<>(JSONObject.toJSONString(checkInfo), headers);
                httpRestTemplate.restTemplate().postForEntity(url, checkInfo, String.class);

//                okhttp3.OkHttpClient client = new OkHttpClient().newBuilder()
//                        .build();
//                okhttp3.MediaType mediaType = MediaType.parse("application/json");
//                RequestBody body = RequestBody.create(mediaType, JSON.toJSONString(requestDate));
//                Request request = new Request.Builder()
//                        .url(url)
//                        .method("POST", body)
//                        .addHeader("", )
//                        .addHeader("Content-Type", "application/json")
//                        .build();
//                Response execute = client.newCall(request).execute();
                String responseBody = requestEntity.getBody();
                log.info("小美易融 =======================>{}",JSONObject.parseObject(responseBody));
                ObjectMapper objectMapper = new ObjectMapper();
                // 解析JSON字符串
                jsonNode = objectMapper.readTree(responseBody);
            } catch (Exception e) {
                log.error("小美易融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XiaoMeiYiRongCreditService response userId:{}, result:{}", userInfo.getUserId(), jsonNode);
            if (jsonNode == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonNode.get("code").intValue()==0) {
                return DataVo.success(0, "小美易融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "小美易融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("小美易融撞库失败", e);
            return DataVo.fail(1, "小美易融撞库失败，请联系系统管理员", product.getPlanId());
        }
    }



    public static class AESUtil {

        public static final String AES = "AES";

        private static final String ALGORITHMSTR = "AES/ECB/PKCS7Padding";


        /**
         * encrypt input text
         *
         * @param input
         * @param key
         * @return
         * @throws Exception
         */
        public static String encrypt(String input, String key) throws Exception {

            SecretKeySpec skey = new SecretKeySpec(key.getBytes(), AES);
            Cipher cipher = Cipher.getInstance(ALGORITHMSTR);
            cipher.init(Cipher.ENCRYPT_MODE, skey);
            byte[] crypted = cipher.doFinal(input.getBytes("UTF8"));

            return new String(Base64.encodeBase64(crypted));
        }
    }
}
