package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;
import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

/**
 * @Author Liu Tao
 * @Date 2024 07 09 17 03
 **/
@Slf4j
@Service
public class XinChuangYinHuiCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;


    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XinChuangYinHui;
    }

    @Data
    private static class CheckInfo {
        private String phoneMd5;// 手机号md5
        private String channelCode;//渠道编号
        private String city;//城市
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfoCmd) {
        try {
            log.info("credit XinChuangYinHuiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfoCmd.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("信创对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            JSONObject json = new JSONObject();
            json.put("phoneMd5", phoneMd5);
            json.put("channelCode", config.getString("channelCode"));
            json.put("city", userInfo.getCompanyCity());
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck XinChuangYinHuiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, phoneMd5);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, json, String.class);
            } catch (Exception e) {
                log.error("信创准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XinChuangYinHuiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject data = JSONObject.parseObject(jsonObject.getString("data"));
            if (jsonObject.getInteger("code") == 0 && data.getInteger("status") == 0) {
                return DataVo.success(0, "信创撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "信创撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("信创撞库失败", e);
            return DataVo.fail(1, "信创撞库失败，请联系系统管理员", product.getPlanId());
        }
    }


}
