package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Base64;

/**
 * @Author zjc
 * @Date 2024 08 29 11 08
 **/
@Slf4j
@Service
public class XinZheChangZhiCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XingZheChangZhi;
    }

    //撞库
    @Data
    private static class CheckInfo {
        private String phone;//md5 的手机号

    }

    @Data
    private static class RquestParam {
        private String data;

    }


    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit XingZheChangZhiCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("行者常至对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhone(phoneMd5);
            RquestParam requestParam=new RquestParam();
            requestParam.setData(encrypt(JSON.toJSONString(checkInfo),config.getString("key"),config.getString("iv")));

            String secretKey = config.getString("secretKey");
            String jsonString = JSON.toJSONString(requestParam);
            String sign = Md5Util.encoderByMd5(jsonString.concat(secretKey)).toLowerCase();
            log.info("行者常至请求参数:sign:{},requestParam:{},checkInfoJson:{}",sign,jsonString,JSON.toJSONString(checkInfo));
            String url = config.getString("checkUrl");
            String appid=config.getString("appid");
            url=url+"?appid="+appid+"&sign="+sign;
            log.info("credit qualityCheck XingZheChangZhiCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, phoneMd5);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, requestParam, String.class);
            } catch (Exception e) {
                log.error("行者常至准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XingZheChangZhiCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject == null || StringUtils.isBlank(jsonObject.getString("data"))) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            String data = jsonObject.getString("data");
            JSONObject jsonData = JSONObject.parseObject(data);
            if (jsonObject.getString("code").equals("200") && "0".equals(jsonData.getString("status"))) {
                return DataVo.success(0, "行者常至撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "行者常至撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("行者常至撞库失败", e);
            return DataVo.fail(1, "行者常至撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    public static String encrypt(String plainText, String key, String iv) throws Exception {
        // 将 key 转换为 SecretKey 对象
        SecretKey secretKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
        // 将 IV 字符串转换为字节数组
        byte[] ivBytes = iv.getBytes(StandardCharsets.UTF_8);
        // 生成 IV
        // 创建 Cipher 对象
        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
        cipher.init(Cipher.ENCRYPT_MODE, secretKey, new IvParameterSpec(ivBytes));
        // 加密明文
        byte[] encryptedBytes = cipher.doFinal(plainText.getBytes(StandardCharsets.UTF_8));
        // 将加密后的字节转换为 Base64 编码
        return Base64.getEncoder().encodeToString(encryptedBytes);
    }
}




