package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.SecretKey;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Base64;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author Liu Tao
 * @Date 2024 04 25 15 50
 **/
@Slf4j
@Service
public class XingChiCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XingChi;
    }



    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit XingChiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("星驰对接参数:{}", JSON.toJSONString(config));
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            String url = config.getString("checkUrl");
            String checkurl = url+"?mobileMD5="+phoneMd5;
            log.info("credit qualityCheck XingChiCreditService request userId:{}, url:{}, checkData:{}",userInfo.getUserId(), url,checkurl);
            JSONObject response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/x-www-form-urlencoded; charset=UTF-8");
                HttpResponse httpResponse = httpRestTemplate.restTemplate().getForObject(url, null, null, head, null);
                String responseStr = EntityUtils.toString(httpResponse.getEntity());
                response = JSONObject.parseObject(responseStr);
            }catch (Exception e){
                log.error("星驰准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XingChiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (response.getString("code").equals("200")) {
                return DataVo.success(0, "星驰撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "星驰撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            return DataVo.fail(1, "星驰撞库失败，请联系系统管理员", product.getPlanId());
        }

    }
    public static String encrypt(String plainText, String key, String iv) throws Exception {
        // 将 key 转换为 SecretKey 对象
        SecretKey secretKey = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
        // 将 IV 字符串转换为字节数组
        byte[] ivBytes = iv.getBytes(StandardCharsets.UTF_8);
        // 生成 IV
        // 创建 Cipher 对象
        Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");
        cipher.init(Cipher.ENCRYPT_MODE, secretKey, new IvParameterSpec(ivBytes));
        // 加密明文
        byte[] encryptedBytes = cipher.doFinal(plainText.getBytes(StandardCharsets.UTF_8));
        // 将加密后的字节转换为 Base64 编码
        return Base64.getEncoder().encodeToString(encryptedBytes);
    }


}
