package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.*;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;

/**
 * 欣客贷API接单
 */
@Service
@Slf4j
public class XinkedaiCreditService implements LoanDockingApi {
    private final String qualityCheckPath = "/admin/pushApi/check_mobile";
    private final String applyPath = "/admin/pushApi/import_tttg";
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.Xinkedai;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"url":"http://121.40.173.17:8811"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit XingkedaiCreditService qualityCheck begin...userId:{}",userInfo.getUserId());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("欣客贷对接参数:{}", JSON.toJSONString(config));
            HttpHeaders headers = new HttpHeaders();
            headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
            MultiValueMap<String, String> params= new LinkedMultiValueMap<String, String>();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            params.add("mobile", phoneMd5);
            String url = config.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck XingkedaiCreditService request userId:{}, url:{}, params:{}",userInfo.getUserId(), url, JSON.toJSONString(params));
            ResponseEntity<String> response = null;
            try{
                ResponseEntity<String> requestEntity = httpRestTemplate.restTemplate().postForEntity(url, params, String.class);
                response = httpRestTemplate.restTemplate().postForEntity(url, requestEntity, String.class);
            }catch (Exception e){
                log.error("欣客贷准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XingkedaiCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null || response.getStatusCode()!= HttpStatus.OK) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return JSON.parseObject(response.getBody()).getInteger("code") ==0 ? DataVo.success(0, "欣客贷撞库成功", product.getPlanId())
                    : DataVo.fail("撞库失败", product.getPlanId());

        } catch (Exception e) {
            log.error("欣客贷撞库失败", e);
            return DataVo.fail(1, "欣客贷撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

}
