package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgLoanApiConfigInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.util.Base64;
import java.util.Objects;

/**
 * 鑫鹿API接单
 */
@Service
@Slf4j
public class XinluCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.CRM_XL;
    }

    @Data
    public static class CheckData{
        private String tenantId;
        private Integer type;
        private String phone;
    }

    @Data
    private static class ResultHt{
        private Integer code;
        private String msg;
        private JSONObject data;
    }

    @Data
    private static class ApplyData{
        String data;
        String sign;
        String platformId;
        String tenantId;
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     *  {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo) {
        try {
            log.info("credit XinluCreditService qualityCheck begin...userId:{}",userInfo.getUserId());
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject xinluJointDTO = JSONObject.parseObject(configJson);
            log.info("鑫鹿对接参数:{}", JSONObject.toJSONString(xinluJointDTO));
            String url = xinluJointDTO.getString("checkUrl");
            CheckData checkData = new CheckData();
            checkData.setPhone(userInfo.getUserMobileMD5());
            checkData.setType(2);
            checkData.setTenantId(xinluJointDTO.getString("tenantId"));
            String requestJson = JSON.toJSONString(checkData);
            log.info("credit qualityCheck XinluCreditService request userId:{}, url:{},requestParam",userInfo.getUserId(), url,requestJson);
            ResultHt response = null;
            try{
                HttpHeaders headers = new HttpHeaders();
                headers.set("Content-Type", "application/json");
                HttpEntity httpEntity = new HttpEntity<>(requestJson,headers);
                 response = httpRestTemplate.restTemplate().postForObject(url,httpEntity, ResultHt.class );
            }catch (Exception e){
                log.error("鑫鹿准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XinluCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            return Objects.equals(200, response.getCode()) ? DataVo.success(0, "鑫鹿撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());
        } catch (Exception e) {
            log.error("鑫鹿撞库失败", e);
            return DataVo.fail(1, "鑫鹿撞库失败，请联系系统管理员", product.getPlanId());
        }

    }



    public static class AesUtil {

        /**
         * 默认的字符编码
         */
        private static final String DEFAULT_CHARSET = "utf-8";
        /**
         * 算法/模式/填充
         **/
        private static final String CipherMode = "AES/ECB/PKCS5Padding";
        /**
         * 算法
         */
        private static String ALGORITHM = "AES";

        /**
         * 解密AES 32位
         *
         * @param sSrc      解密的内容
         * @param secretKey 秘钥
         * @return 解密后的明文 数据
         */
        public static String decrypt(String sSrc, String secretKey) {

            if (secretKey == null) {

                return null;
            }
            try {
                byte[] raw = secretKey.getBytes(DEFAULT_CHARSET);
                SecretKeySpec secretKeySpec = new SecretKeySpec(raw, ALGORITHM);
                Cipher cipher = Cipher.getInstance(CipherMode);
                cipher.init(Cipher.DECRYPT_MODE, secretKeySpec);
                // 先用base64解密
                byte[] encryptedArr = Base64.getDecoder().decode(sSrc);
                byte[] original = cipher.doFinal(encryptedArr);
                return new String(original, DEFAULT_CHARSET);
            } catch (Exception ex) {
                return null;
            }
        }


        /**
         * 加密32位
         *
         * @param sSrc 需要加密的内容
         * @param sKey 秘钥
         * @return 加密的内容
         */
        public static String encrypt(String sSrc, String sKey) {
            if (sKey == null) {
                return null;
            }
            try {
                byte[] raw = sKey.getBytes(DEFAULT_CHARSET);
                SecretKeySpec skeySpec = new SecretKeySpec(raw, ALGORITHM);
                Cipher cipher = Cipher.getInstance(CipherMode);
                cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
                byte[] encrypted = cipher.doFinal(sSrc.getBytes(DEFAULT_CHARSET));

                return Base64.getEncoder().encodeToString(encrypted);
            } catch (Exception ex) {
                ex.printStackTrace();
                return null;
            }
        }
    }
}
