package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.*;


/**
 * @Author Liu Tao
 * @Date 2023 10 23 10 33.
 * 徐州富力V2API接单
 **/
@Service
@Slf4j
public class XuzhoufuliV2CreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;



    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XuzhoufuliV2;
    }

    @Data
    public static class CheckData{
        private String merNo;
        private String params;
    }

    @Data
    private static class CheckInfo{
        private String phoneMd5;

        private String sign;

        private String areaName;


    }
    @Data
    private static class ResultHt{
        private String code;
        private String message;
    }
    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit XuzhoufuliV2CreditService qualityCheck begin...userId:{}",userInfo.getUserId());
           
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString();
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("徐州富丽对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5();
            checkInfo.setPhoneMd5(phoneMd5);

            checkInfo.setAreaName(userInfo.getCompanyCity());
//实体类转为JSONObject
            JSONObject jsons = JSONObject.parseObject(JSON.toJSONString(checkInfo));
            jsons.remove("sign");
            String sign = getSign(jsons,config.getString("signKey"));
            checkInfo.setSign(Md5Util.encoderByMd5(sign));
            CheckData checkData = new CheckData();
            checkData.setParams(AESencrypt(JSONObject.toJSONString(checkInfo),config.getString("encKey")));
            checkData.setMerNo(config.getString("merNo"));
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck XuzhoufuliV2CreditService request userId:{}, url:{}, checkData:{}",userInfo.getUserId(), url, checkData);
            String response = null;
            try{
                response =httpRestTemplate.restTemplate().postForObject(url,checkData, String.class);
            }catch (Exception e){
                log.error("徐州富丽准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck XuzhoufuliV2CreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(),product.getPlanName());
            }
            JSONObject jsonObject=JSONObject.parseObject(response);

            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("code") == 200) {
                return DataVo.success(0, "徐州富丽撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "徐州富丽撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("徐州富丽撞库失败", e);
            return DataVo.fail(1, "徐州富丽撞库失败，请联系系统管理员", product.getPlanId());
        }

    }

    /**
     * 字典排序
     * 获得参数格式化字符串
     * 参数名按字典排序，小写在后面
     */
    private static String getFormatParams(Map<String, Object> params) {
        List<Map.Entry<String, Object>> infoIds = new ArrayList<Map.Entry<String, Object>>(params.entrySet());
        Collections.sort(infoIds, new Comparator<Map.Entry<String, Object>>() {
            public int compare(Map.Entry<String, Object> arg0, Map.Entry<String, Object> arg1) {
                return (arg0.getKey()).compareTo(arg1.getKey());
            }
        });
        String ret = "";
        for (Map.Entry<String, Object> entry : infoIds) {
            ret += entry.getKey();
            ret += "=";
            ret += entry.getValue();
            ret += "&";
        }
        ret = ret.substring(0, ret.length() - 1);
        return ret;
    }


    public static String md5WithSalt(String password, String salt) {
        try {
            // 创建 MD5 MessageDigest 实例
            MessageDigest md = MessageDigest.getInstance("MD5");
            // 设置盐值
            md.update(salt.getBytes(StandardCharsets.UTF_8));
            // 对密码进行 MD5 加密
            byte[] digest = md.digest(password.getBytes(StandardCharsets.UTF_8));
            // 将加密后的字节数组转换为十六进制字符串
            StringBuilder sb = new StringBuilder();
            for (byte b : digest) {
                sb.append(String.format("%02x", b));
            }
            // 返回 32 位小写 MD5 加密结果
            return sb.toString();
        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException("MD5 algorithm not found", e);
        }
    }

    public static String AESencrypt(String str, String key) throws Exception {
        // Create the SecretKeySpec with the given key and algorithm
        SecretKeySpec keySpec = new SecretKeySpec(key.getBytes(StandardCharsets.UTF_8), "AES");
        // Get the AES cipher instance with ECB padding
        Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
        // Initialize the cipher with the given key
        cipher.init(Cipher.ENCRYPT_MODE, keySpec);
        // Encrypt the input string
        byte[] bytes = cipher.doFinal(str.getBytes(StandardCharsets.UTF_8));
        // Convert the encrypted bytes to a hexadecimal string
        return parseByte2HexStr(bytes);
    }

    private static String parseByte2HexStr(byte[] bytes) {
        StringBuilder sb = new StringBuilder();
        for (byte b : bytes) {
            sb.append(String.format("%02x", b));
        }
        return sb.toString();
    }
    /**
     * 计算签名
     *
     * @param params
     * @return
     */
    public static String getSign(JSONObject params,String key) {
        String sortStr = getFormatParams(params);
        System.out.println("sortStr = " + sortStr);
        //第二步：将tradeKey拼接在1中排序后的字符串后面得到待签名字符串。
        sortStr += "&key="+ key;
        System.out.println("sortStr = " + sortStr);
        //sortStr += "key=BF1BDE5A649724056F904A9335B1C1C9";
        //第三步：使用md5算法加密待加密字符串并转为大写即为sign
//        String sign = DigestUtils.md5DigestAsHex(sortStr.getBytes()).toUpperCase();
//        System.out.println("sign = " + sign);
        return sortStr;
    }


}
