package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.fasterxml.jackson.databind.JsonNode;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.UserUtils;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * 雪易融 API 接单
 * @author 黄洋
 * @since 1.0
 */
@Slf4j
@Component
public class XveYiRongCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Data
    private static class Result {
        private Integer code;
        private String msg;
        private JSONObject data;
    }

    @Data
    private static class CheckInfo {
        /**
         * 手机号
         */
        private String name;
        /**
         * 手机号
         */
        private String phone;

    }

    /**
     * 撞库
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        log.info("credit XveYiRongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
        try {

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            if (Objects.isNull(config)) {
                return DataVo.fail(product.getPlanName(), product.getPlanId());
            }
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setName( UserUtils.getUserName(userInfo.getRealName(), userInfo.getPoliceSex()));
            checkInfo.setPhone(userInfo.getUserMobileMD5());

            String url = config.getString("checkUrl");
            log.info("credit qualityCheck XveYiRongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            JsonNode jsonNode = null;
            String msg = null;
            String data = null;
            try {
                HttpHeaders headers = new HttpHeaders();
                headers.set("Content-Type","text/plain");
                headers.set("authKey",config.getString("authKey"));
                headers.set("sessionId",config.getString("sessionId"));
                headers.set("sessionId",config.getString("sessionId"));

                HttpEntity<String> requestEntity = new HttpEntity<>(JSONObject.toJSONString(checkInfo), headers);
                 httpRestTemplate.restTemplate().postForEntity(url, checkInfo, String.class);


//                OkHttpClient client = new OkHttpClient().newBuilder()
//                        .build();
//                MediaType mediaType = MediaType.parse("text/plain");
//                RequestBody body = RequestBody.create(mediaType, JSON.toJSONString(checkInfo));
//                Request request = new Request.Builder()
//                        .url(url)
//                        .method("POST", body)
//                        .addHeader("authKey", config.getString("authKey"))
//                        .addHeader("sessionId", config.getString("sessionId"))
//                        .addHeader("Content-Type", "text/plain")
//                        .build();
//                Response execute = client.newCall(request).execute();
                String responseBody = requestEntity.getBody();
                log.info("雪易融 =======================>{}",JSONObject.parseObject(responseBody));
                ObjectMapper objectMapper = new ObjectMapper();
                // 解析JSON字符串
                 jsonNode = objectMapper.readTree(responseBody);

                if(!Objects.isNull(jsonNode.get("msg"))){
                    msg = jsonNode.get("msg").asText();
                }
                if(!Objects.isNull(jsonNode.get("data"))){
                    data = jsonNode.get("data").asText();
                }


            } catch (Exception e) {
                log.error("雪易融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck 雪易融CreditService response userId:{}, result:{}", userInfo.getUserId(), jsonNode);
            if (jsonNode == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return Objects.equals(0,  jsonNode.get("code").intValue()) ?
                    DataVo.success(0, "雪易融撞库成功", product.getPlanId())
                    : DataVo.fail((msg != null) ? msg : data, product.getPlanId());

        } catch (Exception e) {
            log.error("雪易融撞库失败", e);
            return DataVo.fail(1, "雪易融撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.XveYiRong;
    }



}
