package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.infrastructure.utils.SM3Util;
import com.hrsk.cloud.eg.infrastructure.utils.SM4Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.catalina.manager.host.Constants;
import org.bouncycastle.util.encoders.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.*;

/**
 * @Author Liu Tao
 * @Date 2024 03 18 10 29
 **/
@Slf4j
@Service
public class YiLianRongCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.YiLianRong;
    }

    @Data
    private static class RequestData{
        private String appKey;//平台提供appKe
        private String timestamp;//时间戳
        private String requestId;//唯⼀请求标识，例如：UUID
        private String sign;//签名字符串
        private String data;//请求报⽂密⽂
    }
    @Data
    private static class CheckInfo{
        private String phone;//⼿机号码MD5加密密⽂
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit YiLianRongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("易联融对接参数:{}", JSON.toJSONString(config));
            String appSecret = config.getString("appSecret");
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhone((userInfo.getUserMobileMD5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getUserMobileMD5()));
            JSONObject data = new JSONObject();
            data.put("phone",checkInfo.getPhone());
            // appKey，timestamp，requestId，data 参数按照 ASCII 升序排序，按照“参数=参
            Map<String, String> signMap = new HashMap<>();
            signMap.put("appKey", config.getString("appKey"));
            signMap.put("timestamp", new Date().getTime() + "");
            signMap.put("requestId", UUID.randomUUID().toString());
            String encrypt = SM4Util.encryptStrToBase64(data.toJSONString(), appSecret);
            signMap.put("data", encrypt);
            String signStr = signForJx(signMap, appSecret);
            signMap.put("sign",signStr);
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck YiLianRongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, signMap);
            String response = null;
            try {
                response =httpRestTemplate.restTemplate().postForObject(url,signMap, String.class);
            } catch (Exception e) {
                log.error("易联融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck YiLianRongCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject jsonObject = JSONObject.parseObject(response);
            log.info("credit qualityCheck YiLianRongCreditService response userId:{}, jsonObject:{}", userInfo.getUserId(), jsonObject);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getString("code").equals("0")) {
                return DataVo.success(0, "易联融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "易联融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("易联融撞库失败", e);
            return DataVo.fail(1, "易联融撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    /**
     * ⽣成签名. Java
     *
     * @param data 待签名数据
     * @param appSecret API密钥
     * @return 签名
     */
    public static String signForJx(Map<String, String> data, String appSecret) {
        Set<String> keySet = data.keySet();
        String[] keyArray = keySet.toArray(new String[0]);
        Arrays.sort(keyArray);
        StringBuilder sb = new StringBuilder();
        for (String k : keyArray) {
            sb.append(k).append("=").append(data.get(k)).append("&");
        }
        sb.deleteCharAt(sb.length() - 1);
        try {
            return Base64.toBase64String(SM3Util.sm3(sb.toString().getBytes(Constants.CHARSET), appSecret.getBytes(Constants.CHARSET)));
        } catch (Exception e) {
            return "";
        }
    }

}
