package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.AESUtilPkcs7;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.stereotype.Service;
import org.springframework.util.LinkedMultiValueMap;
import org.springframework.util.MultiValueMap;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.util.Collections;
import java.util.List;

/**
 * 一起花API接单
 */
@Service
@Slf4j
public class YiQiHuaCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.YiQiHua;
    }

    @Data
    private static class CheckInfo {
        private String phone;
        private String source;
        private String city;
    }

    @Data
    private static class ResultHt {
        private String code;
        private String data;
        private String msg;
    }

    @Data
    private static class YiQiHuaConfig {
        private List<String> city;
        private String checkUrl;
        private String applyUrl;
        private String key;
        private String postion;
        private String channel;
    }



    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit YiQiHuaCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
           
            String configJson = HessianUtils.deserialize(configInfo.getRequestConfig()).toString() ;
            YiQiHuaConfig config = getYiQiHuaConfig(configJson, userInfo.getCityCode());
            log.info("对接参数:{}", JSON.toJSONString(config));
            if (null == config) {
                log.info("对接参数不满足城市:");
                return DataVo.fail(1, "一起花撞库失败，请联系系统管理员", product.getPlanId());
            }
            String url = config.getCheckUrl();
            String response = null;
            try {
                MultiValueMap<String, String> params = new LinkedMultiValueMap<>();
                params.put("phone", Collections.singletonList(userInfo.getUserMobileMD5()));
                params.put("source", Collections.singletonList(config.getChannel()));
                params.put("city", Collections.singletonList(userInfo.getCityAllName()));
                HttpHeaders headers = new HttpHeaders();
                headers.setContentType(MediaType.APPLICATION_FORM_URLENCODED);
                HttpEntity<MultiValueMap<String, String>> httpEntity = new HttpEntity<>(params, headers);
                log.info("credit qualityCheck YiQiHuaCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, params);
                response = httpRestTemplate.restTemplate().postForEntity(url, httpEntity, String.class).getBody();
            } catch (Exception e) {
                log.error("一起花准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck YiQiHuaCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            JSONObject jsonObject = JSON.parseObject(response);
            log.info("yiqihua check response{}", response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (jsonObject.getInteger("status") == 200) {
                return DataVo.success(0, "一起花撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "一起花撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("一起花撞库失败", e);
            return DataVo.fail(1, "一起花撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    private YiQiHuaConfig getYiQiHuaConfig(String configData, String cityCode) {
        List<YiQiHuaConfig> config =JSON.parseArray(configData,YiQiHuaConfig.class);
        if (CollectionUtils.isNotEmpty(config)) {
            for (YiQiHuaConfig c : config) {
                if (c.getCity().contains(cityCode)) {
                    return c;
                }
            }
        }
        return null;
    }


    private static class ApiAesUtil {
        //使用AES-128-CBC加密模式，key需要为16位,key和iv可以相同！

        /**
         * @param data 明文
         * @return 密文
         * @author miracle.qu
         * @Description AES算法加密明文
         */
        public static String encryptAES(String data, String ekey, String eiv) {
            try {

                Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5Padding");

                SecretKeySpec keyspec = new SecretKeySpec(ekey.getBytes("UTF-8"), "AES");
                // CBC模式，需要一个向量iv，可增加加密算法的强度
                IvParameterSpec ivspec = new IvParameterSpec(eiv.getBytes("UTF-8"));

                cipher.init(Cipher.ENCRYPT_MODE, keyspec, ivspec);
                byte[] encrypted = cipher.doFinal(data.getBytes("UTF-8"));
                // BASE64做转码。
                return AESUtilPkcs7.encode(encrypted).trim();
            } catch (Exception e) {
                e.printStackTrace();
                return null;
            }
        }

    }


}
