package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
/**
 * 壹融API接单
 */
@Service
@Slf4j
public class YiRongCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final String qualityCheckPath = "/api/customer/phoneRepeatCheck";

    private final String applyPath = "/api/customer/insertDataToCustomer2";



    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.YiRong;
    }

    @Data
    private static class CheckInfo {
        private String mobile_md5;
        private String channelSource;
    }

    @Data
    private static class ResultHt {
        private String code;
        private String data;
        private String msg;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit YiRongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("对接参数:{}", JSONObject.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setMobile_md5(userInfo.getUserMobileMD5());
            checkInfo.setChannelSource(config.getString("channelSource"));
            String url = config.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck YiRongCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, String.class);
                log.info("fanhui");
            } catch (Exception e) {
                log.error("壹融准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck YiRongCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            JSONObject jsonObject = JSONObject.parseObject(response);
            if (jsonObject == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject data = jsonObject.getJSONObject("data");
            if (jsonObject.get("code").equals("200") && data.get("status").equals("1")) {
                return DataVo.success(0, "壹融撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "壹融撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("壹融撞库失败", e);
            return DataVo.fail(1, "壹融撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    private static class ApiAesUtil {
        private static final String AES = "AES";
        private static final String SP = "SHA1PRNG";
        private static final String CHARACTER = "utf-8";
        private static final String ALGO = "AES/ECB/PKCS5Padding"; // 使用AES算法，ECB模式，PKCS5Padding填充

        public static String decrypt(String sSrc, String sKey) {
            try {
                // 判断Key是否正确
                if (sKey == null) {
                    log.error("Key为空null");
                    return null;
                }
                // 判断Key是否为16位
                if (sKey.length() != 16) {
                    log.error("Key长度不是16位");
                    return null;
                }
                byte[] raw = sKey.getBytes("utf-8");
                SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
                Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");
                cipher.init(Cipher.DECRYPT_MODE, skeySpec);
                byte[] encrypted1 = new Base64().decode(sSrc);//先用base64解密
                try {
                    byte[] original = cipher.doFinal(encrypted1);
                    String originalString = new String(original, "utf-8");
                    return originalString;
                } catch (Exception e) {
                    System.out.println(e.toString());
                    return null;
                }
            } catch (Exception ex) {
                System.out.println(ex.toString());
                return null;
            }
        }

        public static String secureBytes(String key) {
            if (key.length() > 16) {
                key = key.substring(0, 16);
            } else if (key.length() < 16) {
                for (int i = (key.length() - 1); i < 15; i++) {
                    key += "\000";
                }
            }
            return key;

        }

        /**
         * @param strhex
         * @return
         */
        public static byte[] hex2byte(String strhex) {
            if (strhex == null) {
                return null;
            }
            int l = strhex.length();
            if (l % 2 != 0) {
                return null;
            }
            byte[] b = new byte[l / 2];
            for (int i = 0; i != l / 2; i++) {
                b[i] = (byte) Integer.parseInt(strhex.substring(i * 2, i * 2 + 2),
                        16);
            }
            return b;
        }

        /**
         * @param b
         * @return
         */
        public static String byte2hex(byte[] b) {
            String hs = "";
            String stmp = "";
            for (int n = 0; n < b.length; n++) {
                stmp = (Integer.toHexString(b[n] & 0XFF));
                System.out.println(stmp);
                if (stmp.length() == 1) {
                    hs = hs + "0" + stmp;
                } else {
                    hs = hs + stmp;
                }
            }
            return hs.toUpperCase();
        }

        public static char[] bytes2hex(final byte[] data) {
            final int l = data.length;
            final char[] out = new char[l << 1];
            // two characters form the hex value.
            for (int i = 0, j = 0; i < l; i++) {
                out[j++] = DIGITS_LOWER[(0xF0 & data[i]) >>> 4];
                out[j++] = DIGITS_LOWER[0x0F & data[i]];
            }
            return out;
        }

        private static final char[] DIGITS_LOWER = {'0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'a', 'b', 'c', 'd', 'e', 'f'};

        public static String encrypt(String sSrc, String sKey) {
            try {


                if (sKey == null) {
                    log.error("Key为空null");
                    return null;
                }
                // 判断Key是否为16位
                if (sKey.length() != 16) {
                    log.error("Key长度不是16位");
                    return null;
                }
                byte[] raw = sKey.getBytes("utf-8");
                SecretKeySpec skeySpec = new SecretKeySpec(raw, "AES");
                Cipher cipher = Cipher.getInstance("AES/ECB/PKCS5Padding");//"算法/模式/补码方式"
                cipher.init(Cipher.ENCRYPT_MODE, skeySpec);
                byte[] encrypted = cipher.doFinal(sSrc.getBytes("utf-8"));

                return new Base64().encodeToString(encrypted);//此处使用BASE64做转码功能，同时能起到2次加密的作用。
            } catch (Exception e) {

            }
            return null;
        }

    }


}
