package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/2/8
 * @Version V1.0
 **/
@Service
@Slf4j
public class YijieCreditService implements LoanDockingApi {

    private final static String checkPath = "api/third/check_loan?server=1";
    private final static String pushPath = "api/third/loan_do?server=1";
    private final static String factor = "tVhNbn86r3R0";
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    @Data
    private static class CheckInfo {
        private String channel;
        private JSONObject data;
    }

    @Data
    private static class Result {
        private Integer code;

        private String message;
    }



    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit YijieCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("易借对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setChannel(config.getString("channel"));
            JSONObject data = new JSONObject() {{
                put("type", 102);
                put("mobileMd5", userInfo.getUserMobileMD5());
            }};
            checkInfo.setData(data);

            String url = config.getString("url") + checkPath;
            log.info("credit qualityCheck YijieCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            Result response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, Result.class);
            } catch (Exception e) {
                log.error("易借准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck YijieCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return Objects.equals(0, response.getCode()) ? DataVo.success(0, "易借撞库成功", product.getPlanId())
                    : DataVo.fail("撞库失败", product.getPlanId());

        } catch (Exception e) {
            log.error("易借撞库失败", e);
            return DataVo.fail(1, "易借撞库失败，请联系系统管理员", product.getPlanId());
        }
    }

    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.YiJie;
    }

    public String bulidSign(String jsonStr, String factor) {
        return Md5Util.encoderByMd5(jsonStr + "_" + factor);
    }


}
