package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.lang3.StringUtils;
import org.springframework.http.HttpEntity;
import org.springframework.http.HttpHeaders;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import javax.crypto.Cipher;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Random;

import static org.apache.commons.codec.digest.DigestUtils.sha256Hex;


/**
 * @Descrption 银华咨询
 * @Author: zhangyy
 * @Date: 2023/5/15
 * @Version V1.0
 **/
@Service
@Slf4j
public class YinHuaCreditService implements LoanDockingApi {
    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final String qualityCheckPath = "api/channel/clue/md5/_check";

    private final String applyPath = "api/channel/clue";



    @Data
    private static class CheckInfo {
        private String phoneMd5;
        private String channelSource;
    }

    @Data
    private static class ResultHt {
        private String code;
        private String msg;
    }
    @Override
    public ServerCodeEnums  getType() {
        return ServerCodeEnums.YinHua;
    }


    /**
     * 撞库 实现单个用户撞库
     *
     * @param userInfo
     * @param product
     * @return {"channelSource":"birong","url":"http://apitest.shlyxxjs.com","key":"mgjr@3des123#dhjr9763089"}
     */
    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd configInfo)  {
        try {
            log.info("credit HuizhongCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
          
            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("银华对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setPhoneMd5(userInfo.getUserMobileMD5());
            String url = config.getString("url") + qualityCheckPath;
            log.info("credit qualityCheck YinHuaCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            String response = null;
            try {
                HttpHeaders headers = new HttpHeaders();
                headers.setContentType(MediaType.APPLICATION_JSON);
                headers.set("channel", config.getString("channel"));
                HttpEntity httpEntity = new HttpEntity<>(checkInfo, headers);
                ResponseEntity<String> responseEntity = httpRestTemplate.restTemplate().postForEntity(url, httpEntity, String.class);
                response = responseEntity.getBody();
            } catch (Exception e) {
                log.error("银华准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck YinHuaCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            JSONObject res = JSONObject.parseObject(response);
            if (res.getInteger("code") == 200) {
                if (res.getJSONObject("data").getInteger("status") == 0) {
                    return DataVo.success(0, "银华撞库成功", product.getPlanId());
                }
                return DataVo.fail(1, "银华撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("银华撞库失败", e);
            return DataVo.fail(1, "银华撞库失败，请联系系统管理员", product.getPlanId());
        }
        return DataVo.fail(1, "银华撞库失败，请联系系统管理员", product.getPlanId());
    }


    private static class ApiAesUtil {
        private static final String AES = "AES";
        private static final String CIPHER_ALGORITHM = "AES/ECB/PKCS5Padding";

        /**
         * 串接arr参数，生成sha256 digest.
         * json，nonce，secretKey，timestamp
         */
        public static String getSignature(String... arr) {
            StringBuilder sb = new StringBuilder();
            for (String a : arr) {
                sb.append(a);
            }
            return sha256Hex(sb.toString());
        }


        /**
         * 随机生成16位字符串.
         */
        public static String getRandomStr() {
            return getRandomStr(16);
        }

        /**
         * 随机生成字符串.
         *
         * @param length 字符串长度
         */
        public static String getRandomStr(int length) {
            String base = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789";
            Random random = new Random();
            StringBuilder sb = new StringBuilder();
            for (int i = 0; i < length; i++) {
                int number = random.nextInt(base.length());
                sb.append(base.charAt(number));
            }
            return sb.toString();
        }

        /**
         * 获取当前时间戳
         *
         * @return
         */
        public static Long getTimeStamp() {
            return System.currentTimeMillis() / 1000L;
        }

        /**
         * 加密
         *
         * @param value     加密内容
         * @param secretKey 密钥
         * @return 加密后数据
         */
        public static String encrypt(String value, String secretKey) {
            try {
                if (StringUtils.isBlank(value)) {
                    log.error("加密失败,参数为空");
                    return null;
                }
                if (secretKey.length() != 16) {
                    return null;
                }

                byte[] aesKey = secretKey.getBytes(StandardCharsets.UTF_8);
                SecretKeySpec keySpec = new SecretKeySpec(aesKey, AES);
                Cipher cipher = Cipher.getInstance(CIPHER_ALGORITHM);
                cipher.init(Cipher.ENCRYPT_MODE, keySpec);
                return Base64.encodeBase64String(cipher.doFinal(value.getBytes(StandardCharsets.UTF_8)));
            } catch (Exception e) {
                log.error("加密失败,参数为空");
                return null;
            }
        }

        /**
         * 对密文进行解密.
         *
         * @param encryptedData 需要解密的密文
         * @param secretKey     密钥
         * @return 解密得到的明文
         */
        public static String decrypt(String encryptedData, String secretKey) {
            if (StringUtils.isBlank(encryptedData)) {
                log.error("解密失败,参数为空");
                return null;
            }
            if (secretKey.length() != 16) {
                return null;
            }
            try {
                byte[] aesKey = secretKey.getBytes(StandardCharsets.UTF_8);
                SecretKeySpec keySpec = new SecretKeySpec(aesKey, AES);
                Cipher cipher = Cipher.getInstance(CIPHER_ALGORITHM);
                cipher.init(Cipher.DECRYPT_MODE, keySpec);
                return new String(cipher.doFinal(Base64.decodeBase64(encryptedData)));
            } catch (Exception e) {
                log.error("解密失败{}", e.getMessage());
                return null;
            }
        }

    }
}
