package com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.EgLoanApiConfigInfoCmd;
import com.hrsk.cloud.eg.clinet.dto.data.plan.command.PlanCmd;
import com.hrsk.cloud.eg.clinet.dto.data.user.command.UserBaseInfoCmd;
import com.hrsk.cloud.eg.domain.common.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.loanMannager.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import com.hrsk.cloud.eg.clinet.vo.DataVo;

import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * @Descrption
 * @Author: chend
 * @Date: 2023/2/6
 * @Version V1.0
 **/
@Slf4j
@Service
public class YukuaihuaCreditService implements LoanDockingApi {

    @Resource
    private EgApiService egApiService;

    @Resource
    private RetryRestTemplate httpRestTemplate;

    private final static String checkPath = "api/External/hit_library";
    private final static String applyPath = "api/External/create";

    @Data
    private static class Result {
        private Integer code;

        private String msg;

        private Long time;

        private Object data;
    }

    @Data
    private static class CheckInfo {
        private String userPhone;
    }

    @Override
    public DataVo qualityCheck(UserBaseInfoCmd userInfo, PlanCmd product, EgLoanApiConfigInfoCmd    configInfo)  {
        try {
            log.info("credit YukuaihuaCreditService qualityCheck begin...userId:{}", userInfo.getUserId());
//            XdProductJointConfig xdProductJointConfig = xdProductJointConfigMapper.selectById(product.getJointType());

            byte[] requestConfig = configInfo.getRequestConfig();
            Object deserialize = HessianUtils.deserialize(requestConfig);
            JSONObject config = JSONObject.parseObject(deserialize.toString());
            log.info("愉快花对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            checkInfo.setUserPhone(userInfo.getUserMobileMD5());
            String url = config.getString("url") + checkPath;
            log.info("credit qualityCheck YukuaihuaCreditService request userId:{}, url:{}, CheckInfo:{}", userInfo.getUserId(), url, checkInfo);
            Result response = null;
            try {
                response = httpRestTemplate.restTemplate().postForObject(url, checkInfo, Result.class);
            } catch (Exception e) {
                log.error("愉快花准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck YukuaihuaCreditService response userId:{}, result:{}", userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            return Objects.equals(1, response.getCode()) ? DataVo.success(0, "愉快花撞库成功", product.getPlanId())
                    : DataVo.fail(response.getMsg(), product.getPlanId());

        } catch (Exception e) {
            log.error("愉快花撞库失败", e);
            return DataVo.fail(1, "愉快花撞库失败，请联系系统管理员", product.getPlanId());
        }
    }
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.YuKuaiHua;
    }

}
