package com.hrsk.cloud.eg.infrastructure.request;

import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.clinet.dto.data.command.LoanParamCmd;
import com.hrsk.cloud.eg.clinet.vo.DataVo;
import com.hrsk.cloud.eg.domain.api.Api;
import com.hrsk.cloud.eg.domain.api.ApiFactory;
import com.hrsk.cloud.eg.domain.api.HttpApi;
import com.hrsk.cloud.eg.domain.api.HttpApiConfig;
import com.hrsk.cloud.eg.infrastructure.config.client.HessianUtils;
import com.hrsk.cloud.eg.infrastructure.config.client.HttpTemPlateClient;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.EgApiEndpointDo;
import com.hrsk.cloud.eg.infrastructure.service.EgApiEndpointService;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Objects;

/**
 * @author zhangyy
 * @version 1.0
 * @description: HttpRequestCheckIntoService
 * @date 2024/8/30 14:15
 */
@Slf4j
@Service
public class HttpRequestCheckIntoService {
    @Resource
    private EgApiService    egApiService;

    @Resource
    private EgApiEndpointService egApiEndpointService;

    @Resource
    private ApiFactory apiFactory;

    @Resource
    private HttpTemPlateClient httpTemPlateClient;


    /**
     * @description:  撞库
     * @param:
     * @return:
     * @author zhangyy
     * @date: 2024/8/30 14:24
     */
    public DataVo checkInto(LoanParamCmd paramDto){
        EgApiEndpointDo eg = egApiEndpointService.getById(paramDto.getPlan().getApiId());
        try {
            HttpApiConfig httpApiConfig = (HttpApiConfig) HessianUtils.deserialize(eg.getRequestConfig());
            String type = httpApiConfig.getUrl().substring(0, httpApiConfig.getUrl().indexOf("://"));
            httpApiConfig.setType(type);
            Api api = apiFactory.createApi(httpApiConfig, paramDto);
            Object result = httpTemPlateClient.request((HttpApi) api);
            if (Objects.isNull(result)) {
                return DataVo.fail();
            }
            Object output = apiFactory.createResult(httpApiConfig, result);
            JSONObject res = JSONObject.parseObject(output.toString());
            DataVo dataVo = new DataVo();
            dataVo.setStatus(res.getInteger("status"));
            dataVo.setMsg(paramDto.getPlan().getPlanName()+"撞库成功");
            return dataVo;
        } catch (Exception e) {
            log.error("check into error {}",paramDto.getPlan().getPlanId(),e);
            return DataVo.fail(paramDto.getPlan().getPlanName());
        }
    }
}
