package com.hrsk.cloud.eg.infrastructure.service.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hrsk.cloud.eg.clinet.constant.GlobalDataStatusEnum;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.*;
import com.hrsk.cloud.eg.infrastructure.repository.database.mapper.EgApiEndpointMapper;
import com.hrsk.cloud.eg.infrastructure.repository.database.mapper.EgApiLoanExtendMapper;
import com.hrsk.cloud.eg.infrastructure.repository.database.mapper.EgApiMapper;
import com.hrsk.cloud.eg.infrastructure.service.EgApiService;
import com.hrsk.cloud.eg.infrastructure.utils.RedisUtil;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.List;
import java.util.Objects;

import static com.hrsk.cloud.eg.infrastructure.constant.RedisConstant.BUSINESS_API_KEY;

/**
 * @author zhangyy
 * @version 1.0
 * @description: EgApiServiceImpl
 * @date 2024/8/28 11:01
 */
@Service
public class EgApiServiceImpl extends ServiceImpl<EgApiMapper, EgApiDo> implements EgApiService {

    @Resource
    private EgApiEndpointMapper egApiEndpointMapper;

    @Resource
    private EgApiLoanExtendMapper egApiLoanExtendMapper ;

    @Resource
    private RedisUtil   redisUtil;

    @Override
    public EgLoanApiConfigInfoDo getLoanApiConfigInfo(Integer apiId) {
        EgLoanApiConfigInfoDo egLoanApiConfigInfoDo=new EgLoanApiConfigInfoDo();
        EgApiDo egApiDo = baseMapper.selectById(apiId);
        if (Objects.isNull(egApiDo)) {
            return new EgLoanApiConfigInfoDo();
        }
        egLoanApiConfigInfoDo.setApiName(egApiDo.getApiName());
        egLoanApiConfigInfoDo.setApiType(egApiDo.getApiType());
        egLoanApiConfigInfoDo.setApiId(egApiDo.getId());
        //查询对应的配置
        LambdaQueryWrapper<EgApiEndpointDo> queryWrapper=new LambdaQueryWrapper<>();
        queryWrapper.eq(EgApiEndpointDo::getApiId, apiId);
        queryWrapper.eq(EgApiEndpointDo::getStatus, GlobalDataStatusEnum.YES.getCode());
        queryWrapper.orderByDesc(EgApiEndpointDo::getId);
        queryWrapper.last("limit 1");

        EgApiEndpointDo egApiEndpointDos = egApiEndpointMapper.selectOne(queryWrapper);
        if (Objects.isNull(egApiEndpointDos)) {
            return egLoanApiConfigInfoDo;
        }
        egLoanApiConfigInfoDo.setRequestConfig(egApiEndpointDos.getRequestConfig());

        //查询扩展配置
        LambdaQueryWrapper<EgApiLoanExtendDo> extendDoLambdaQueryWrapper=new LambdaQueryWrapper<>();
        extendDoLambdaQueryWrapper.eq(EgApiLoanExtendDo::getApiId, egApiEndpointDos.getId());
        extendDoLambdaQueryWrapper.eq(EgApiLoanExtendDo::getStatus, GlobalDataStatusEnum.YES.getCode());
        extendDoLambdaQueryWrapper.orderByDesc(EgApiLoanExtendDo::getId);
        extendDoLambdaQueryWrapper.last("limit 1");
        EgApiLoanExtendDo egApiLoanExtendDo = egApiLoanExtendMapper.selectOne(extendDoLambdaQueryWrapper);
        if (Objects.isNull(egApiLoanExtendDo)) {
            return egLoanApiConfigInfoDo;
        }
        egLoanApiConfigInfoDo.setNeedCheck(egApiLoanExtendDo.getCheckInto());
        return egLoanApiConfigInfoDo;
    }

    @Override
    public EgLoanApiConfigInfoDo getApiInfoByRedis(Integer apiId) {
        String key = String.format(BUSINESS_API_KEY, apiId);
        Object value = redisUtil.get(key);
        if (null == value || StringUtils.isBlank((String) value)) {
            EgLoanApiConfigInfoDo api = getLoanApiConfigInfo(apiId);
            if (null != api) {
                redisUtil.set(key, JSON.toJSONString(api));
            }
            return api;
        }
        return JSONObject.parseObject((String) value, EgLoanApiConfigInfoDo.class);
    }
}
