package com.hrsk.cloud.eg.infrastructure.service.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.repository.database.mapper.ProductBusinessApiInfoMapper;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.infrastructure.utils.RedisUtil;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.Collections;
import java.util.List;

import static com.hrsk.cloud.eg.infrastructure.constant.RedisConstant.BUSINESS_API_KEY;

/**
 * 商户对接配置信息表业务层
 *
 * @author Mybatis Plus Generator
 * @date 2023.05.09 10:11
 */
@Slf4j
@Service
public class ProductBusinessApiInfoServiceImpl extends ServiceImpl<ProductBusinessApiInfoMapper, ProductBusinessApiInfoDo> implements ProductBusinessApiInfoService {

    @Resource
    private RedisUtil redisUtil;

    @Override
    public List<ProductBusinessApiInfoDo> selectByJointCodeForList(String apiCode) {
        LambdaQueryWrapper<ProductBusinessApiInfoDo> queryChainWrapper=new LambdaQueryWrapper<>();
        queryChainWrapper.eq(ProductBusinessApiInfoDo::getJoinMethod,apiCode);
        queryChainWrapper.orderByDesc(ProductBusinessApiInfoDo::getCreateTime);
        List<ProductBusinessApiInfoDo> productBusinessApiInfoDos = baseMapper.selectList(queryChainWrapper);
        if (CollectionUtils.isEmpty(productBusinessApiInfoDos)) {
            return Collections.emptyList();
        }
        return productBusinessApiInfoDos;
    }

    @Override
    public List<ProductBusinessApiInfoDo> selectByJointJonintTypeForList(String apiCode) {
        LambdaQueryWrapper<ProductBusinessApiInfoDo> queryChainWrapper=new LambdaQueryWrapper<>();
        queryChainWrapper.eq(ProductBusinessApiInfoDo::getJointType,apiCode);
        queryChainWrapper.orderByDesc(ProductBusinessApiInfoDo::getCreateTime);
        List<ProductBusinessApiInfoDo> productBusinessApiInfoDos = baseMapper.selectList(queryChainWrapper);
        if (CollectionUtils.isEmpty(productBusinessApiInfoDos)) {
            return Collections.emptyList();
        }
        return productBusinessApiInfoDos;
    }

    @Override
    public ProductBusinessApiInfoDo getApiInfoByRedis(Integer apiId) {
        String key = String.format(BUSINESS_API_KEY, apiId);
        Object value = redisUtil.get(key);
        if (null == value || StringUtils.isBlank((String) value)) {
            ProductBusinessApiInfoDo api = getById(apiId);
            if (null != api) {
                redisUtil.set(key, JSON.toJSONString(api));
            }
            return api;
        }
        return JSONObject.parseObject((String) value, ProductBusinessApiInfoDo.class);
    }

    @Override
    public List<ProductBusinessApiInfoDo> apiList() {
        LambdaQueryWrapper<ProductBusinessApiInfoDo> queryWrapper=new LambdaQueryWrapper<>();
        queryWrapper.ne(ProductBusinessApiInfoDo::getJoinMethod,2);
        queryWrapper.orderByDesc(ProductBusinessApiInfoDo::getCreateTime);
        List<ProductBusinessApiInfoDo> productBusinessApiInfoDos = baseMapper.selectList(queryWrapper);
        if (CollectionUtils.isEmpty(productBusinessApiInfoDos)) {
            return Collections.emptyList();
        }
        return productBusinessApiInfoDos;
    }
}
