package com.hrsk.cloud.eg.infrastructure.utils;


import org.apache.commons.codec.Charsets;
import org.apache.commons.codec.binary.Base64;
import org.apache.commons.lang3.StringUtils;

import javax.crypto.*;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.security.InvalidAlgorithmParameterException;
import java.security.InvalidKeyException;
import java.security.NoSuchAlgorithmException;


public class AesCBCUtil {
	//使用AES-128-CBC加密模式，key需要为16位,key和iv可以相同！
	private static String KEY = "dufy20170329java";

	private static String IV = "dufy20170329java";

	/**
	 * 加密方法
	 * @param data  要加密的数据
	 * @param key 加密key
	 * @param iv 加密iv
	 * @return 加密的结果
	 * @throws Exception
	 */
	public static String encryptNoPadding(String data, String key, String iv) throws Exception {
		try {
			Cipher cipher = Cipher.getInstance("AES/CBC/NoPadding");//"算法/模式/补码方式"
			int blockSize = cipher.getBlockSize();

			byte[] dataBytes = data.getBytes();
			int plaintextLength = dataBytes.length;
			if (plaintextLength % blockSize != 0) {
				plaintextLength = plaintextLength + (blockSize - (plaintextLength % blockSize));
			}

			byte[] plaintext = new byte[plaintextLength];
			System.arraycopy(dataBytes, 0, plaintext, 0, dataBytes.length);

			SecretKeySpec keyspec = new SecretKeySpec(key.getBytes(), "AES");
			IvParameterSpec ivspec = new IvParameterSpec(iv.getBytes());

			cipher.init(Cipher.ENCRYPT_MODE, keyspec, ivspec);
			byte[] encrypted = cipher.doFinal(plaintext);
			return new Base64().encodeToString(encrypted);

		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	/**
	 * 解密方法
	 * @param data 要解密的数据
	 * @param key  解密key
	 * @param iv 解密iv
	 * @return 解密的结果
	 * @throws Exception
	 */
	public static String desEncryptNoPadding(String data, String key, String iv) throws Exception {
		try {
			byte[] encrypted1 = new Base64().decode(data);
			return desEncryptNoPadding(encrypted1,key, iv);
		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	private static String desEncryptNoPadding(byte[] src,String key, String iv)
			throws NoSuchAlgorithmException, NoSuchPaddingException, InvalidKeyException,
			InvalidAlgorithmParameterException, IllegalBlockSizeException, BadPaddingException {
		Cipher cipher = Cipher.getInstance("AES/CBC/NoPadding");
		SecretKeySpec keyspec = new SecretKeySpec(key.getBytes(), "AES");
		IvParameterSpec ivspec = new IvParameterSpec(iv.getBytes());

		cipher.init(Cipher.DECRYPT_MODE, keyspec, ivspec);

		byte[] original = cipher.doFinal(src);
		String originalString = new String(original);
		return originalString;
	}
	/**
	 * 使用默认的key和iv加密
	 * @param data
	 * @return
	 * @throws Exception
	 */
	public static String encryptNoPadding(String data) throws Exception {
		return encryptNoPadding(data, KEY, IV);
	}

	/**
	 * 使用默认的key和iv解密
	 * @param data
	 * @return
	 * @throws Exception
	 */
	public static String desEncryptNoPadding(String data) throws Exception {
		return desEncryptNoPadding(data, KEY, IV);
	}
	public static String encryptPKCS5PADDING(String data, String key, String iv) throws Exception {
		try {
			Cipher cipher = Cipher.getInstance("AES/CBC/PKCS5PADDING");//"算法/模式/补码方式"
			int blockSize = cipher.getBlockSize();

			byte[] dataBytes = data.getBytes();
			int plaintextLength = dataBytes.length;
			if (plaintextLength % blockSize != 0) {
				plaintextLength = plaintextLength + (blockSize - (plaintextLength % blockSize));
			}
			byte[] plaintext = new byte[plaintextLength];
			System.arraycopy(dataBytes, 0, plaintext, 0, dataBytes.length);

			SecretKeySpec keyspec = new SecretKeySpec(key.getBytes(), "AES");
			IvParameterSpec ivspec = new IvParameterSpec(iv.getBytes());

			cipher.init(Cipher.ENCRYPT_MODE, keyspec, ivspec);
			byte[] encrypted = cipher.doFinal(plaintext);

			return new Base64().encodeToString(encrypted);

		} catch (Exception e) {
			e.printStackTrace();
			return null;
		}
	}

	 /**
     * 加密数据
     *
     * @param data 待加密数据
     * @param key  密钥
     */
    public static byte[] encryptPKCS5PADDING(byte[] data, byte[] key) throws Exception {
        if (key.length != 16) {
            throw new RuntimeException("AES加密失败, 密钥不是128位");
        }
        Cipher cipher = Cipher.getInstance("AES");
        SecretKeySpec keySpec = new SecretKeySpec(key, "AES");
        cipher.init(Cipher.ENCRYPT_MODE, keySpec);
        return cipher.doFinal(data);
    }

    /**
     * 解密数据
     *
     * @param value 待解密数据
     * @param key   密钥
     */
    public static byte[] decryptPKCS5PADDING(byte[] value, byte[] key) throws Exception {
        if (key.length != 16) {
            throw new RuntimeException("AES解密失败, 密钥不是128位");
        }
        Cipher cipher = Cipher.getInstance("AES");
        SecretKey keySpec = new SecretKeySpec(key, "AES");
        cipher.init(Cipher.DECRYPT_MODE, keySpec);
        return cipher.doFinal(value);
    }


    /**
     * 默认的AES加密字符串方法，可以内部使用
     * 对明文的UTF-8编码字节进行加密，然后使用Base64转码
     * 密钥使用UTF-8编码
     *
     * @param data 明文
     * @param key  加密密钥
     */
    public static String encryptPKCS5PADDING(String data, String key) throws Exception {
        if (StringUtils.isEmpty(data) || StringUtils.isEmpty(key)) {
            throw new RuntimeException("AES加密失败, 参数有误. data: " + data + ", key: " + key);
        }
        byte[] keyBytes = key.getBytes(Charsets.UTF_8);
        byte[] dataBytes = data.getBytes(Charsets.UTF_8);
        byte[] encryptBytes = encryptPKCS5PADDING(dataBytes, keyBytes);
        return new String(java.util.Base64.getEncoder().encode(encryptBytes));
    }

    /**
     * 默认的AES解密字符串方法，可以内部使用
     * 对密文使用Base64转码后，再进行解密，然后再转为UTF-8编码
     * 密钥使用UTF-8编码
     *
     * @param
     * @param key        加密密钥
     */
	public static byte[] desEncryptPKCS5PADDING(byte[] value, byte[] key) throws Exception {
		if (key.length != 16) {
			throw new RuntimeException("AES解密失败, 密钥不是128位");
		}
		Cipher cipher = Cipher.getInstance("AES");
		SecretKey keySpec = new SecretKeySpec(key, "AES");
		cipher.init(Cipher.DECRYPT_MODE, keySpec);
		return cipher.doFinal(value);
	}

	public static String desEncryptPKCS5PADDING(String ciphertext, String key) throws Exception {
		if (StringUtils.isEmpty(ciphertext) || StringUtils.isEmpty(key)) {
			throw new RuntimeException("AES解密失败, 参数有误. ciphertext: " + ciphertext + ", key: " + key);
		}
		byte[] keyBytes = key.getBytes(Charsets.UTF_8);
		byte[] dataBytes = java.util.Base64.getDecoder().decode(ciphertext);
		byte[] keyBytesDecrypt = desEncryptPKCS5PADDING(dataBytes, keyBytes);
		return new String(keyBytesDecrypt, Charsets.UTF_8);
	}

	/**
	* 测试
	*/
	public static void main(String args[]) throws Exception {


	}

}
