package com.hrsk.cloud.eg.infrastructure.utils;

import org.springframework.beans.BeanUtils;
import org.springframework.beans.BeanWrapper;
import org.springframework.beans.BeanWrapperImpl;

import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 *
 * Author:   zhangyy
 * Date:     2020/4/3 14:29
 * Description: BeanCopy工具
 * History:
 * describe:
 **/
public class BeanCopyUtils {

    /**
     * 空值不复制
     *
     * @param source
     * @return
     */
    public static String[] getNullPropertyNames(Object source) {
        final BeanWrapper src = new BeanWrapperImpl(source);
        java.beans.PropertyDescriptor[] pds = src.getPropertyDescriptors();

        Set<String> emptyNames = new HashSet<String>();
        for (java.beans.PropertyDescriptor pd : pds) {
            Object srcValue = src.getPropertyValue(pd.getName());
            if (srcValue == null) emptyNames.add(pd.getName());
        }
        String[] result = new String[emptyNames.size()];
        return emptyNames.toArray(result);
    }

    /**
     * 透传数据
     *
     * @param <T>
     */
    public static <T, K> T copy(final K k, final Class<? extends T> t) {
        try {
            T r = t.newInstance();
            BeanUtils.copyProperties(k, r);
            return r;
        } catch (Exception e) {
            return null;
        }
    }

    /**
     * 透传数据
     *
     * @param <T>
     */
    public static <T, K> List<T> copyList(final List<K> kl, final Class<? extends T> t) {
        try {
            List<T> l = new ArrayList<>(kl.size());
            for (K k : kl) {
                l.add(copy(k, t));
            }
            return l;
        } catch (Exception e) {
            return new ArrayList<>();
        }
    }
}
